@@ -3,7 +3,7 @@
 
 #include "moveable.h"
 #include "builder.h"
-#include "player.h"
+#include "individual.h"
 
 class Boat : public Moveable
 {
@@ -23,7 +23,7 @@ public:
 
    int     enter_boat(Player *the_player);
    int     exit_boat(Player *the_player);
-   int     get_passengers(Player *the_player, Strings *the_string);
+   int     get_passengers(Individual *the_ind, Strings *the_string);
    int     stop_passengers_fighting(void);
    int     move_location(Location *new_loc);
    int     contains_players(void);
