@@ -7,10 +7,12 @@
 #define FORMAT_FUNC 0
 #define FORMAT_EQ   1
 
-struct params {
+class params {
+ public:
+   params();
+   ~params();
    int       param_type;
    var_ptrs  the_param;
-   params    *next_param;
 };
 
 struct in_params {
@@ -31,18 +33,17 @@ public:
    int    add_pass_param(params *the_param);
    params *get_param(int the_num);
    
-   params *execute_command(Specials *the_special, Player *the_player, 
+   params *execute_command(Specials *the_special, Individual *the_user, 
         in_params *player_params, int *the_results, special_env *environment);
    int    load_from_file(FILE *the_file, ErrLog *the_log);
    int    load_from_file(FILE *the_file, ErrLog *the_log, int the_format);
 
-   int       delete_param_list(params *the_list);
    Code      *get_next_code();
    int       set_next_code(Code *the_code);
    Code      **get_next_ptr();
    Spec_Func get_funct_ptr();
    int       copy_code(Code *copy_from);
-   params    *copy_param_list();
+   LinkedList<params> *copy_param_list_to(LinkedList<params> *the_list);
    void      set_var_name(char *new_name);
    char      *get_var_name();
 
@@ -54,8 +55,8 @@ private:
    Code();
 
    Spec_Func the_mudcode;
-   params    *param_list;
-   params    *pass_list;
+   LinkedList<params> param_list;
+   LinkedList<params> pass_list;
    int       valid;
 
    Strings   var_name;
