@@ -15,7 +15,10 @@
 
 #ifdef INDIVIDUAL_C
 
-char *indflagnames[] = {"Male", "Fighting", "AttackPlayer", "NoSteal",
+char *sex_possessive[] = {"his", "her", "its", NULL};
+char *sex_name[] = {"Male", "Female", "Neuter", NULL};
+
+char *indflagnames[] = {"NotUsed1", "Fighting", "AttackPlayer", "NoSteal",
        "Sitting", "Sleeping", "GetStuff", "InBoat", "Corpse", 
        "Ghost", "NightVision", NULL};
 
