@@ -34,7 +34,10 @@ public:
    virtual void describe(Player *the_player);
    virtual int set_attrib(Builder *the_builder, Parse *the_parsed);
    virtual int copy_object(Entity *copy_obj);
-
+   int remove_from_loc();
+   virtual int set_dual_loc(char *loc1_name, char *loc2_name, 
+                                                  Object_List *the_dbase);
+   int     set_location(MudObject *new_loc);
    int     get_mem_size_item();
 
 protected:
