@@ -1,14 +1,17 @@
 #ifndef _MUDTYPES_H_
 #define _MUDTYPES_H_
 
+#include "linkedlist.h"
 
 class Code;
 class Specials;
 class MudObject;
-struct params;
+
 struct in_params;
 struct special_env;
 
+class params;
+
 
 #define MAXNAMELEN     80   /* max length a mudobject name can have */
 #define MAXFILENAMELEN 60   /* max length of a filename that we will allow */
@@ -30,11 +33,11 @@ typedef enum { false, true } bool;
 
 enum load_type { None, Header, Full };
 
-class Player;
+class Individual;
 class Parse;
 typedef void (*Cmd_Func)(Parse *, MudObject *); 
-typedef params *(*Spec_Func)(params *, Specials *, Player *, in_params *, 
-                                         special_env *, int *);
+typedef params *(*Spec_Func)(LinkedList<params> *, Specials *, Individual *, 
+			     in_params *, special_env *, int *);
 typedef int (*Inp_Func)(MudObject *, char *); 
 
 
