@@ -28,12 +28,16 @@ public:
    void     set_untied();
    virtual  int get_mem_size();
    virtual  int get_mem_size_dynamic();
+   
+   void     set_other_loc(MudObject *new_loc);
+   MudObject *get_other_loc();
 
  private:
 
    Rope();
 
-   int     length;
+   int       length;
+   MudObject *other_loc;
 };
 
 
