@@ -14,11 +14,6 @@ class Skill : public Ability {
    virtual ~Skill();
    Skill(char *skill_name);
 
-   void set_min_str(int new_str);
-   int get_min_str();
-   void set_min_dex(int new_dex);
-   int get_min_dex();
-
    Flags *get_skillflags();
 
    int read_skill_attrib(FILE *read_file, ErrLog *error_log);   
@@ -33,12 +28,10 @@ class Skill : public Ability {
    virtual int get_mem_size();
    virtual int get_mem_size_dynamic();
 
+   virtual int check_usage(Individual *user, MudObject *target);
 
  private:
 
-
-   int     min_str;
-   int     min_dex;
    Flags   *skill_flags;
 };
 
