@@ -14,9 +14,6 @@ class Spell : public Ability {
    virtual ~Spell();
    Spell(char *spell_name);
 
-   void set_min_intel(int new_min_intel);
-   int get_min_intel();
-
    Flags *get_spellflags();
    
    int read_spell_attrib(FILE *read_file, ErrLog *error_log);
@@ -32,11 +29,10 @@ class Spell : public Ability {
    virtual int get_mem_size();
    virtual int get_mem_size_dynamic();
 
+   virtual int check_usage(Individual *user, MudObject *target);
 
  private:
 
-
-   int     min_intel;
    Flags   *spell_flags;
 };
 
