@@ -5,15 +5,16 @@
 #define SPELLFLAG_OPTTARGET    1
 #define SPELLFLAG_ONLYIND      2
 #define SPELLFLAG_NOIND        3
-#define SPELLFLAG_REQINTEL     4
+#define SPELLFLAG_ONCORPSE     4
 #define SPELLFLAG_MUSTSTAND    5
 #define SPELLFLAG_PASSSTRING   6
 #define SPELLFLAG_GIVEEXP      7
+#define SPELLFLAG_ONSELF       8
 
 #ifdef COMMANDS_C
 
 char *spellflagnames[] = {"ReqTarget", "OptTarget", "OnlyInd", "NoInd", 
-       "ReqIntel", "MustStand", "PassString", "GiveExp", NULL};
+       "OnCorpse", "MustStand", "PassString", "GiveExp", "OnSelf", NULL};
 
 #else
 
