@@ -2,7 +2,7 @@
 #define _VERB_LIST_H
 
 #include "verb.h"
-#include "btree_l.h"
+#include "btree.h"
 #include "lextree.h"
 #include "builder.h"
 #include "errlog.h"
