@@ -1,9 +1,6 @@
 #ifndef _WEAPON_H
 #define _WEAPON_H
 
-#ifdef USE_PTHREAD
-#include <pthread.h>
-#endif
 #include "strings.h"
 #include "moveable.h"
 #include "builder.h"
@@ -44,6 +41,8 @@ public:
    virtual  int get_mem_size();
    virtual  int get_mem_size_dynamic();
 
+   int swing(Individual *attacker, Individual *target, Merger **proj_return);
+
  private:
 
    Weapon();
