@@ -39,6 +39,8 @@
 #include "skillflags.h"
 #include "spellflags.h"
 #include "player.h"
+#include "global.h"
+#include "code.h"
 
 char *depend_name[] = {"ReqIntel", "ReqStrength", "ReqDexterity", 
 		       "ReqConstitution", "ReqHealth", "ReqMaxHealth",
@@ -810,20 +812,6 @@ int Ability::read_ability_attrib(FILE *read_file, ErrLog *error_log,
    set_failure_str(Target, temp_desc);
    delete temp_desc;
 
-   // We keep this in for now but need to remove it before the next version release
-   /* get the next item, it should be a '^', if not, raise error */
-   the_token = get_token(read_file, '\0');
-   if (the_token->token_type != T_CARROT)
-   {
-     error_log->invalid_attr_format(get_name(), "abilities", 
-				    "items needed", "read_ability_attrib");
-     return -1;
-   }
-
-   /* get the items needed string */
-   the_token = get_token(read_file, '^');
-   // REmoved
-
    /* get the next item, it should be a '^', if not, raise error */
    the_token = get_token(read_file, '\0');
    if (the_token->token_type != T_CARROT)
@@ -975,9 +963,6 @@ int Ability::write_ability_attrib(FILE *the_file)
                                                    get_failure_str(Actor));
    fprintf(the_file, "^%s^\n", (get_failure_str(Target) == NULL) ? "" : 
                                                    get_failure_str(Target));
-   fprintf(the_file, "^^\n");  // Remove later
-//   fprintf(the_file, "^%s^\n", (get_items_needed() == NULL) ? "" : 
-//                                                     get_items_needed());
    fprintf(the_file, "^%s^\n", (get_special_name() == NULL) ? "" : 
                                                      get_special_name());
    fprintf(the_file, "^%s^\n", (get_succ_trig() == NULL) ? "" :
@@ -1050,7 +1035,7 @@ int Ability::copy_ability_attrib(Ability *copy_from)
  **
  ***********************************************************************/
 
-int Ability::test_success(Player *the_player, int difficulty)
+int Ability::test_success(Individual *the_user, int difficulty)
 {
    int the_rank;
    int succ_factor;
@@ -1058,7 +1043,7 @@ int Ability::test_success(Player *the_player, int difficulty)
    Flags *skillflags = NULL;
    Flags *spellflags = NULL;
 
-   the_rank = the_player->get_rank_number(get_name());
+   the_rank = the_user->get_rank_number(get_name());
 
    /* first roll the dice */ 
    succ_factor = 1+ (int) (20.0*(rand()/(RAND_MAX+1.0)));
@@ -1085,47 +1070,47 @@ int Ability::test_success(Player *the_player, int difficulty)
 
       if (has_dependency(ReqIntel))
       {
-         the_sum += get_stat_bonus(the_player->get_intel());
+         the_sum += get_stat_bonus(the_user->get_intel());
          num_apply++;
       }
       if (has_dependency(ReqStrength))
       {
-         the_sum += get_stat_bonus(the_player->get_strength());
+         the_sum += get_stat_bonus(the_user->get_strength());
          num_apply++;
       }
       if (has_dependency(ReqDexterity))
       {
-         the_sum += get_stat_bonus(the_player->get_dexterity());
+         the_sum += get_stat_bonus(the_user->get_dexterity());
          num_apply++;
       }
       if (has_dependency(ReqHealth))
       {
-         the_sum += get_stat_bonus(the_player->get_health());
+         the_sum += get_stat_bonus(the_user->get_health());
          num_apply++;
       }
       if (has_dependency(ReqConstitution))
       {
-         the_sum += get_stat_bonus(the_player->get_constitution());
+         the_sum += get_stat_bonus(the_user->get_constitution());
          num_apply++;
       }
       if (has_dependency(ReqEndurance))
       {
-         the_sum += get_stat_bonus(the_player->get_endurance());
+         the_sum += get_stat_bonus(the_user->get_endurance());
          num_apply++;
       }
       if (has_dependency(ReqMagic))
       {
-         the_sum += get_stat_bonus(the_player->get_magic());
+         the_sum += get_stat_bonus(the_user->get_magic());
          num_apply++;
       }
       if (has_dependency(ReqWisdom))
       {
-         the_sum += get_stat_bonus(the_player->get_wisdom());
+         the_sum += get_stat_bonus(the_user->get_wisdom());
          num_apply++;
       }
       if (has_dependency(ReqCharisma))
       {
-         the_sum += get_stat_bonus(the_player->get_charisma());
+         the_sum += get_stat_bonus(the_user->get_charisma());
          num_apply++;
       }
 
@@ -1139,16 +1124,16 @@ int Ability::test_success(Player *the_player, int difficulty)
    succ_factor -= (difficulty * 2);
 
    /* next we subtract a factor for the total weight carried */
-   succ_factor -= (int) (the_player->get_weight_held() / 10);
+   succ_factor -= (int) (the_user->get_weight_held() / 10);
 
    /* now we subtract for poor health */
-   div_factor = ((float) the_player->get_health() / 
-                                      (float) the_player->get_maxhealth());
+   div_factor = ((float) the_user->get_health() / 
+                                      (float) the_user->get_maxhealth());
    succ_factor -= (10 - ((int) (10.0 * div_factor)));
 
    /* now we subtract for exhaustion */
-   div_factor = ((float) the_player->get_endurance() / 
-                                   (float) the_player->get_max_endurance());
+   div_factor = ((float) the_user->get_endurance() / 
+                                   (float) the_user->get_max_endurance());
 
    succ_factor -= (10 - ((int) (10.0 * div_factor)));
 
@@ -1426,7 +1411,10 @@ int Ability::add_dependency(depend_type the_type, int the_val)
 	new_dep->next_depend = NULL;
 
 	if (the_type == MustHaveItem)
+	{
+		delete new_dep;
 		return -1;
+	}
 
 	new_dep->the_type = the_type;
 	new_dep->num_value = the_val;
@@ -1733,6 +1721,230 @@ int Ability::copy_dependencies(dependency *the_list)
 	return 1;
 }
 
+/***********************************************************************
+ ** use_ability - casts or performs this ability for a player or mobile
+ **
+ **	Parameters: user - the user who is using the ability
+ **                 target - the target of this ability, if any
+ **                 targ_name - in case the spell uses a string parameter
+ **
+ ** Returns: 1 if success, 0 if something stopped them, -1 if error
+ **
+ ***********************************************************************/
+
+int Ability::use_ability(Individual *user, MudObject *target, char *targ_name)
+{
+   Location  *cur_loc;
+   char *pre_trig;
+   char *on_trig;
+   Flags *abil_flag;
+   int results;
+   Strings formatted;
+   Strings holder;
+   int succ_factor;
+
+   // Check if we are properly using this ability first
+   if (check_usage(user, target) < 1)
+     return 0;
+
+   cur_loc = user->get_loc();
+
+   if (get_type() == OBJ_TYPE_SPELL)
+   {
+     pre_trig = "pre_cast";
+     on_trig = "oncast";
+     abil_flag = ((Spell *) this)->get_spellflags();
+   }
+   else
+   {
+     pre_trig = "on_perform";
+     on_trig = "onperform";
+     abil_flag = ((Skill *) this)->get_skillflags();
+   }
+
+   /*************** send the message that we are using this ********/
+   results = 0;
+
+   formatted.format_for_abilities(get_acting_str(Room), user, target);
+   if ((target != NULL) && (target->get_type() == OBJ_TYPE_PLAYER))
+   {
+      cur_loc->send_location(formatted.str_show(), user, (Player *) target);
+      formatted.format_for_abilities(get_acting_str(Target), user, target);
+      ((Player *) target)->send_plr("%s", formatted.str_show());
+   }
+   else
+   {
+      cur_loc->send_location(formatted.str_show(), user, ( Player * )NULL);
+   }
+
+   formatted.format_for_abilities(get_acting_str(Actor), user, target);
+   user->send_plr("%s", formatted.str_show());
+
+   if (check_specials(_(pre_trig), user, NULL, NULL, user, user) == 3)
+     return 0;
+
+   /* drain the player the amount */
+   if (get_type() == OBJ_TYPE_SPELL)
+     user->set_magic(user->get_magic() - get_drain());
+   else
+     user->set_endurance(user->get_endurance() - get_drain());
+
+   if ((target != NULL) && (get_attempt_trig() != NULL))
+   {
+
+      if ((results = check_specials(get_attempt_trig(), target,
+                  target, NULL, target, user, targ_name)) == 3)
+         return 0;
+      else if (results == 7)
+         return 0;
+   }
+
+
+
+   /*************** is it successful ************/
+
+   succ_factor = test_success(user, 1);
+
+   if (succ_factor >= 30)
+   {
+      Specials    *the_special;
+      special_env environment;
+      in_params fill_param;
+
+      environment.exec_vars = NULL;
+
+      if (results != 5)
+      {
+         formatted.format_for_abilities(get_success_str(Room), user, target);
+         if ((target != NULL) && (target->get_type() == OBJ_TYPE_PLAYER))
+         {
+            cur_loc->send_location(formatted.str_show(), user, (Player *) target);
+            formatted.format_for_abilities(get_success_str(Target), user, target);
+            ((Player *) target)->send_plr("%s", formatted.str_show());
+         }
+         else
+         {
+            cur_loc->send_location(formatted.str_show(), user, ( Player * )NULL);
+         }
+
+         formatted.format_for_abilities(get_success_str(Actor), user, target);
+         user->send_plr("%s", formatted.str_show());
+      }
+
+      if ((the_special = mainstruct->get_special(get_special_name())) != NULL)
+      {
+
+         if (STRCASECMP(the_special->get_trigger(), _(on_trig)))
+         {
+            holder.sprintf(
+                _("Special %s for ability %s not with '%s' trigger\n"),
+                      the_special->get_name(), get_name(), on_trig);
+            mainstruct->log_error(holder.str_show(), "use_ability");
+            return 0; 
+         }
+
+         fill_param.primary_obj = target;
+         fill_param.secondary_obj = NULL;
+         fill_param.this_obj = user;
+
+         environment.counter = the_special->get_counter();
+         if (((get_type() == OBJ_TYPE_SPELL) && 
+	      (abil_flag->get_flag(SPELLFLAG_PASSSTRING))) ||
+	     ((get_type() == OBJ_TYPE_SKILL) && 
+	      (abil_flag->get_flag(SKILLFLAG_PASSSTRING))))
+         {
+            environment.target_str = targ_name;
+         }
+         environment.stack_pointer = NULL;
+
+         the_special->run_special(user, &fill_param, &environment);
+      }
+
+      if ((target != NULL) && (get_succ_trig() != NULL))
+      {
+         if ((results =
+               check_specials(get_succ_trig(), target, target,
+                   NULL, target, user, targ_name)) == 3)
+            return 0;
+
+      }
+
+      // Mobiles don't increase ability rank by using it, but players do
+      if (get_type() == OBJ_TYPE_PLAYER)
+      {
+	if (((get_type() == OBJ_TYPE_SPELL) && 
+	     (abil_flag->get_flag(SPELLFLAG_GIVEEXP))) ||
+	    ((get_type() == OBJ_TYPE_SKILL) && 
+	     (abil_flag->get_flag(SKILLFLAG_GIVEEXP))))
+	{
+	  ((Player *) user)->increase_rank_exp(100, this, 1);
+	}
+      }
+
+   }
+   /* spell failed */
+   else
+   {
+      if (results != 4)
+      {
+         formatted.format_for_abilities(get_failure_str(Room), user, target);
+         if ((target != NULL) && (target->get_type() == OBJ_TYPE_PLAYER))
+         {
+            cur_loc->send_location(formatted.str_show(), user, (Player *) target);
+            formatted.format_for_abilities(get_failure_str(Target), user, target);
+            ((Player *) target)->send_plr("%s", formatted.str_show());
+         }
+         else
+         {
+            cur_loc->send_location(formatted.str_show(), user, ( Player * )NULL);
+         }
+
+         formatted.format_for_abilities(get_failure_str(Actor), user, target);
+         user->send_plr("%s", formatted.str_show());
+      }
+
+      if ((target != NULL) && (get_fail_trig() != NULL))
+      {
+         if (check_specials(get_fail_trig(), target, target,
+                           NULL, target, user, targ_name) == 3)
+            return 0;
+      }
+
+
+      // Mobiles don't increase ability rank by using it, but players do
+      if (get_type() == OBJ_TYPE_PLAYER)
+      {
+
+	if (((get_type() == OBJ_TYPE_SPELL) && 
+	     (abil_flag->get_flag(SPELLFLAG_GIVEEXP))) ||
+	    ((get_type() == OBJ_TYPE_SKILL) && 
+	     (abil_flag->get_flag(SKILLFLAG_GIVEEXP))))
+	{
+	  ((Player *) user)->increase_rank_exp(100, this, 2);
+	}
+      }
+   }
+
+   cur_loc = user->get_loc();
+   return 1;
+}
+
+
+/***********************************************************************
+ ** check_usage - not used in ability, only subclasses
+ **
+ **	Parameters: user - the user who is using the ability
+ **                 target - the target of this ability, if any
+ **
+ ** Returns: 1 if success, 0 if something stopped them, -1 if error
+ **
+ ***********************************************************************/
+
+int Ability::check_usage(Individual *user, MudObject *target)
+{
+  return -1;
+}
+
 
 #endif
 
