@@ -63,7 +63,7 @@ Action::Action(char *action_name)
 
    modified = 0;
    obj_type = OBJ_TYPE_ACTION;
-   act_flags = new_Flags(1);
+   act_flags = new Flags(1);
 }
 
 
@@ -78,7 +78,7 @@ Action::Action(char *action_name)
 
 Action::~Action(void)
 {
-   delete_Flags(act_flags);
+   delete act_flags;
 }
 
 
@@ -559,28 +559,53 @@ int Action::execute_action(Parse *the_parsed, Player *the_player)
    Location   *player_loc;
    Strings    formatted;
    Flags      *tmp_actflags;
-   MudObject  *target_ind;
+   MudObject  *the_target = NULL;
+   Individual *target_ind = NULL;
    int        the_num = 0;
+   int        results;
+   Strings    pretrig;
+   Strings    posttrig;
 
    tmp_actflags = get_actflags();
    player_loc = the_player->get_loc();
 
+   pretrig.sprintf("pre_action_%s", get_name());
+   posttrig.sprintf("post_action_%s", get_name());
+
+   printf("pretrig: %s\n", pretrig.str_show());
    /* if this is a targeted action, show appropriate strings */
    if ((tmp_actflags->get_flag(ACTFLAG_TARGETED)) &&
        (the_parsed->get_target1() != NULL))
    {
+      /* get the target if it exists */
+      if ((the_target = player_loc->
+	   find_contained(the_parsed->get_target1(), &the_num)) == NULL)
+      {
+	if ((the_target = the_player->
+	     find_contained(the_parsed->get_target1(), &the_num)) == NULL)
+	{
+	  return -2;
+	}
+      }
+
+      /* now run any specials on this target */
+      if ((results = check_specials(pretrig.str_show(), the_target, NULL, NULL,
+				    the_target, the_player)) == 3)
+	return 0;
+      
+
       /* don't perform the action on objects, only individuals */
-      if (((target_ind = player_loc->
-             find_contained(the_parsed->get_target1(), &the_num)) == NULL) ||
-               ((target_ind->get_type() != OBJ_TYPE_PLAYER) &&
-                         (target_ind->get_type() != OBJ_TYPE_MOBILE)))
+      if (((the_target->get_type() != OBJ_TYPE_PLAYER) &&
+                         (the_target->get_type() != OBJ_TYPE_MOBILE)))
          return -2;
 
+      target_ind = (Individual *) the_target;
+
       /* if it is a player, show them the string */
       if (target_ind->get_type() == OBJ_TYPE_PLAYER)
       {
          formatted.format_for_actions(target.str_show(), the_player,
-                                               (Individual *) target_ind);
+                                                                target_ind);
          ((Player *) target_ind)->send_plr("%s", formatted.str_show());
       }
 
@@ -598,10 +623,20 @@ int Action::execute_action(Parse *the_parsed, Player *the_player)
       else
          player_loc->send_location(formatted.str_show(), the_player, ( Player * )NULL);
 
+      /* now run any specials on this target */
+      if ((results = check_specials(posttrig.str_show(), the_target, NULL, NULL,
+				    the_target, the_player)) == 3)
+	return 0;
+
       return 1;
 
    }
 
+   /* now run any specials on this target */
+   if ((results = check_specials(pretrig.str_show(), the_player->get_loc(), NULL, 
+				 NULL, the_player->get_loc(), the_player)) == 3)
+     return 0;
+
    /* if the action can go to all in the room, send to them */
    if (tmp_actflags->get_flag(ACTFLAG_ALL))
    {
@@ -612,6 +647,11 @@ int Action::execute_action(Parse *the_parsed, Player *the_player)
       player_loc->send_location(formatted.str_show(), the_player);
    }
 
+   /* now run any specials on this target */
+   if ((results = check_specials(posttrig.str_show(), the_player->get_loc(), NULL, 
+				 NULL, the_player->get_loc(), the_player)) == 3)
+     return 0;
+
 
    return 1;
 }
