@@ -202,7 +202,7 @@ int Boat::enter_boat(Player *the_player)
    tmp_indflags = the_player->get_indflags();
    tmp_indflags->set_flag(INDFLAG_INBOAT);
 
-   the_player->set_location(this, the_player->get_loc());
+   the_player->set_location(this);
    return 1;
 }
 
@@ -223,7 +223,7 @@ int Boat::exit_boat(Player *the_player)
    tmp_indflags = the_player->get_indflags();
    tmp_indflags->clr_flag(INDFLAG_INBOAT);
 
-   the_player->set_location(get_contained_by(), this);
+   the_player->set_location(get_contained_by());
    return 1;
 }
 
@@ -520,16 +520,22 @@ Boat *Boat::operator = (Boat *copy_from)
  **           0 if failed
  **
  ***********************************************************************/
-int Boat::get_passengers(Player *the_player, Strings *the_string)
+int Boat::get_passengers(Individual *the_ind, Strings *the_string)
 {
    MudObject *tmp_obj;
    Individual *cur_ind = NULL;
    Individual *next_ind = NULL;
    int        first = 1;
+   Player     *the_player;
+
+   if (the_ind->get_type() != OBJ_TYPE_PLAYER)
+     return 0;
 
    if (the_string == NULL)
       return -1;
 
+   the_player = (Player *) the_ind;
+
    the_string->truncate(0);
    inventory.reset_current();
    tmp_obj = inventory.get_next();
@@ -627,10 +633,9 @@ int Boat::move_location(Location *new_loc)
    Individual *the_ind;
    Flags      *tmp_gameflags;
    Player     *the_player;
-   LinkedNode *tmp_node;
    Strings    holder;
 
-   if (set_location(new_loc, get_contained_by()) == -1)
+   if (set_location(new_loc) == -1)
    {
      holder.sprintf(_("Could not set boat location %s@%s for boat '%s@%s'"), 
 	       new_loc->get_name(), new_loc->get_area(), get_name(), get_area());
@@ -647,17 +652,17 @@ int Boat::move_location(Location *new_loc)
       {
          the_ind = (Individual *) tmp_obj;
  
-         the_ind->set_curr_loc(new_loc);
+         the_ind->set_location(new_loc);
 
          if (the_ind->get_type() == OBJ_TYPE_PLAYER)
 	 {
             the_player = (Player *) the_ind;
             tmp_gameflags = the_player->get_gameflags();
 
-            tmp_node = inventory.store_current();
+            inventory.push_current();
             new_loc->show_location(the_player, 
                                     tmp_gameflags->get_flag(GAMEFLAG_BRIEF));
-            inventory.restore_current(tmp_node);
+            inventory.pop_current();
          }
 
       }
