@@ -115,7 +115,7 @@ void Book::write_object(FILE *the_file, int build_format)
    write_item_attrib(the_file);
    write_moveable_attrib(the_file);
 
-   fprintf(the_file, "%s\n", get_book_subject());
+   fprintf(the_file, "^%s^\n", get_book_subject());
 }
 
 /***********************************************************************
@@ -497,11 +497,21 @@ Book *Book::operator = (Book *copy_from)
 int Book::read_book_attrib(FILE *read_file, ErrLog *error_log)
 {
    token_record *the_token;
+   Strings holder;
+   
 
-   error_log = NULL;
+   /* get the next item, it should be a '^', if not, raise error */
+   the_token = get_token(read_file, '\0');
+   if (the_token->token_type != T_CARROT)
+   {
+      holder.sprintf("Invalid format in book %s, area %s", get_name(), 
+		     get_area());
+      error_log->log_err(holder.str_show(), "read_item_attrib");
+      return -1;
+   }
 
    /* get the book subject */
-   the_token = get_token(read_file, '\0');
+   the_token = get_token(read_file, '^');
    set_book_subject(the_token->the_string);
 
    return 1;
