@@ -36,9 +36,8 @@
 #include "builder.h"
 #include "player.h"
 #include "location.h"
-#include "btree_l.h"
+#include "btree.h"
 #include "area_dbase.h"
-#include "btree_a.h"
 #include "login.h"
 #include "verb.h"
 #include "parse.h"
@@ -101,6 +100,90 @@ Builder::Builder(Connection *the_conn)
 	init_object(the_conn);
 }   
 
+/***********************************************************************
+ ** is_visible - is this builder totally visible
+ **
+ ** Parameters: Nothing
+ **
+ ** Returns: 1 for true, 0 for false
+ **
+ ***********************************************************************/
+
+int Builder::is_visible()
+{
+    return (vislvl == VIS_VISIBLE);
+}
+
+
+/***********************************************************************
+ ** is_vis_admin - is this builder admin invis
+ **
+ ** Parameters: Nothing
+ **
+ ** Returns: 1 for true, 0 for false
+ **
+ ***********************************************************************/
+
+int Builder::is_vis_admin()
+{
+    return (vislvl == VIS_ADMIN);
+}
+
+
+/***********************************************************************
+ ** get_vislvl - get the vislvl of the builder
+ **
+ ** Parameters: Nothing
+ **
+ ** Returns: 0, 1, 2, or 3
+ **
+ ***********************************************************************/
+
+int Builder::get_vislvl()
+{
+    return vislvl;
+}
+
+
+/***********************************************************************
+ ** get_vislvl_str - gets the string version of an builder's vislvl
+ **
+ ** Parameters: Nothing
+ **
+ ** Returns: Visible, GameInvis, Incognito, or AdminInvis
+ **
+ ***********************************************************************/
+
+char *Builder::get_vislvl_str()
+{
+    return vis_table[vislvl];
+}
+
+
+/***********************************************************************
+ ** set_vislvl - sets an builder's vislvl
+ **
+ ** Parameters: VIS_VISIBLE, VIS_GAME, VIS_INCOG, or VIS_ADMIN
+ **
+ ** Returns: Nothing
+ **
+ ***********************************************************************/
+
+void Builder::set_vislvl(int in_vislvl)
+{
+    vislvl = in_vislvl;
+}
+
+bool Builder::can_see_bldr(Builder *the_bldr)
+{
+    if (the_bldr->is_visible())
+        return true;
+
+    if (the_bldr->is_vis_admin() && get_adminflags()->get_flag(ADMINFLAG_ADMINISTRATOR))
+        return true;
+
+    return false;
+}
 
 /***********************************************************************
  ** init_object - initializes this object
@@ -147,8 +230,10 @@ int Builder::init_object(Connection *the_conn)
 
    /* set the prompt and push the main input handler onto the stack */
    set_prompt();
+
    input_handler.push_input_handler(main_bldr_handler, &prompt, 0, 0, 0);
 
+
 #ifdef WIN32
    if (!has_valid_conn)
    {
@@ -280,30 +365,39 @@ int Builder::check_connection()
    {
        if (the_socket->has_input())
        {   
-
-          had_input = 1;
-          the_input = 
-               the_socket->get_input(input_handler.get_lines_per_handle());
+	 // Loop through and handle lines
+	 for (int i=0; i<input_handler.get_lines_per_handle(); i++)
+	 {
+           the_input = the_socket->get_input();
 
            if (the_input != NULL)
-	   {
-              holder.sprintf(_("                                   \r"
-                             "&+g%s's input:&* %s"), get_title(), 
+           {
+              holder.sprintf("                                   \r"
+                             "&+g%s's input:&* %s", get_title(),
                                                        the_input->str_show());
               get_connection()->send_to_snoopers(holder.str_show());
+              input_handler.exec_input_handler((MudObject *) this,
+                                                     the_input->str_show());
+	      delete the_input;
+	   }
+	   else
+	   {
+	     break;
 	   }
 
-          if (the_input != NULL)
-             input_handler.exec_input_handler((MudObject *) this, 
-                                                     the_input->str_show());
+	   // If this player has lost its connection, exit out
+	   if (the_socket == NULL)
+	   {
+	     return -5;				
+	   }
 
-          if (the_input != NULL)
-             delete_Strings(the_input);
+	   if (!is_quitting() && is_on())
+	   {  
+	     send_bldr("%s", input_handler.get_prompt());
+	   }
 
-          if (!is_quitting() && is_on())
-          {  
-             send_bldr("%s", input_handler.get_prompt());
-          }
+           had_input = 1;
+	 }
 
        }
 
@@ -630,7 +724,7 @@ int Builder::load_area(char *areaname, FILE *the_file, ErrLog *error_log,
 
    /* nobody has it already, load it */
    name_area = areaname;
-   the_area = new_Area_Dbase(name_area.str_show());
+   the_area = new Area_Dbase(name_area.str_show());
 
    the_area->load_area(the_file, error_log, build_format, 1);
    if ((!the_area->can_read(this)) &&
@@ -705,7 +799,7 @@ int Builder::load_area(DirRead *the_dir, char *areaname, char *pattern,
 
    /* nobody has it already, load it */
    name_area = areaname;
-   the_area = new_Area_Dbase(name_area.str_show());
+   the_area = new Area_Dbase(name_area.str_show());
 
    the_area->load_area(the_dir, pattern, error_log, build_format, 1);
    if ((!the_area->can_read(this)) &&
@@ -828,7 +922,7 @@ int Builder::delete_area(void)
    clr_modify();
    name_area.truncate(0);
 
-   delete_Area_Dbase(the_area);
+   delete the_area;
    the_area = NULL;
 
    set_prompt();
