@@ -80,7 +80,7 @@ Bulletin::Bulletin(char *bull_name, int build_port)
       tmp_char = new char[10];
    }
 
-   bull_flags = new_Flags(1);
+   bull_flags = new Flags(1);
 }
 
 
@@ -96,31 +96,31 @@ Bulletin::Bulletin(char *bull_name, int build_port)
 Bulletin::~Bulletin()
 { 
    delete_bull();
-   delete_Flags(bull_flags);
+   delete bull_flags;
 }
 
 
 /***********************************************************************
- ** set_location - sets the location string that this bulletin board will
+ ** set_loc_str - sets the location string that this bulletin board will
  **                be attached to (any object, not just locations)
  **
  ** Parameters: the_str - the string to set the field to
  **
  ***********************************************************************/
 
-void Bulletin::set_location(char *the_str)
+void Bulletin::set_loc_str(char *the_str)
 {
    location = the_str;
 }
 
 
 /***********************************************************************
- ** get_location - gets the location string that this bulletin board will
+ ** get_loc_str - gets the location string that this bulletin board will
  **                be attached to (any object, not just locations)
  **
  ***********************************************************************/
 
-char *Bulletin::get_location()
+char *Bulletin::get_loc_str()
 {
    return location.str_show();
 }
@@ -229,7 +229,6 @@ int Bulletin::load_bulletin(ErrLog *error_log)
    if ((the_bullfile = xfopen(bullfilename.str_show(), "r", 
                                                    "bull_file")) == NULL)
    {
-
       return -1;
    }
 
@@ -413,8 +412,8 @@ int Bulletin::write_bull()
    /* no header information yet */
    fprintf(the_bullfile, "^%s^\n", (get_title() == NULL) ? _("none") : 
                                                             get_title());
-   fprintf(the_bullfile, "%s\n", (get_location() == NULL) ? _("none") : 
-                                                            get_location());
+   fprintf(the_bullfile, "%s\n", (get_loc_str() == NULL) ? _("none") : 
+                                                            get_loc_str());
    fprintf(the_bullfile, "^%s^\n", (get_authorized() == NULL) ? "" : 
                                                             get_authorized());
    bull_flags->write_flag(the_bullfile);
@@ -625,7 +624,7 @@ void Bulletin::describe(Builder *the_builder)
    the_builder->send_bldr(_("&+GTitle:&* \t\t%s\n"), get_title());
    if (!bull_flags->get_flag(BULLFLAG_GLOBAL))
    {
-      the_builder->send_bldr(_("&+GLocation: \t&+m%s&*\n"), get_location());
+      the_builder->send_bldr(_("&+GLocation: \t&+m%s&*\n"), get_loc_str());
    }
    if (bull_flags->get_flag(BULLFLAG_LIMITED))
    {
@@ -649,7 +648,7 @@ void Bulletin::describe(Player *the_player)
    the_player->send_plr(_("&+GTitle:&* \t%s\n"), get_title());
    if (!bull_flags->get_flag(BULLFLAG_GLOBAL))
    {
-      the_player->send_plr(_("&+GLocation: \t&+m%s&*\n"), get_location());
+      the_player->send_plr(_("&+GLocation: \t&+m%s&*\n"), get_loc_str());
    }
    if (bull_flags->get_flag(BULLFLAG_LIMITED))
    {
@@ -681,9 +680,9 @@ int Bulletin::set_attrib(Builder *the_builder, Parse *the_parsed){
    if (!STRNCASECMP(the_parsed->get_target1(), _("location"), 
                                strlen(the_parsed->get_target1())))
    {
-      set_location(the_parsed->get_speech());
+      set_loc_str(the_parsed->get_speech());
       the_builder->send_bldr(_("Location on bulletin %s set to: %s\n"), 
-                                           get_name(), get_location());
+                                           get_name(), get_loc_str());
       set_modified(1);
       return 1;
    }
@@ -788,7 +787,7 @@ int Bulletin::copy_object(Entity *copy_obj)
 
    /****** set up bulletin attributes ******/
    set_title(copy_from->get_title());
-   set_location(copy_from->get_location());
+   set_loc_str(copy_from->get_loc_str());
    set_authorized(copy_from->get_authorized());
 
    return 1;
@@ -1255,7 +1254,7 @@ int bulletin_command_handler(MudObject *the_obj, char *the_input)
       new_bull->set_date();
       the_player->send_plr(_("&+gAuthor: &*%s\n"), new_bull->get_author());
 
-      prompt = new_Strings(_("&+gSubject:&* "));
+      prompt = new Strings(_("&+gSubject:&* "));
 
       /* get the subject from the user */
       tmp_handler->push_input_handler(bulletin_get_subject, 
