@@ -63,7 +63,7 @@ ChatLine::ChatLine(char *chatline_name)
 
    modified = 0;
    obj_type = OBJ_TYPE_CHATLINE;
-   line_flags = new_Flags(1);
+   line_flags = new Flags(1);
 }
 
 
@@ -78,7 +78,7 @@ ChatLine::ChatLine(char *chatline_name)
 
 ChatLine::~ChatLine(void)
 {
-   delete_Flags(line_flags);
+   delete line_flags;
 }
 
 
@@ -228,124 +228,125 @@ char *ChatLine::get_border(void)
 
 int ChatLine::execute_chat(Parse *the_parsed, MudObject *the_user)
 {
-   Strings    formatted;
-   Strings    tmp_lead_in;
-   Strings    holder;
-   Strings    auth_chatlines;
-   Flags      *tmp_lineflags;
-   Flags      *tmp_adminflags;
-   int        the_num = 0;
-   Player     *the_player = NULL;
-   Builder    *the_builder = NULL;
-   Player     *player_list;
-   Builder    *builder_list;
-
-   tmp_lineflags = get_lineflags();
-
-   if (the_user->get_type() == OBJ_TYPE_PLAYER)
-   {
-     the_player = (Player *) the_user;
-
-      auth_chatlines = the_player->get_chatlines();
-      if (!auth_chatlines.find_in_str(get_name()))
-      {
-        the_player->send_plr(_("You are not authorized to use this chat line.\n"));
+    Strings    formatted;
+    Strings    tmp_lead_in;
+    Strings    holder;
+    Strings    auth_chatlines;
+    Flags      *tmp_lineflags;
+    Flags      *tmp_adminflags;
+    int        the_num = 0;
+    Player     *the_player = NULL;
+    Builder    *the_builder = NULL;
+    Player     *player_list;
+    Builder    *builder_list;
+    
+    tmp_lineflags = get_lineflags();
+    
+    if (the_user->get_type() == OBJ_TYPE_PLAYER)
+    {
+        the_player = (Player *) the_user;
+        
+        auth_chatlines = the_player->get_chatlines();
+        if (!auth_chatlines.find_in_str(get_name()))
+        {
+            the_player->send_plr(_("You are not authorized to use this chat line.\n"));
+            return -1;
+        }
+        
+    }
+    else
+    {
+        the_builder = (Builder *) the_user;
+    }
+    
+    /* modification added 3/12/01 JH */
+    /* if there is nothing after chat, send a message to the player */
+    if ((the_parsed->get_speech() == NULL) || (strlen(the_parsed->get_speech()) <= 0))
+    {
+        the_player->send_plr(_("Format: chat <phrase>\n"));
         return -1;
-      }
-
-   }
-   else
-   {
-     the_builder = (Builder *) the_user;
-   }
-
-   /* modification added 3/12/01 JH */
-   /* if there is nothing after chat, send a message to the player */
-   if ((the_parsed->get_speech() == NULL)||
-        (strlen(the_parsed->get_speech()) <= 0))
-   {
-      the_player->send_plr(_("Format: chat <phrase>\n"));
-      return -1;
-   }
+    }
     /* end modification */
-
-   tmp_lead_in.format_for_actions(get_lead_in_actor(), the_user, NULL);
-   if (get_border() != NULL)
-      tmp_lead_in.str_cat(get_border());
-   if (get_text_color() != NULL)
-      tmp_lead_in.str_cat(get_text_color());
-
-   formatted.format_for_comm(the_parsed->get_speech(), tmp_lead_in.cstr_len(),
-                                                   the_config.max_line_len);
-
-   if (the_player != NULL)
-      the_player->send_plr("%s%s%s&*\n", tmp_lead_in.str_show(), 
-			formatted.str_show(), (get_border() == NULL) ? "" : 
-                                               get_border());
-   else
-      the_builder->send_bldr("%s%s%s&*\n", tmp_lead_in.str_show(), 
-			formatted.str_show(), (get_border() == NULL) ? "" : 
-                                               get_border());
-
-
-   tmp_lead_in.format_for_actions(get_lead_in_crowd(), the_user, NULL);
-   if (get_border() != NULL)
-      tmp_lead_in.str_cat(get_border());
-   if (get_text_color() != NULL)
-      tmp_lead_in.str_cat(get_text_color());
-   if (tmp_lineflags->get_flag(LINEFLAG_MESSAGEBEEP))
-      tmp_lead_in.str_cat("\a");
-
-   formatted.format_for_comm(the_parsed->get_speech(), tmp_lead_in.cstr_len(),
-                                                   the_config.max_line_len);
-
-   holder.sprintf("%s%s%s&*\n", tmp_lead_in.str_show(), 
-			formatted.str_show(), (get_border() == NULL) ? "" : 
-                                               get_border());
-
-   /* now we have to figure out who this should go to */
-   if (the_player != NULL)
-   {
-     player_list = mainstruct->get_first_player();
-     while (player_list != NULL)
-     {
-        tmp_adminflags = player_list->get_admflags();
-        auth_chatlines.truncate(0);
-        auth_chatlines = player_list->get_chatlines();
-        if ((player_list != the_player) && 
-            ((tmp_lineflags->get_flag(LINEFLAG_SENDALL)) ||
-             ((tmp_lineflags->get_flag(LINEFLAG_SENDBUILDER)) &&
-	      (tmp_adminflags->get_flag(ADMINFLAG_BUILDER))) ||
-             ((tmp_lineflags->get_flag(LINEFLAG_SENDADMIN)) &&
-	      (tmp_adminflags->get_flag(ADMINFLAG_ADMINISTRATOR))) ||
-             ((tmp_lineflags->get_flag(LINEFLAG_SENDBUILDER)) &&
-	      (tmp_adminflags->get_flag(ADMINFLAG_BUILDER))) ||
-             ((tmp_lineflags->get_flag(LINEFLAG_SENDHASCHAT)) &&
-              (auth_chatlines.find_in_str(get_name())))))
-	  player_list->send_plr("%s", holder.str_show());
-        player_list = player_list->get_next_player();
-     }
-   }
-   else
-   {
-     builder_list = mainstruct->get_first_builder();
-     while (builder_list != NULL)
-     {
-        tmp_adminflags = builder_list->get_adminflags();
-        if ((builder_list != the_builder) && 
-            ((tmp_lineflags->get_flag(LINEFLAG_SENDALL)) ||
-             ((tmp_lineflags->get_flag(LINEFLAG_SENDBUILDER)) &&
-	      (tmp_adminflags->get_flag(ADMINFLAG_BUILDER))) ||
-             ((tmp_lineflags->get_flag(LINEFLAG_SENDADMIN)) &&
-	      (tmp_adminflags->get_flag(ADMINFLAG_ADMINISTRATOR))) ||
-             ((tmp_lineflags->get_flag(LINEFLAG_SENDBUILDER)) &&
-	      (tmp_adminflags->get_flag(ADMINFLAG_BUILDER)))))
-	  builder_list->send_bldr("%s", holder.str_show());
-
-        builder_list = builder_list->get_next_builder();
-     }
-   }
-   return 1;
+    
+    tmp_lead_in.format_for_actions(get_lead_in_actor(), the_user, NULL);
+    
+    if (get_border() != NULL)
+        tmp_lead_in.str_cat(get_border());
+    if (get_text_color() != NULL)
+        tmp_lead_in.str_cat(get_text_color());
+    
+    formatted.format_for_comm(the_parsed->get_speech(), tmp_lead_in.cstr_len(),the_config.max_line_len);
+    
+    if (the_player != NULL)
+        the_player->send_plr("%s%s%s&*\n", tmp_lead_in.str_show(), 
+        formatted.str_show(), (get_border() == NULL) ? "" : 
+        get_border());
+    else
+        the_builder->send_bldr("%s%s%s&*\n", tmp_lead_in.str_show(), 
+        formatted.str_show(), (get_border() == NULL) ? "" : 
+        get_border());
+    
+    tmp_lead_in.format_for_actions(get_lead_in_crowd(), the_user, NULL);
+    
+    if (get_border() != NULL)
+        tmp_lead_in.str_cat(get_border());
+    if (get_text_color() != NULL)
+        tmp_lead_in.str_cat(get_text_color());
+    if (tmp_lineflags->get_flag(LINEFLAG_MESSAGEBEEP))
+        tmp_lead_in.str_cat("\a");
+    
+    formatted.format_for_comm(the_parsed->get_speech(), tmp_lead_in.cstr_len(), the_config.max_line_len);
+    
+    holder.sprintf("%s%s%s&*\n", tmp_lead_in.str_show(), 
+        formatted.str_show(), (get_border() == NULL) ? "" : 
+        get_border());
+    
+    /* now we have to figure out who this should go to */
+    if (the_player != NULL)
+    {
+        player_list = mainstruct->get_first_player();
+        while (player_list != NULL)
+        {
+            tmp_adminflags = player_list->get_admflags();
+            auth_chatlines.truncate(0);
+            auth_chatlines = player_list->get_chatlines();
+            if ((player_list != the_player) 
+            &&  ((tmp_lineflags->get_flag(LINEFLAG_SENDALL)) 
+            ||  ((tmp_lineflags->get_flag(LINEFLAG_SENDBUILDER)) 
+            &&  (tmp_adminflags->get_flag(ADMINFLAG_BUILDER))) 
+            ||  ((tmp_lineflags->get_flag(LINEFLAG_SENDADMIN)) 
+            &&  (tmp_adminflags->get_flag(ADMINFLAG_ADMINISTRATOR))) 
+            ||  ((tmp_lineflags->get_flag(LINEFLAG_SENDBUILDER))
+            &&  (tmp_adminflags->get_flag(ADMINFLAG_BUILDER))) 
+            ||  ((tmp_lineflags->get_flag(LINEFLAG_SENDHASCHAT)) 
+            &&  (auth_chatlines.find_in_str(get_name())))))
+                player_list->send_plr("%s", holder.str_show());
+            player_list = player_list->get_next_player();
+        }
+    }
+    else
+    {
+        builder_list = mainstruct->get_first_builder();
+        while (builder_list != NULL)
+        {
+            tmp_adminflags = builder_list->get_adminflags();
+            if (builder_list != the_builder)
+            {
+                printf("one to send to\n");
+                if ((tmp_lineflags->get_flag(LINEFLAG_SENDHASCHAT)) ||
+                    ((tmp_lineflags->get_flag(LINEFLAG_SENDBUILDER)) &&
+                    (tmp_adminflags->get_flag(ADMINFLAG_BUILDER))) ||
+                    ((tmp_lineflags->get_flag(LINEFLAG_SENDADMIN)) &&
+                    (tmp_adminflags->get_flag(ADMINFLAG_ADMINISTRATOR))))
+                {
+                    printf("sending: %s\n", holder.str_show());
+                    builder_list->send_bldr("%s", holder.str_show());
+                }
+            }
+            builder_list = builder_list->get_next_builder();
+        }
+    }
+    return 1;
 }
 
 
@@ -360,84 +361,79 @@ int ChatLine::execute_chat(Parse *the_parsed, MudObject *the_user)
 
 int ChatLine::load_chatline(FILE *the_file, ErrLog *error_log, int is_builder)
 {
-   token_record *the_token;
-   Flags        *tmp_lineflags;
-   Strings      holder;
-
-   if (is_builder)
-   {
-       the_token = get_token(the_file,'\0');
-
-       if (the_token->token_type != T_NUMERICAL)
-       {
-	 error_log->invalid_header("chatlines", "load_chatline");
-         return -1;
-       }
-       set_modified(atoi(the_token->the_string));
-   }
-
-   /* get the next item, it should be a '^', if not, raise error */
-   the_token = get_token(the_file, '\0');
-   if (the_token->token_type != T_CARROT)
-   {
-     error_log->invalid_attr_format(get_name(), "chatlines", _("lead_in_actor"), 
-				    "load_chatline");
-     return -1;
-   }
-
-   /* get the lead_in_actor of this chatline */
-   the_token = get_token(the_file, '^');
-   set_lead_in_actor(the_token->the_string);   
-
-   /* get the next item, it should be a '^', if not, raise error */
-   the_token = get_token(the_file, '\0');
-   if (the_token->token_type != T_CARROT)
-   {
-     error_log->invalid_attr_format(get_name(), "chatlines", _("lead_in_crowd"), 
-				    "load_chatline");
-     return -1;
-   }
-
-   /* get the lead_in_crowd of this chatline */
-   the_token = get_token(the_file, '^');
-   set_lead_in_crowd(the_token->the_string);   
-
-   /* get the next item, it should be a '^', if not, raise error */
-   the_token = get_token(the_file, '\0');
-   if (the_token->token_type != T_CARROT)
-   {
-     error_log->invalid_attr_format(get_name(), "chatlines", _("text_color"), 
-				    "load_chatline");
-     return -1;
-   }
-
-   /* get the text_color of this chatline */
-   the_token = get_token(the_file, '^');
-   set_text_color(the_token->the_string);   
- 
-   /* get the next item, it should be a '^', if not, raise error */
-   the_token = get_token(the_file, '\0');
-   if (the_token->token_type != T_CARROT)
-   {
-     error_log->invalid_attr_format(get_name(), "chatlines", _("border"), 
-				    "load_chatline");
-     return -1;
-   }
-
-   /* get the border of this chatline */
-   the_token = get_token(the_file, '^');
-   set_border(the_token->the_string);   
- 
-   /* read in the line flags */
-   tmp_lineflags = get_lineflags();
-   if (tmp_lineflags->read_flags(the_file, error_log) <= 0)
-   {
-     error_log->invalid_attr_format(get_name(), "chatlines", _("lineflags"), 
-				    "load_chatline");
-     return -1;
-   }
-
-   return 1;
+    token_record *the_token;
+    Flags        *tmp_lineflags;
+    Strings      holder;
+    
+    if (is_builder)
+    {
+        the_token = get_token(the_file,'\0');
+        
+        if (the_token->token_type != T_NUMERICAL)
+        {
+            error_log->invalid_header("chatlines", "load_chatline");
+            return -1;
+        }
+        set_modified(atoi(the_token->the_string));
+    }
+    
+    /* get the next item, it should be a '^', if not, raise error */
+    the_token = get_token(the_file, '\0');
+    if (the_token->token_type != T_CARROT)
+    {
+        error_log->invalid_attr_format(get_name(), "chatlines", _("lead_in_actor"), "load_chatline");
+        return -1;
+    }
+    
+    /* get the lead_in_actor of this chatline */
+    the_token = get_token(the_file, '^');
+    set_lead_in_actor(the_token->the_string);   
+    
+    /* get the next item, it should be a '^', if not, raise error */
+    the_token = get_token(the_file, '\0');
+    if (the_token->token_type != T_CARROT)
+    {
+        error_log->invalid_attr_format(get_name(), "chatlines", _("lead_in_crowd"), "load_chatline");
+        return -1;
+    }
+    
+    /* get the lead_in_crowd of this chatline */
+    the_token = get_token(the_file, '^');
+    set_lead_in_crowd(the_token->the_string);   
+    
+    /* get the next item, it should be a '^', if not, raise error */
+    the_token = get_token(the_file, '\0');
+    if (the_token->token_type != T_CARROT)
+    {
+        error_log->invalid_attr_format(get_name(), "chatlines", _("text_color"), "load_chatline");
+        return -1;
+    }
+    
+    /* get the text_color of this chatline */
+    the_token = get_token(the_file, '^');
+    set_text_color(the_token->the_string);   
+    
+    /* get the next item, it should be a '^', if not, raise error */
+    the_token = get_token(the_file, '\0');
+    if (the_token->token_type != T_CARROT)
+    {
+        error_log->invalid_attr_format(get_name(), "chatlines", _("border"), "load_chatline");
+        return -1;
+    }
+    
+    /* get the border of this chatline */
+    the_token = get_token(the_file, '^');
+    set_border(the_token->the_string);   
+    
+    /* read in the line flags */
+    tmp_lineflags = get_lineflags();
+    if (tmp_lineflags->read_flags(the_file, error_log) <= 0)
+    {
+        error_log->invalid_attr_format(get_name(), "chatlines", _("lineflags"), "load_chatline");
+        return -1;
+    }
+    
+    return 1;
 }
 
 
