@@ -39,6 +39,7 @@
 #include "lexer.h"
 #include "newfuncts.h"
 #include "global.h"
+#include "linkedlist.h"
 
 /***********************************************************************
  ** ~Code (destructor) - destroys the code
@@ -51,8 +52,6 @@
 
 Code::~Code()
 {
-   delete_param_list(pass_list);
-   delete_param_list(param_list);
 }
 
 
@@ -71,8 +70,6 @@ Code::Code(char *the_funct)
 
    valid = 1;
    the_mudcode = NULL;
-   param_list = NULL;
-   pass_list = NULL;
    next_code = NULL;
 
    /* find the appropriate function */
@@ -91,6 +88,9 @@ Code::Code(char *the_funct)
       valid = 0;
       return;
    }
+
+   param_list.set_del_data();
+   pass_list.set_del_data();
 }
 
 
@@ -107,8 +107,6 @@ Code::Code(Spec_Func the_funct)
 {
    valid = 1;
    the_mudcode = NULL;
-   param_list = NULL;
-   pass_list = NULL;
    next_code = NULL;
 
    
@@ -120,6 +118,9 @@ Code::Code(Spec_Func the_funct)
       return;
    }
 
+   param_list.set_del_data();
+   pass_list.set_del_data();
+
 }
 
 
@@ -180,25 +181,10 @@ int Code::set_next_code(Code *the_code)
 
 int Code::add_param(params *the_param)
 {
-   params *tmp_param;
-
    if (the_param == NULL)
-      return -1;
-   
-   the_param->next_param = NULL;
-   if (param_list == NULL)
-   {
-      param_list = the_param;
-      return 1;
-   }   
- 
-   tmp_param = param_list;
-   while (tmp_param->next_param != NULL)
-   {
-      tmp_param = tmp_param->next_param;
-   }
+     fault("Attempt to add null parameter.\n");
 
-   tmp_param->next_param = the_param;
+   param_list.add_tail_entry(the_param);
    return 1;
 }
 
@@ -214,70 +200,8 @@ int Code::add_param(params *the_param)
 
 int Code::add_pass_param(params *the_param)
 {
-   params *tmp_param;
-
-   if (the_param == NULL)
-      return -1;
-   
-   the_param->next_param = NULL;
-   if (pass_list == NULL)
-   {
-      pass_list = the_param;
-      return 1;
-   }   
- 
-   tmp_param = pass_list;
-   while (tmp_param->next_param != NULL)
-   {
-      tmp_param = tmp_param->next_param;
-   }
-
-   tmp_param->next_param = the_param;
-   return 1;
-}
-
-
-/***********************************************************************
- ** delete_param_list - deletes all the parameters from the list
- **
- ** Parameters: the_list - the list to delete
- **
- ** Returns: -1 if failed, 1 if good
- **
- ***********************************************************************/
-
-int Code::delete_param_list(params *the_list)
-{
-   params *tmp_list;
-
-   tmp_list = the_list;
-   while (tmp_list != NULL)
-   {
-      switch(tmp_list->param_type)
-      {
-         case VAR_TYPE_STRING:
-         case VAR_TYPE_OBJNAME:
-         case VAR_TYPE_VAR:
-            delete_Strings(tmp_list->the_param.a_string);
-            break;
-
-         case VAR_TYPE_INT:
-            delete_long(tmp_list->the_param.an_int);
-            break;
-
-         case VAR_TYPE_CODE:
-            delete_Code(tmp_list->the_param.a_code);
-            break;
-
-         default:
-            printf("error, unrecognized param type in code, not freed.\n");
-            break;
-      }
-      the_list = tmp_list->next_param;
-      delete_params(tmp_list);
-      tmp_list = the_list;
-   }
-   return 1;   
+  pass_list.add_tail_entry(the_param);
+  return 1;
 }
 
 
@@ -296,17 +220,20 @@ params *Code::get_param(int the_num)
    int count = 1;
    params *tmp_list;
 
-   tmp_list = param_list;
+   param_list.push_current();
+   tmp_list = param_list.get_first();
 
    while (tmp_list != NULL)
    {
       if (count == the_num)
       {
-         return tmp_list;
+	param_list.pop_current();
+	return tmp_list;
       }
-      tmp_list = tmp_list->next_param;
+      tmp_list = param_list.get_next();
       count++;
    }
+   param_list.pop_current();
    return NULL;
 }
 
@@ -321,7 +248,7 @@ params *Code::get_param(int the_num)
  **
  ***********************************************************************/
    
-params *Code::execute_command(Specials *the_special, Player *the_player, 
+params *Code::execute_command(Specials *the_special, Individual *the_user, 
 	in_params *player_params, int *the_results, special_env *environment)
 {
    Code   *code_holder;
@@ -334,12 +261,14 @@ params *Code::execute_command(Specials *the_special, Player *the_player,
       return NULL;
    }
 
-   delete_param_list(pass_list);
-   pass_list = NULL;
+   pass_list.clr_list();
+
+   param_list.push_current();
+
    /* go through the parameter list executing them and getting what they
       return so we can replace the code parameters in the parameter list
       with the code's resulting parameters */
-   cur_param = param_list;
+   cur_param = param_list.get_first();
 
    while (cur_param != NULL)
    {
@@ -347,85 +276,85 @@ params *Code::execute_command(Specials *the_special, Player *the_player,
       if (cur_param->param_type == VAR_TYPE_CODE)
       {
          params *new_param;
-
+	 
          code_holder = cur_param->the_param.a_code;
-         new_param = code_holder->execute_command(the_special, the_player, 
-                          player_params, the_results, environment);
-
+         new_param = code_holder->execute_command(the_special, the_user, 
+	   				  player_params, the_results, environment);
+	 
          add_pass_param(new_param);
 
       }
       else if (cur_param->param_type == VAR_TYPE_VAR)
       {
-         params *new_param;
-         vars *tmp_param;
-
-         code_holder = cur_param->the_param.a_code;
-         tmp_param = 
-             get_var(environment, cur_param->the_param.a_string->str_show());
-         if ((tmp_param == NULL) || (tmp_param->vartype == 0))
-	 {
-            holder.sprintf("Variable '%s' used as parameter before assigned "
-                "anything in special '%s'.\n", 
-             cur_param->the_param.a_string->str_show(), the_special->get_name());
+	     params *new_param;
+	     vars *tmp_param;
+	
+	     code_holder = cur_param->the_param.a_code;
+	     tmp_param = 
+	        get_var(environment, cur_param->the_param.a_string->str_show());
+	     if ((tmp_param == NULL) || (tmp_param->vartype == 0))
+		 {
+	        holder.sprintf("Variable '%s' used as parameter before assigned "
+			    "anything in special '%s'.\n", 
+		    cur_param->the_param.a_string->str_show(), the_special->get_name());
                
             mainstruct->log_error(holder.str_show(), "execute_command");
-            *the_results = 0;
-            return NULL;
-	 }
+	        *the_results = 0;
+	        return NULL;
+		 }
 
-         new_param = new_params();
-         new_param->param_type = tmp_param->vartype;
-         switch(tmp_param->vartype)
-	 {
-	    case VAR_TYPE_STRING:
-            case VAR_TYPE_OBJNAME:
-               new_param->the_param.a_string = 
-                     new_Strings(tmp_param->the_ptr.a_string->str_show());
-               break;
-
-	    case VAR_TYPE_INT:
-               new_param->the_param.an_int = new_long();
-               *(new_param->the_param.an_int) = 
-                                        *(tmp_param->the_ptr.an_int);
-               break;
-
-            default:
-               break;
-         }
+	     new_param = new params;
+	     new_param->param_type = tmp_param->vartype;
+	     switch(tmp_param->vartype)
+		 {
+	     case VAR_TYPE_STRING:
+	     case VAR_TYPE_OBJNAME:
+	        new_param->the_param.a_string = 
+                     new Strings(tmp_param->the_ptr.a_string->str_show());
+	        break;
+	  
+	     case VAR_TYPE_INT:
+	        new_param->the_param.an_int = new long;
+	        *(new_param->the_param.an_int) = 
+	        *(tmp_param->the_ptr.an_int);
+	        break;
+	  
+	     default:
+	        break;
+		 }
     
-         add_pass_param(new_param);
+	     add_pass_param(new_param);
 
       }
       else
       {
-         new_param = new_params();
+         new_param = new params;
          switch(cur_param->param_type)
-	 {
-	    case VAR_TYPE_STRING:
-            case VAR_TYPE_OBJNAME:
-	    case VAR_TYPE_VAR:
+		 {
+	     case VAR_TYPE_STRING:
+         case VAR_TYPE_OBJNAME:
+	     case VAR_TYPE_VAR:
                new_param->the_param.a_string = 
-                     new_Strings(cur_param->the_param.a_string->str_show());
+                     new Strings(cur_param->the_param.a_string->str_show());
                break;
 
-	    case VAR_TYPE_INT:
-               new_param->the_param.an_int = new_long();
+	     case VAR_TYPE_INT:
+               new_param->the_param.an_int = new long;
                *(new_param->the_param.an_int) = 
                                         *(cur_param->the_param.an_int);
                break;
 
-            default:
+         default:
                break;
          }
          new_param->param_type = cur_param->param_type;
          add_pass_param(new_param);
       }
-      cur_param = cur_param->next_param;
+      cur_param = param_list.get_next();
    }
 
    /* execute the code, returning the parameter */
-   return the_mudcode(pass_list, the_special, the_player, player_params, 
+   return the_mudcode(&pass_list, the_special, the_user, player_params, 
                                                   environment, the_results);
 }
 
@@ -487,24 +416,24 @@ int Code::load_from_file(FILE *the_file, ErrLog *the_log, int the_format)
             the_token = get_token(the_file, '\"');
 
             if (strlen(the_token->the_string) == 0)
-	    {
+			{
                the_log->log_err("Null string passed into code as parameter.",
                                             "load_from_file"); 
                return -1;
             }
-            param_holder = new_params();
+            param_holder = new params;
             param_holder->param_type = VAR_TYPE_STRING;
             param_holder->the_param.a_string = 
-                           new_Strings(the_token->the_string);
+                           new Strings(the_token->the_string);
 
             read_ptr = param_holder->the_param.a_string->str_show();
             write_ptr = read_ptr;
 
             while (*read_ptr)
-	    {
+			{
                if ((*read_ptr == '\\') && 
                    ((*(read_ptr+1)) && (*(read_ptr + 1) == 'n')))
-	       {
+			   {
                   *write_ptr = '\n';
                   write_ptr++;
                   read_ptr += 2;
@@ -525,22 +454,22 @@ int Code::load_from_file(FILE *the_file, ErrLog *the_log, int the_format)
             the_token = get_token(the_file, '\0');
 
             if (ident_name.num_char('@') > 0)
-	    {
-               param_holder = new_params();
+			{
+               param_holder = new params;
                param_holder->param_type = VAR_TYPE_OBJNAME;
                param_holder->the_param.a_string = 
-                                      new_Strings(ident_name.str_show());
+                                      new Strings(ident_name.str_show());
             }
             else if (the_token->token_type == T_LPAREN)
-	    {
-               code_holder = new_Code(ident_name.str_show());
+			{
+               code_holder = new Code(ident_name.str_show());
 
                if (!code_holder->check_valid())
                {
                   holder.sprintf("Unrecognized function '%s' as parameter", 
                                                     ident_name.str_show());
                   the_log->log_err(holder.str_show(), "load_from_file");
-                  delete_Code(code_holder);
+                  delete code_holder;
                   return -1;
                }
 
@@ -549,10 +478,10 @@ int Code::load_from_file(FILE *the_file, ErrLog *the_log, int the_format)
                   holder.sprintf("Error in function '%s' as parameter", 
                                                      ident_name.str_show());
                   the_log->log_err(holder.str_show(), "load_from_file");
-                  delete_Code(code_holder);
+                  delete code_holder;
                   return -1;
                }
-               param_holder = new_params();
+               param_holder = new params;
                param_holder->param_type = VAR_TYPE_CODE;
                int_holder = atoi(the_token->the_string);
                param_holder->the_param.a_code = code_holder;
@@ -562,18 +491,18 @@ int Code::load_from_file(FILE *the_file, ErrLog *the_log, int the_format)
             else if ((the_token->token_type == T_COMMA) ||
                      (the_token->token_type == T_RPAREN))
 	    {
-               param_holder = new_params();
+               param_holder = new params;
                param_holder->param_type = VAR_TYPE_VAR;
-               param_holder->the_param.a_string = new_Strings(
+               param_holder->the_param.a_string = new Strings(
                                                        ident_name.str_show());    
 	    }
             break;
 
 	 case T_NUMERICAL:
-            param_holder = new_params();
+            param_holder = new params;
             param_holder->param_type = VAR_TYPE_INT;
             int_holder = atoi(the_token->the_string);
-            param_holder->the_param.an_int = new_long();
+            param_holder->the_param.an_int = new long;
             *(param_holder->the_param.an_int) = int_holder;
             the_token = get_token(the_file, '\0');
             break;
@@ -595,13 +524,14 @@ int Code::load_from_file(FILE *the_file, ErrLog *the_log, int the_format)
       {
          holder.sprintf("Unexpected '%s' found", the_token->the_string); 
          the_log->log_err(holder.str_show(), "load_from_file (code)");
-         delete_params(param_holder);
+         delete param_holder;
          return -1;
       }
       if (the_token->token_type == T_COMMA)
          the_token = get_token(the_file, '\0');
 
-      add_param(param_holder);
+      if (param_holder != NULL)
+	     add_param(param_holder);
 
    } while (((the_format != FORMAT_EQ) && (the_token->token_type != T_RPAREN)) ||
         ((the_format == FORMAT_EQ) && (the_token->token_type != T_SEMICOLON)));
@@ -652,32 +582,32 @@ Spec_Func Code::get_funct_ptr(void)
 
 int Code::copy_code(Code *copy_from)
 {
-   param_list = copy_from->copy_param_list();
+   copy_from->copy_param_list_to(&param_list);
    return 1;
 }
 
 
 /***********************************************************************
- ** copy_param_list - copies the param list and passes the new list out
+ ** copy_param_list_to - copies the param list and passes the new list out
  **
- ** Parameters: None
+ ** Parameters: the_list - the list to copy the list of this object to
  **
  ** Returns: pointer to the newly created list if success
  **
  ***********************************************************************/
 
-params *Code::copy_param_list()
+LinkedList<params> *Code::copy_param_list_to(LinkedList<params> *the_list)
 {
    params *tmp_list;
-   params *new_list = NULL;
-   params *last_added = NULL;
    params *new_param;
 
-   tmp_list = param_list;
+   the_list->clr_list();
+
+   param_list.push_current();
+   tmp_list = param_list.get_first();
    while (tmp_list != NULL)
    {
-      new_param = new_params();
-      new_param->next_param = NULL;
+      new_param = new params;
       new_param->param_type = tmp_list->param_type;
       switch(tmp_list->param_type)
       {
@@ -685,16 +615,16 @@ params *Code::copy_param_list()
          case VAR_TYPE_OBJNAME:
          case VAR_TYPE_VAR:
             new_param->the_param.a_string = 
-                     new_Strings(tmp_list->the_param.a_string->str_show());
+                     new Strings(tmp_list->the_param.a_string->str_show());
             break;
          case VAR_TYPE_INT:
-            new_param->the_param.an_int = new_long();
+            new_param->the_param.an_int = new long;
             *(new_param->the_param.an_int) = *(tmp_list->the_param.an_int);
             break;
 
          case VAR_TYPE_CODE:
             new_param->the_param.a_code = 
-                new_Code(tmp_list->the_param.a_code->get_funct_ptr());
+                new Code(tmp_list->the_param.a_code->get_funct_ptr());
             new_param->the_param.a_code->copy_code(tmp_list->the_param.a_code);
             break;
 
@@ -704,20 +634,12 @@ params *Code::copy_param_list()
 
          default: return NULL;
       }
-      if (last_added == NULL)
-      {
-         new_list = new_param;
-         last_added = new_param;
-      }
-      else
-      {
-         last_added->next_param = new_param;
-         last_added = new_param;
-      }
 
-      tmp_list = tmp_list->next_param;
+      the_list->add_tail_entry(new_param);
+
+      tmp_list = param_list.get_next();
    }
-   return new_list;
+   return the_list;
 }
 
 
@@ -750,21 +672,10 @@ int Code::get_mem_size()
 int Code::get_mem_size_dynamic()
 {
    int  size = 0;
-   params *tmp_param;
 
-   tmp_param = param_list;
-   while (tmp_param != NULL)
-   {
-      size += sizeof(tmp_param);
-      tmp_param = tmp_param->next_param;
-   }
+   size += param_list.get_mem_size_dynamic();
+   size += pass_list.get_mem_size_dynamic();
 
-   tmp_param = pass_list;
-   while (tmp_param != NULL)
-   {
-      size += sizeof(tmp_param);
-      tmp_param = tmp_param->next_param;
-   }
    return size;   
 }
 
@@ -793,6 +704,53 @@ char *Code::get_var_name()
 { 
    return var_name.str_show();
 }
+
+/*********************************************************
+ ** Params class code
+ *********************************************************/
+
+/*********************************************************
+ * params (constructor) - initializes
+ *********************************************************/
+
+params::params()
+{
+
+}
+
+/*********************************************************
+ * ~params (destructor) - cleans up
+ *********************************************************/
+
+params::~params()
+{
+  switch(param_type)
+  {
+  case VAR_TYPE_STRING:
+  case VAR_TYPE_OBJNAME:
+  case VAR_TYPE_VAR:
+    delete the_param.a_string;
+    break;
+
+  case VAR_TYPE_INT:
+    delete the_param.an_int;
+    break;
+
+  case VAR_TYPE_CODE:
+    delete the_param.a_code;
+    break;
+
+  case VAR_TYPE_GOTO:
+    break;
+
+  default:
+    fault("Unexpected param type found when deleting params.\n");
+  }
+
+}
+
 #endif
 
 
+
+
