@@ -50,7 +50,7 @@
 
 Configs::Configs()
 {
-   conf_flags = new_Flags(1);
+   conf_flags = new Flags(1);
    init_configs();
 }
 
@@ -67,7 +67,7 @@ Configs::Configs()
 Configs::~Configs()
 {
 	if (conf_flags != NULL)
-		delete_Flags(conf_flags);
+		delete conf_flags;
 }
 
 
@@ -104,11 +104,10 @@ void Configs::init_configs()
    conf_flags->set_flag(CF_GAMEALLOW);
    conf_flags->set_flag(CF_LOGBOOT);
    conf_flags->set_flag(CF_LOOKUPHOSTS);
+   conf_flags->set_flag(CF_WIN32AUTOSTART);
 
    timezone = "U.S. Central";
    buildprompt = "&+cB&+C>&* ";
-   masteruser = "xxxxxxxx";
-   masterpasswd = "xxxxxxxx";
 
    secs_player_heal = 5;
    secs_mobile_heal = 30;
@@ -148,6 +147,7 @@ void Configs::init_configs()
    default_indweight = 180;
    default_indsize = 180;
    default_wimpy = 30;
+   default_mob_wimpy = 0;
    default_wisdom = 8;
    default_charisma = 8;
    secs_to_rot = 100;
@@ -188,6 +188,9 @@ int Configs::load_configs()
       if ((conf_file = xfopen(the_config.conffile_loc.str_show(), "r", 
                                                    "config_file")) == NULL)
       {
+#ifdef WIN32
+		  AfxMessageBox("Could not find aime.conf file at specified location\n");
+#endif
          printf("Could not find aime.conf file at specified location: %s\n", 
                                        the_config.conffile_loc.str_show());
          exit(0);
@@ -241,10 +244,18 @@ int Configs::load_configs()
 
          case T_IDENTIFIER:
             if (read_config(the_token->the_string, conf_file) <= 0)
+			{
+#ifdef WIN32
+			   AfxMessageBox("Error reading in config file.\n");
+#endif
                return -1;
+			}
             break;
 
          default:
+#ifdef WIN32
+		    AfxMessageBox("Invalid token found\n");
+#endif
             printf("Invalid token '%s' found in config file.\n", 
                                          the_token->the_string);
             xfclose(conf_file, "config_file");
@@ -542,6 +553,32 @@ int Configs::read_config(char *the_ident, FILE *the_file)
          return -1;
       } 
    }
+   else if (!STRCASECMP(the_ident, "crashsegfault"))
+   {
+      the_token = get_token(the_file, '\0');
+      if (!STRCASECMP(the_token->the_string, "yes"))
+         conf_flags->set_flag(CF_CRASHSEGFLT);
+      else if (!STRCASECMP(the_token->the_string, "no"))
+         conf_flags->clr_flag(CF_CRASHSEGFLT);
+      else
+      {
+         printf("Invalid format in config entry '%s'\n", the_ident);
+         return -1;
+      } 
+   }
+   else if (!STRCASECMP(the_ident, "crashothersignals"))
+   {
+      the_token = get_token(the_file, '\0');
+      if (!STRCASECMP(the_token->the_string, "yes"))
+         conf_flags->set_flag(CF_CRASHSIGNAL);
+      else if (!STRCASECMP(the_token->the_string, "no"))
+         conf_flags->clr_flag(CF_CRASHSIGNAL);
+      else
+      {
+         printf("Invalid format in config entry '%s'\n", the_ident);
+         return -1;
+      } 
+   }
    else if (!STRCASECMP(the_ident, "timezone"))
    {
       the_token = get_token(the_file, '\n');
@@ -564,7 +601,7 @@ int Configs::read_config(char *the_ident, FILE *the_file)
    else if (!STRCASECMP(the_ident, "masteruser"))
    {
       the_token = get_token(the_file, '\0');
-      masteruser = the_token->the_string;
+      //      masteruser = the_token->the_string;
    }
    else if (!STRCASECMP(the_ident, "masterpasswd"))
    {
@@ -576,7 +613,7 @@ int Configs::read_config(char *the_ident, FILE *the_file)
       }
 
       the_token = get_token(the_file, '\"');
-      masterpasswd = the_token->the_string;
+      //      masterpasswd = the_token->the_string;
    }
    else if (!STRCASECMP(the_ident, "autowiz"))
    {
@@ -786,6 +823,32 @@ int Configs::read_config(char *the_ident, FILE *the_file)
          return -1;
       } 
    }
+   else if (!STRCASECMP(the_ident, "win32autostart"))
+   {
+       the_token = get_token(the_file, '\0');
+       if (!STRCASECMP(the_token->the_string, "yes"))
+           conf_flags->set_flag(CF_WIN32AUTOSTART);
+       else if (!STRCASECMP(the_token->the_string, "no"))
+           conf_flags->clr_flag(CF_WIN32AUTOSTART);
+       else
+       {
+           printf("Invalid format in config entry '%s'\n", the_ident);
+           return -1;
+       }
+   }
+   else if (!STRCASECMP(the_ident, "permdeath"))
+   {
+      the_token = get_token(the_file, '\0');
+      if (!STRCASECMP(the_token->the_string, "yes"))
+         conf_flags->set_flag(CF_PERMDEATH);
+      else if (!STRCASECMP(the_token->the_string, "no"))
+         conf_flags->clr_flag(CF_PERMDEATH);
+      else
+      {
+         printf("Invalid format in config entry '%s'\n", the_ident);
+         return -1;
+      } 
+   }
    else if (!STRCASECMP(the_ident, "userslevelchain"))
    {
       the_token = get_token(the_file, '\0');
@@ -810,15 +873,11 @@ int Configs::read_config(char *the_ident, FILE *the_file)
    }   
    else if (!STRCASECMP(the_ident, "backuplocdesc"))
    {
-      the_token = get_token(the_file, '\0');
-      if (the_token->token_type != T_CARROT)
-      {
-         printf("Invalid format in config entry '%s'\n", the_ident);
+      temp_desc = read_desc_type(the_file, NULL, NULL);
+      if (temp_desc == NULL)
          return -1;
-      }
-
-      the_token = get_token(the_file, '^');
-      backup_locdesc = the_token->the_string;
+      backup_locdesc = temp_desc;
+      delete temp_desc;
    }
    else if (!STRCASECMP(the_ident, "entrylocname"))
    {
@@ -1022,8 +1081,8 @@ int Configs::read_config(char *the_ident, FILE *the_file)
       }
 
       default_wimpy = atoi(the_token->the_string);
-   }   
-   else if (!STRCASECMP(the_ident, "defaultwisdom"))
+   } 
+   else if (!STRCASECMP(the_ident, "defaultwimpy"))
    {
       the_token = get_token(the_file, '\0');
       if (the_token->token_type != T_NUMERICAL)
@@ -1032,7 +1091,18 @@ int Configs::read_config(char *the_ident, FILE *the_file)
          return -1;
       }
 
-      default_wisdom = atoi(the_token->the_string);
+      default_wimpy = atoi(the_token->the_string);
+   }   
+   else if (!STRCASECMP(the_ident, "defaultmobwimpy"))
+   {
+      the_token = get_token(the_file, '\0');
+      if (the_token->token_type != T_NUMERICAL)
+      {
+         printf("Invalid format in config entry '%s'\n", the_ident);
+         return -1;
+      }
+
+      default_mob_wimpy = atoi(the_token->the_string);
    }   
    else if (!STRCASECMP(the_ident, "defaultcharisma"))
    {
