@@ -6,7 +6,7 @@
  ** Reviewed through: version 0.14
  **
  **
- ** Copyright (C) 2000 George Noel (Slate), Ed Boraas
+ ** Copyright (C) 2001 George Noel (Slate), Ed Boraas
  **
  **   This program is free software; you can redistribute it and/or modify
  **   it under the terms of the GNU General Public License as
@@ -232,12 +232,7 @@ void Connection::flush()
    if ((FD_ISSET(socketfd,&write_fds)) && (!hold_buffers))
    {
 
-#if defined( AIME_WIN32 )
-      send(socketfd, final_string.str_show(), final_string.str_len(), 0);
-#else
       write(socketfd, final_string.str_show(), final_string.str_len());
-#endif // AIME_WIN32
-
       write_buffer.truncate(0);
       FD_CLR((unsigned int)socketfd,&write_fds);
    }
@@ -255,13 +250,13 @@ void Connection::flush()
  **          -1 if something went wrong with select
  **          -2 if the select had an exception
  **          -3 if we lost the player's link
+ **          -4 if something went wrong reading in the data
  **
  ***********************************************************************/
 
 int Connection::check_socket()
 {   int     numselected = 0;
     int     numread = 0;
-    char    input_buffer[MAX_COM_LEN+4];
     char    holder[MAX_COM_LEN];
     Strings *the_input;
     struct  timeval timeout, nulltime;
@@ -269,6 +264,7 @@ int Connection::check_socket()
     int     x;
     Strings tmpholder;
     Strings tmp_buffer;
+    char    input_buffer[MAX_COM_LEN+4];
 
 
     BZERO(input_buffer, MAX_COM_LEN);
@@ -300,133 +296,55 @@ int Connection::check_socket()
     }
     else if (FD_ISSET(socketfd,&read_fds))
     {
-       the_input = new_Strings();
        for (x=0; x<the_config.maxreadsperpoll; x++)
        {
           BZERO(input_buffer,MAX_COM_LEN+3);
 
-#if defined( AIME_WIN32 )
-          if ((numread = recv(socketfd, input_buffer, MAX_COM_LEN - 1, 0)) <= 0)
-#else
           if ((numread = read(socketfd, input_buffer, MAX_COM_LEN - 1)) <= 0)
-#endif // AIME_WIN32
+		  {
+	      
+	         /* since we have non-blocking set, if we read and nothing is
+		       there to read, we get this error, so return 0 */
 
-          {
-
-	     /* since we have non-blocking set, if we read and nothing is
-             there to read, we get this error, so return 0 */
-
-#if defined( AIME_WIN32 )
-        if( WSAGetLastError( ) == WSAEWOULDBLOCK )
-#else
-        if (errno == EAGAIN)
-#endif // AIME_WIN32
-
-	     {
-                break;
-             }
-
-             if (!lost_connection)
-	     {
-               if ((host_addr.str_show() == NULL) || (host_addr.str_len() <= 0))
-                  tmpholder.sprintf("Connection lost for %s\n",
+	          if (errno == EAGAIN)
+			  {
+	             break;
+			  }
+	    
+	          if (!lost_connection)
+			  {
+                 if ((host_addr.str_show() == NULL) || (host_addr.str_len() <= 0))
+                   tmpholder.sprintf("Connection lost for %s\n",
                                                         ip_addr.str_show());
-               else
-                  tmpholder.sprintf("Connection lost for host %s",
+                 else
+                   tmpholder.sprintf("Connection lost for host %s",
                                                        host_addr.str_show());
-               mainstruct->log_event(tmpholder.str_show());
+                 mainstruct->log_event(tmpholder.str_show());
 
-               lost_connection = time(0);
-               return -3;
-             }
-             else
-               return -4;
-          }
+                 lost_connection = time(0);
+                 return -3;
+			  } 
+              else
+                 return -4;
+		  }
           else if (numread == 0)
-             break;
+              break;
           else
-	  {
+		  {
              if (*input_buffer != '\0')
-             {
-                size_t i;
+			 {
+                if (fill_read_buffer(input_buffer) < 0)
+		           return -4;
+			 }
+		  } // read if
 
-                /* remove all wierd telnet function chars */
-#ifdef DEBUG_INPUT
-                printf("Packet: %s\n",input_buffer);
-                printf("Strlen: %d\n", strlen(input_buffer));
-#endif
-
-                for (i=0; i < strlen(input_buffer); i++)
-	        {
-                   if ((input_buffer[i] == '\n') || (input_buffer[i] == '\r'))
-		   {
-                      if ((input_buffer[i+1]) &&
-                              ((input_buffer[i+1] == '\n') ||
-                              (input_buffer[i+1] == '\r')))
-                         i++;
-                      holder[holder_count] = '\n';
-                      holder[holder_count+1] = '\0';
-
-                      if (partial_line.str_show() != NULL)
-		      {
-#ifdef DEBUG_INPUT
-                         printf("adding partial: %s\n",
-                                                    partial_line.str_show());
-#endif
-                         the_input->str_copy(partial_line.str_show());
-                         partial_line.truncate(0);
-                      }
-#ifdef DEBUG_INPUT
-                      printf("adding: %s\n", holder);
-#endif
-                      the_input->str_cat(holder);
-
-
-                      holder_count = -1;
-
-#ifdef DEBUG_INPUT
-                      printf("input is: %s\n", the_input->str_show());
-#endif
-                   }
-                   else if (input_buffer[i] > 1)
-		   {
-                      holder[holder_count] = input_buffer[i];
-                   }
-
-                   holder_count++;
-                }
-
-                if (holder_count != 0)
-	        {
-                   holder[holder_count] = '\0';
-                   partial_line.str_cat(holder);
-                   holder[0] = '\0';
-                   holder_count = 0;
-                }
-                else
-                   partial_line.truncate(0);
-
-                if (the_input->str_len() == 0)
-                   return 0;
-
-
-                read_buffer.str_cat(the_input->str_show());
-
-             }
-             the_input->truncate(0);	
-          } // read if
-
-       } // main for
+	   } // main for
        valid_input = true;
-       delete_Strings(the_input);
 
-       if (read_buffer.str_show() == NULL)
+       if (read_buffer.get_first() == NULL)
            return 0;
 
-#ifdef DEBUG_INPUT
-       printf("Input is: %s\n", read_buffer.str_show());
-#endif
-        return 1;
+       return 1;
    }
    else if (FD_ISSET(socketfd,&write_fds))
    {
@@ -446,7 +364,7 @@ int Connection::check_socket()
  **
  ***********************************************************************/
 
-Strings *Connection::get_input(int lines)
+Strings *Connection::get_input()
 {  Strings *the_input = NULL;
 
    if (!lost_link())
@@ -454,19 +372,19 @@ Strings *Connection::get_input(int lines)
 #ifdef DEBUG_INPUT
        printf("Reading input.\n");
 #endif
-       if (read_buffer.str_len() != 0)
-       {
-          the_input = new_Strings();
-          the_input->copy_lines(read_buffer.str_show(), lines);
-          read_buffer.del_lines(lines);
-          the_input->handle_backspaces();
-       }
-       if ((read_buffer.str_show() == NULL) ||
-            (read_buffer.str_len() == 0))
+
+       if ((the_input = read_buffer.get_first()) == NULL)
+	 return NULL;
+
+       read_buffer.reset_current();
+       read_buffer.del_cur_entry();
+
+       the_input->handle_backspaces();
+
+       if (read_buffer.get_first() == NULL)
        {
           valid_input = false;
           FD_CLR((unsigned int)socketfd,&read_fds);
-          read_buffer.truncate(0);
        }
 
        /* now reset the idle time */
@@ -915,16 +833,12 @@ int Connection::echo_off()
     {
       (char) IAC,
       (char) WILL,
-      (char) TELOPT_ECHO,
-      (char)  0,
+      (char) TELOPT_ECHO
    };
    flush();
 
-#if defined( AIME_WIN32 )
-   send(socketfd, the_string, sizeof(the_string), 0);
-#else
    write(socketfd, the_string,sizeof(the_string));
-#endif // AIME_WIN32
+   flush();
 
    return 1;
 }
@@ -948,16 +862,13 @@ int Connection::echo_on()
       (char) WONT,
       (char) TELOPT_ECHO,
       (char) TELOPT_NAOFFD,
-      (char) TELOPT_NAOCRD,
-      (char)  0,
+      (char) TELOPT_NAOCRD
    };
    flush();
 
-#if defined( AIME_WIN32 )
-   send(socketfd, the_string, sizeof(the_string), 0);
-#else
    write(socketfd, the_string, sizeof(the_string));
-#endif // AIME_WIN32
+
+   flush();
 
    return 1;
 }
@@ -1004,13 +915,9 @@ void Connection::set_color(int the_num)
 
 bool    Connection::has_input()
 {
-   if ((read_buffer.str_show() != NULL) && (read_buffer.str_len() == 0))
-      read_buffer.truncate(0);
-
-   if (read_buffer.str_show() == NULL)
-      return false;
-   else
-      return true;
+  if (read_buffer.get_first() != NULL)
+    return true;
+  return false;
 }
 
 
@@ -1359,6 +1266,79 @@ void Connection::set_valid()
   valid_socket = true;
 }
 
+
+/***********************************************************************
+ ** fill_read_buffer - fills up the read buffer with any input in the socket
+ **
+ ** Parameters: the_conn - the connection to check for
+ **
+ ** Returns: 1 for has it, 0 if not found
+ **
+ ***********************************************************************/
+
+int Connection::fill_read_buffer(char *input_buf)
+{
+  char copy_buffer[MAX_COM_LEN+4];
+  char *str_ptr = input_buf;
+  char *new_ptr = NULL;
+  int  counter = 0;
+  Strings *new_str = NULL;
+
+  /* remove all wierd telnet function chars */
+#ifdef DEBUG_INPUT
+  printf("Packet: %s\n", str_ptr);
+  printf("Strlen: %d\n", strlen(str_ptr));
+#endif
+
+  // Read the input buffer until we hit the end of it
+  while ((str_ptr) && (*str_ptr != '\0'))
+  {
+    // Set up a buffer to write valid chars to
+    bzero(copy_buffer, MAX_COM_LEN+4);
+    new_ptr = copy_buffer;
+
+    // Now search along the input for the length of the line
+    while ((str_ptr) && (*str_ptr != '\n') && (*str_ptr != '\0'))
+    {
+      // Skip this char if it is not an authorized char
+      if (!isalnum(*str_ptr) && !ispunct(*str_ptr) && (!isspace(*str_ptr)) &&
+	  (*str_ptr != '\b'))
+	str_ptr++;
+
+      // Else, it is an authorized char, copy it
+      else
+      {
+	*new_ptr = *str_ptr;
+	new_ptr++;
+	str_ptr++;
+      }
+    }
+
+    // Now we theoretically have the entire line, if the length is greater
+    // than zero, lets copy it to a buffer
+    if (strlen(copy_buffer) > 0)
+    {
+      // If we don't have a newline, add this to the partial buffer
+      if (*str_ptr != '\n')
+      {
+	partial_line.str_cat(copy_buffer);
+      }
+      else
+      {
+	new_str = new Strings(partial_line.str_show());
+	new_str->str_cat(copy_buffer);
+	partial_line.truncate(0);
+	new_str->remove_newline();
+	read_buffer.add_entry(new_str);
+	counter++;
+      }
+    }
+    if ((str_ptr) && (*str_ptr != '\0'))
+      str_ptr++;
+  }
+  return counter;
+}
+
 #endif
 
 
