@@ -44,6 +44,7 @@
 #include "memchk.h"
 #include "global.h"
 #include "newfuncts.h"
+#include "doorflags.h"
 
 /***********************************************************************
  ** Door (constructor) - creates the door
@@ -68,6 +69,8 @@ Door::Door(char *the_name, char *the_area)
 
    doorstate = 0;
    distance = 1;
+
+   doorflags = new Flags(2);
 }
 
 /***********************************************************************
@@ -81,6 +84,84 @@ Door::Door(char *the_name, char *the_area)
 
 Door::~Door()
 {
+   delete doorflags;
+}
+
+/***********************************************************************
+ ** get_doorflags - gets the door flags object
+ **
+ ** Parameters: Nothing
+ **
+ ** Returns: a pointer to the door flags structure
+ **
+ ***********************************************************************/
+
+Flags *Door::get_doorflags()
+{
+   return doorflags;
+}
+
+/***********************************************************************
+ ** set_attrib_doorflags - for set attribute, sets the doorflags for any
+ **                        item class object
+ **
+ ** Parameters: the_parsed - the parsed list from the user
+ **             the_builder - the builder doing this command
+ **
+ ** Returns: 1 for success, -1 for failure
+ **
+ ***********************************************************************/
+
+int Door::set_attrib_doorflags(Parse *the_parsed, Builder *the_builder)
+{
+   Flags *tmp_doorflags;
+   int flagnum;
+   Strings holder;
+
+   tmp_doorflags = get_doorflags();
+      
+   if (the_parsed->get_speech() == NULL)
+   {
+      the_builder->send_bldr("Set which door flag?\n");
+      return -1;
+   }
+   holder.assign_word(the_parsed->get_speech(), 1);
+     
+   if ((flagnum = 
+       tmp_doorflags->get_by_name(holder.str_show(), doorflagnames)) == -1)
+   {
+      the_builder->send_bldr("That is not a door flag.\n");
+      return -1;
+   }
+
+   holder.assign_word(the_parsed->get_speech(), 2);
+   if (holder.str_show() == NULL)
+   {
+      the_builder->send_bldr("Set that flag to what?\n"
+                                "Valid choices are: On or Off\n");
+      return -1;
+   }
+
+   if (holder.str_n_cmp("On", holder.str_len()))
+      tmp_doorflags->set_flag(flagnum);
+   else if (holder.str_n_cmp("Off", holder.str_len()))
+      tmp_doorflags->clr_flag(flagnum);
+   else
+   {
+      the_builder->send_bldr("That is not a valid setting.\n"
+                             "Valid choices are: On or Off\n");
+      return -1;
+   }
+   the_builder->send_bldr("Flag &+M%s&* has been set to: %s\n",
+       doorflagnames[flagnum], (tmp_doorflags->get_flag(flagnum)) ? 
+			     "&+GOn&*" : "&+ROff&*");
+
+   if (flagnum == DOORFLAG_ROPETIE)
+   {
+     set_door_state(DOOR_CLOSED);
+   }
+   return 1;
+ 
 }
 
 /***********************************************************************
@@ -119,6 +200,68 @@ char *Door::get_outside_loc(void)
 }
 
 
+/***********************************************************************
+ ** get_outside_loc_obj - gets the outside location for this door by object
+ ***********************************************************************/
+
+MudObject *Door::get_outside_loc_obj()
+{
+  Strings holder;
+  if (outside_loc.num_char('@') == 0)
+    holder.sprintf("%s@%s", outside_loc.str_show(), get_area());
+  else
+    holder = outside_loc.str_show();
+
+  return mainstruct->get_object(holder.str_show());
+}
+
+/***********************************************************************
+ ** which_loc - given a passed in location name and area, determines if
+ **             the location is 1, insideloc, 2, outsideloc, or 0, neither
+ **
+ ** Parameters: the_loc - name of the loc, may have area in it after the @
+ **             the_area - the name of the location's area, could be null if
+ **                        this is in the location string
+ **
+ ** Returns: 1 for insideloc, 2 for outsideloc, 0 for neither, -1 for failure
+ **
+ ***********************************************************************/
+
+int Door::which_loc(char *the_loc, char *the_area)
+{
+  char *areaptr;
+  Strings fullloc;
+  Strings testloc;
+
+  if (the_area != NULL)
+    areaptr = the_area;
+
+  fullloc = the_loc;
+  if (fullloc.find_letter('@') == -1)
+  {
+    if (the_area == NULL)
+      return -1;
+
+    fullloc.sprintf("%s@%s", the_loc, the_area); 
+  }
+
+  testloc = get_loc_str();
+  if (testloc.find_letter('@') == -1)
+    testloc.sprintf("%s@%s", get_loc_str(), get_area());
+  if (!testloc.str_cmp(fullloc.str_show()))
+  {
+    return 1;
+  }
+
+  testloc = get_outside_loc();
+  if (testloc.find_letter('@') == -1)
+    testloc.sprintf("%s@%s", get_outside_loc(), get_area());
+  if (!testloc.str_cmp(fullloc.str_show()))
+    return 2;
+
+  return 0;
+}
+
 /***********************************************************************
  ** set_rope_name - sets the rope name that is tied to this
  **
@@ -503,6 +646,7 @@ void Door::write_object(FILE *the_file, int build_format)
    fprintf(the_file, "%d\n", get_distance());
    fprintf(the_file, "%s\n", (get_rope_name() == NULL) ? "none" : 
                                                           get_rope_name());
+   doorflags->write_flag(the_file);
 }
 
 /***********************************************************************
@@ -524,7 +668,7 @@ void Door::describe(Builder *the_builder)
    the_builder->send_bldr("&+GSpecials: \t\t&+g%s&*\n", get_special_str());
    the_builder->send_bldr("&+GGuards: \t\t&+g%s&*\n", get_guards());
 
-   if (itemflags->get_flag(ITEMFLAG_ROPETIE))
+   if (doorflags->get_flag(DOORFLAG_ROPETIE))
       the_builder->send_bldr("&+GInitialState: \t\t&+W%s&*\n", 
                                        ropestatenames[get_door_state()]);
    else
@@ -547,7 +691,7 @@ void Door::describe(Builder *the_builder)
                               get_outside_brief(i));
    }
 
-   if (itemflags->get_flag(ITEMFLAG_ROPETIE))
+   if (doorflags->get_flag(DOORFLAG_ROPETIE))
    {
       the_builder->send_bldr("&+GDistance: \t\t&+W%d&*\n", get_distance());
       if (get_door_state() == DOOR_OPEN)
@@ -580,7 +724,7 @@ void Door::describe(Player *the_player)
    the_player->send_plr("&+GSpecials: \t\t&+g%s&*\n", get_special_str());
    the_player->send_plr("&+GGuards: \t\t&+g%s&*\n", get_guards());
 
-   if (itemflags->get_flag(ITEMFLAG_ROPETIE))
+   if (doorflags->get_flag(DOORFLAG_ROPETIE))
       the_player->send_plr("&+GInitialState: \t\t&+W%s&*\n", 
                                        ropestatenames[get_door_state()]);
    else
@@ -613,7 +757,7 @@ void Door::describe(Player *the_player)
                               get_outside_brief(i));
    }
 
-   if (itemflags->get_flag(ITEMFLAG_ROPETIE))
+   if (doorflags->get_flag(DOORFLAG_ROPETIE))
    {
       the_player->send_plr("&+GDistance: \t\t&+W%d&*\n", get_distance());
       if (get_door_state() == DOOR_OPEN)
@@ -644,8 +788,8 @@ int Door::set_attrib(Builder *the_builder, Parse *the_parsed){
    if (the_parsed->get_target1() == NULL)
    {   the_builder->send_bldr("You can set the following attributes "
              "on a door.\n"
-             "   title, altnames, itemflags, keynames, clones, desc,\n"
-             "   insidedesc, outsidedesc, insidebrief, outsidebrief\n"
+             "   title, altnames, itemflags, doorflags, keynames, clones,\n"
+	     "   desc, insidedesc, outsidedesc, insidebrief, outsidebrief\n"
              "   insideloc, outsideloc, guards, specials, ropename,\n"
              "   distance and initialstate\n");
        return -1;
@@ -665,6 +809,11 @@ int Door::set_attrib(Builder *the_builder, Parse *the_parsed){
    {
       return set_attrib_itemflags(the_parsed, the_builder);
    }
+   if (!STRNCASECMP(the_parsed->get_target1(), "doorflags",
+                               strlen(the_parsed->get_target1())))
+   {
+      return set_attrib_doorflags(the_parsed, the_builder);
+   }
    if (!STRNCASECMP(the_parsed->get_target1(), "keynames",
                                strlen(the_parsed->get_target1())))
    {
@@ -716,7 +865,7 @@ int Door::set_attrib(Builder *the_builder, Parse *the_parsed){
          the_builder->send_bldr("You need to specify a location to set to.\n");
          return -1;
       }
-      set_location(the_parsed->get_speech());
+      set_loc_str(the_parsed->get_speech());
       the_builder->send_bldr("Location on %s set to: %s\n", get_name(), 
                                                         get_location());
       set_modified(1);
@@ -746,10 +895,11 @@ int Door::set_attrib(Builder *the_builder, Parse *the_parsed){
          the_builder->send_bldr("You need to specify a state to set to.\n");
          return -1;
       }
+
       
       for (i=0; i<= DOOR_MAXSTATE; i++)
       {
-         if ((!itemflags->get_flag(ITEMFLAG_ROPETIE)) && 
+         if ((!doorflags->get_flag(DOORFLAG_ROPETIE)) && 
                 (!STRNCASECMP(statenames[i], the_parsed->get_speech(), 
                                     strlen(the_parsed->get_speech()))))
 	 {
@@ -761,7 +911,7 @@ int Door::set_attrib(Builder *the_builder, Parse *the_parsed){
             return 1;
 
          }
-         else if ((itemflags->get_flag(ITEMFLAG_ROPETIE)) && 
+         else if ((doorflags->get_flag(DOORFLAG_ROPETIE)) && 
                 (!STRNCASECMP(ropestatenames[i], the_parsed->get_speech(), 
                                     strlen(the_parsed->get_speech()))))
 	 {
@@ -780,7 +930,11 @@ int Door::set_attrib(Builder *the_builder, Parse *the_parsed){
 
          }
       }
-      the_builder->send_bldr("That is not a valid state.\n"
+      if (doorflags->get_flag(DOORFLAG_ROPETIE))
+	the_builder->send_bldr("That is not a valid state.\n"
+			       "Valid states are: Untied, Tied\n");
+      else
+	the_builder->send_bldr("That is not a valid state.\n"
                  "Valid states are: Open, Close, Locked, Magically Locked\n");
       return -1;
    }  
@@ -876,9 +1030,9 @@ int Door::set_attrib(Builder *the_builder, Parse *the_parsed){
    if (!STRNCASECMP(the_parsed->get_target1(), "ropename", 
                                strlen(the_parsed->get_target1())))
    {
-      if (!itemflags->get_flag(ITEMFLAG_ROPETIE))
+      if (!doorflags->get_flag(DOORFLAG_ROPETIE))
       {
-         the_builder->send_bldr("You must set the RopeTie itemflag "
+         the_builder->send_bldr("You must set the RopeTie doorflag "
                                 "first to set this attribute.\n");
          return -1;
       }
@@ -896,15 +1050,16 @@ int Door::set_attrib(Builder *the_builder, Parse *the_parsed){
       set_rope_name(the_parsed->get_speech());
       the_builder->send_bldr("RopeName on %s set to: %s\n", get_name(), 
                                                         get_rope_name());
+      set_door_state(DOOR_OPEN);
       set_modified(1);
       return 1;
    }
    if (!STRNCASECMP(the_parsed->get_target1(), "distance", 
                                strlen(the_parsed->get_target1())))
    {
-      if (!itemflags->get_flag(ITEMFLAG_ROPETIE))
+      if (!doorflags->get_flag(DOORFLAG_ROPETIE))
       {
-         the_builder->send_bldr("You must set the RopeTie itemflag "
+         the_builder->send_bldr("You must set the RopeTie doorflag "
                                 "first to set this attribute.\n");
          return -1;
       }
@@ -959,7 +1114,7 @@ char *Door::get_link(Location *the_location, int *return_val){
       return NULL;
    }
 
-   if ((doorstate != DOOR_OPEN) && (itemflags->get_flag(ITEMFLAG_ROPETIE)))
+   if ((doorstate != DOOR_OPEN) && (doorflags->get_flag(DOORFLAG_ROPETIE)))
    {
 
       /* if the rope is too short */
@@ -1078,7 +1233,8 @@ int Door::toggle_lock(char *keyname)
       *tmp_str = '\0';
    }
 
-   if ((keyname == NULL) || (!key_names.find_in_str(keyname)))
+   if ((keyname == NULL) || ((!key_names.find_in_str(keyname)) && 
+	       ((key_names.str_show() == NULL) || (!key_names.str_cmp("all")))))
       return 0;
 
    if (doorstate == 1)
@@ -1133,6 +1289,7 @@ int Door::copy_object(Entity *copy_obj)
    set_door_state(copy_from->get_door_state());   
    set_key_names(copy_from->get_key_names());
 
+   doorflags->copy_flags(copy_from->get_doorflags());
 
    return 1;
 }
@@ -1252,11 +1409,52 @@ int Door::read_door_attrib(FILE *read_file, ErrLog *error_log)
       rope_name.truncate(0);
    else
       set_rope_name(the_token->the_string);
+
+   /* read in the door flags */
+   if (doorflags->read_flags(read_file, error_log) <= 0)
+   {
+      holder.sprintf("Error reading doorflags for door '%s@%s'", get_name(),
+                                                                 get_area()); 
+      error_log->log_err(holder.str_show(), "read_door_attrib");
+      return -1;
+   }   
    
    return 1;
 }
 
 
+/***********************************************************************
+ ** is_visible - is the door visible to the player in the player's location?
+ **
+ ** Parameters: plr_loc - the player's current location
+ **
+ ** Returns:  1 for visible
+ **           0 for not
+ **
+ ***********************************************************************/
+
+int Door::is_visible(MudObject *plr_loc)
+{
+  Object_List *the_dbase;
+  MudObject   *tmp_outside;
+
+  if (doorflags->get_flag(DOORFLAG_OUTSIDEINVIS))
+  {
+    the_dbase = mainstruct->get_dbase();
+    if ((tmp_outside = 
+	 the_dbase->get_mudobject(get_area(), outside_loc.str_show())) != NULL)
+    {
+      if (tmp_outside == plr_loc)
+      {
+	return 0;
+      }
+    }
+  }
+
+  return 1;
+}
+
+
 /***********************************************************************
  ** get_mem_size - gets how much memory this special is taking up
  **
@@ -1306,6 +1504,8 @@ int Door::get_mem_size_dynamic()
    size += get_mem_size_mudobj();
    size += get_mem_size_entity();
 
+   size += doorflags->get_mem_size();
+
    return size;
 }
 
