@@ -167,14 +167,14 @@ int Editor::start_editor(MudObject *the_User)
 		bldr_ptr = (Builder *) the_User;
       tmp_handler = bldr_ptr->get_input_handler();
       /*cur_prompt  = bldr_ptr->get_prompt();*/
-      cur_prompt = new_Strings(EDITOR_PROMPT);
+      cur_prompt = new Strings(EDITOR_PROMPT);
       bldr_ptr->send_bldr(EDITOR_HEADER);
 		break;
    case OBJ_TYPE_PLAYER:
       plr_ptr = (Player *) the_User;
       tmp_handler = plr_ptr->get_input_handler();
       /*cur_prompt  = plr_ptr->get_prompt();*/
-      cur_prompt = new_Strings(EDITOR_PROMPT);
+      cur_prompt = new Strings(EDITOR_PROMPT);
       plr_ptr->send_plr(EDITOR_HEADER);
 		break;
    default:
@@ -480,7 +480,7 @@ int Editor::write_context(Strings *tostr)
    tostr->str_copy(tmpptr->str_show());
    if (remove_newline == true)
       tostr->remove_newline();
-   delete_Strings(tmpptr);
+   delete tmpptr;
    return 1;
 }
 
@@ -602,7 +602,7 @@ int Editor::format_context(void)
    }
    reset_editor();
    load_string(newstr.str_show());
-   delete_Strings(tostr);
+   delete tostr;
    return 1;   
 }
 
@@ -621,7 +621,7 @@ Strings *Editor::get_context(void)
     
     while (lin_ptr != NULL)
     {   if (tmp_ptr == NULL)
-        {   tmp_ptr = new_Strings();
+        {   tmp_ptr = new Strings();
             if (tmp_ptr == NULL)
                return NULL;
         }
@@ -695,8 +695,10 @@ void Editor::goto_line(int linenr)
 void Editor::show_help(Connection *the_conn)
 {   FILE *hfp = NULL;
     char linebuffer[512];
+    Strings full_filename;
 
-    if ((hfp = xfopen("../data/editor.help","r", "editor_help_file")) == NULL)
+    full_filename.sprintf("%s/%s", the_config.basedir.str_show(), EDITOR_HELP); 
+    if ((hfp = xfopen(full_filename.str_show(),"r", "editor_help_file")) == NULL)
     {   the_conn->send_to_socket("Help file not found.\n");
     }
     else
@@ -980,8 +982,8 @@ int editor_command_handler(MudObject *theobject, char *the_input)
          break;
       case 'A':
          the_conn->send_to_socket("&+b[&+WAborting Editor&+b]&*\n");
-         tmp_handler->pop_input_handler();
          the_editor->stop_editor(true);
+         tmp_handler->pop_input_handler();
          break;
       case 'i':
          tmp_handler->push_input_handler(editor_input_handler,NULL,0,
@@ -1214,7 +1216,7 @@ int editor_input_handler(MudObject *theobject, char *the_input)
    default:
       the_conn->send_to_socket("Whoops, the editor is screwed up.. going to command mode.\n");
       the_editor->set_cmdmode(Command);
-      tmp_prompt = new_Strings(EDITOR_PROMPT);
+      tmp_prompt = new Strings(EDITOR_PROMPT);
 
       tmp_handler->pop_input_handler();
       return 1;
