@@ -60,7 +60,7 @@
 #include "chatline.h"
 #include "inclination.h"
 #include "talent.h"
-
+#include "race.h"
 
 /***********************************************************************
  ** Entity (constructor) - creates the entity
@@ -469,58 +469,58 @@ Entity *Entity::copy_obj(char *new_name)
    {
       case OBJ_TYPE_BOOK:
       {  
-         new_obj = (Entity *) new_Book(new_name, get_area());
+         new_obj = (Entity *) new Book(new_name, get_area());
          break;
       }      
       case OBJ_TYPE_DOOR:
       {
-         new_obj = (Entity *) new_Door(new_name, get_area());
+         new_obj = (Entity *) new Door(new_name, get_area());
          break;
       }
 
       case OBJ_TYPE_KEY:
       {
-         new_obj = (Entity *) new_Key(new_name, get_area());
+         new_obj = (Entity *) new Key(new_name, get_area());
          break;
       }
 
       case OBJ_TYPE_BOAT:
       {
-         new_obj = (Entity *) new_Boat(new_name, get_area());
+         new_obj = (Entity *) new Boat(new_name, get_area());
          break;
      }
 
       case OBJ_TYPE_LOCATION:
       {
-         new_obj = (Entity *) new_Location(new_name, get_area());
+         new_obj = (Entity *) new Location(new_name, get_area());
          break;
       }
 
       case OBJ_TYPE_MARKER:
       {
-         new_obj = (Entity *) new_Marker(new_name, get_area());
+         new_obj = (Entity *) new Marker(new_name, get_area());
          break;
       }
 
       case OBJ_TYPE_MOBILE:
       {
-         new_obj = (Entity *) new_Mobile(new_name, get_area());
+         new_obj = (Entity *) new Mobile(new_name, get_area());
          break;
       }
 
       case OBJ_TYPE_MOVEABLE:
       {
-         new_obj = (Entity *) new_Moveable(new_name, get_area());
+         new_obj = (Entity *) new Moveable(new_name, get_area());
          break;
       }
       case OBJ_TYPE_WEARABLE:
       {
-         new_obj = (Entity *) new_Wearable(new_name, get_area());
+         new_obj = (Entity *) new Wearable(new_name, get_area());
          break;
       }
       case OBJ_TYPE_WEAPON:
       {
-         new_obj = (Entity *) new_Weapon(new_name, get_area());
+         new_obj = (Entity *) new Weapon(new_name, get_area());
          break;
       }
       case OBJ_TYPE_MERGER:
@@ -545,7 +545,7 @@ Entity *Entity::copy_obj(char *new_name)
       }
       case OBJ_TYPE_SPECIAL:
       {
-         new_obj = (Entity *) new_Specials(new_name, get_area());
+         new_obj = (Entity *) new Specials(new_name, get_area());
          break;
       }
       case OBJ_TYPE_ACTION:
@@ -572,17 +572,17 @@ Entity *Entity::copy_obj(char *new_name)
       }
       case OBJ_TYPE_RACE:
       {
-         new_obj = (Entity *) new_Race(new_name);
+         new_obj = (Entity *) new Race(new_name);
          break;
       }
       case OBJ_TYPE_INCLINAT:
       {
-         new_obj = (Entity *) new_Inclination(new_name);
+         new_obj = (Entity *) new Inclination(new_name);
          break;
       }
       case OBJ_TYPE_TALENT:
       {
-         new_obj = (Entity *) new_Talent(new_name);
+         new_obj = (Entity *) new Talent(new_name);
          break;
       }
       case OBJ_TYPE_MASK:
@@ -602,7 +602,7 @@ Entity *Entity::copy_obj(char *new_name)
       }
       case OBJ_TYPE_SPELL:
       {
-         new_obj = (Entity *) new_Spell(new_name);
+         new_obj = (Entity *) new Spell(new_name);
          break;
       }
       case OBJ_TYPE_SKILL:
