@@ -79,7 +79,7 @@ Inclination::Inclination(char *inclination_name)
  **
  ***********************************************************************/
 
-Inclination::~Inclination(void)
+Inclination::~Inclination()
 {
 }
 
@@ -714,7 +714,7 @@ int Inclination::set_attrib(Builder *the_builder, Parse *the_parsed){
 
       set_cha_offset(value);
       the_builder->send_bldr("ChaOffset set to %d on inclination object %s.\n",
-                                          get_intel_offset(), get_name());
+                                          get_cha_offset(), get_name());
       return 1;
    }
    if (!STRNCASECMP(the_parsed->get_target1(), "wisoffset",
@@ -741,7 +741,7 @@ int Inclination::set_attrib(Builder *the_builder, Parse *the_parsed){
 
       set_wis_offset(value);
       the_builder->send_bldr("WisOffset set to %d on inclination object %s.\n",
-                                          get_intel_offset(), get_name());
+                                          get_wis_offset(), get_name());
       return 1;
    }
 
