@@ -191,7 +191,7 @@ int get_bname(MudObject *the_user, char *the_input)
    tmp_handler->replace_input_handler(get_bpasswd, 
                                       "Please enter your password: ", 
                                       HANDLER_DATA_INT);
-   the_builder->echo_off();
+   tmp_handler->set_input_invis();
    return 1;
 }
 
@@ -232,7 +232,6 @@ int get_bpasswd(MudObject *the_user, char *the_input)
    builder_input.remove_newline();
    if (builder_input.str_len() <= 0)
    {
-      the_builder->echo_on();
       the_builder->send_bldr("\n\nCancelling log-on, bye!\n\n");
       the_builder->set_off();
       return -1;
@@ -245,7 +244,6 @@ int get_bpasswd(MudObject *the_user, char *the_input)
       *counter = *counter + 1;
       if (*counter == the_config.maxpasswdtries)
       {
-         the_builder->echo_on();
          the_builder->send_bldr("Too many failures, bye!\n\n");
          the_builder->set_off();
          return -1;
@@ -258,7 +256,6 @@ int get_bpasswd(MudObject *the_user, char *the_input)
    }
    else
    {
-      the_builder->echo_on();
       the_builder->send_bldr("\nCorrect password.\n\n");
    }
 
@@ -272,6 +269,9 @@ int get_bpasswd(MudObject *the_user, char *the_input)
 
    the_builder->set_pname(the_builder->get_title());
 
+   // turn on their echo if it isnt yet
+   the_builder->get_connection()->echo_on();
+
    gameflags = the_builder->get_gameflags();
    if (gameflags->get_flag(GAMEFLAG_COLOR))
       (the_builder->get_connection())->set_color(1);
@@ -305,6 +305,7 @@ int get_pname(MudObject *the_user, char *the_input)
    User_Dbase *tmp_udbase;
    Inp_Handler *tmp_handler;
    Flags       *oTmpFlags;
+   int        result;
 
    if (the_user->get_type() != OBJ_TYPE_PLAYER)
       return -1;
@@ -345,23 +346,33 @@ int get_pname(MudObject *the_user, char *the_input)
 
       the_player->create_mail();
 
-      if(    tmp_udbase->read_user( playername.str_show( ), the_player ) <= 0
-          || ( ( oTmpFlags = the_player->get_gameflags( ) )
-               && oTmpFlags->get_flag( GAMEFLAG_DELETED ) ) )
+      if(((result = tmp_udbase->read_user( playername.str_show( ), the_player )) 
+	 <= 0) || (( oTmpFlags = the_player->get_gameflags())
+		   && oTmpFlags->get_flag( GAMEFLAG_DELETED)))
+
       {
-         the_player->
-               send_plr("That player does not exist in our database.\n");
-         tmp_handler->replace_input_handler(ask_new_player, 
-                             "Create a new player? (y/n) ", 0);
-         return 1;
-      }   
+	if (result == -2)
+	{
+	  the_player->send_plr("That player is dead and can't be used.\n"
+			       "Please choose another.\n\n");
+	  return 0;
+	}
+	else
+	{
+	  the_player->
+	    send_plr("That player does not exist in our database.\n");
+	  tmp_handler->replace_input_handler(ask_new_player, 
+					     "Create a new player? (y/n) ", 0);
+	  return 1;
+	}   
+      }
+
    }
 
    tmp_handler->replace_input_handler(get_ppasswd,
                                    "Please enter your password: ", 
                                    HANDLER_DATA_INT);
-
-   the_player->echo_off();
+   tmp_handler->set_input_invis();
 
    return 1;
 }
@@ -397,10 +408,10 @@ int ask_new_player(MudObject *the_user, char *the_input)
 
    if (!STRNCASECMP("yes", player_input.str_show(), player_input.str_len()))
    {
-      the_player->echo_off();
       the_player->send_plr("\n");
       tmp_handler->replace_input_handler(get_new_passwd1, 
                                           "Please enter a password: ", 0);
+      tmp_handler->set_input_invis();
       return 1; 
    }
    else if (!STRNCASECMP("no", player_input.str_show(), 
@@ -451,7 +462,6 @@ int get_ppasswd(MudObject *the_user, char *the_input)
 
    if (player_input.str_len() <= 0)
    {
-      the_player->echo_on();
       the_player->send_plr("\n\nCancelling log-on, bye!\n\n");
       the_player->set_off();
       return -1;
@@ -474,7 +484,6 @@ int get_ppasswd(MudObject *the_user, char *the_input)
       *count = *count + 1;
       if (*count == the_config.maxpasswdtries)
       {
-         the_player->echo_on();
          the_player->send_plr("\nToo many failures, bye!\n\n");
          the_player->set_off();
          return -1;
@@ -487,7 +496,6 @@ int get_ppasswd(MudObject *the_user, char *the_input)
    }
 
 
-   the_player->echo_on();
    the_player->send_plr("\nCorrect password.\n\n");
 
 
@@ -509,10 +517,10 @@ int get_ppasswd(MudObject *the_user, char *the_input)
 
       if (plr_race == NULL)
       {
-         the_player->set_location(mainstruct->get_def_start_loc());   
+         the_player->set_loc_str(mainstruct->get_def_start_loc());   
       }
       else
-         the_player->set_location(plr_race->get_init_location());
+         the_player->set_loc_str(plr_race->get_init_location());
    }
    if (the_player->reset_curr_loc() == -1)
    {
@@ -522,7 +530,7 @@ int get_ppasswd(MudObject *the_user, char *the_input)
                                        the_config.hardcoded_areaname.str_show());
       mainstruct->set_def_start_loc(holder.str_show());
 
-      the_player->set_location(mainstruct->get_def_start_loc());
+      the_player->set_loc_str(mainstruct->get_def_start_loc());
       if (the_player->reset_curr_loc() == -1)
       {
          printf("Fatal Error!!! "
@@ -531,13 +539,11 @@ int get_ppasswd(MudObject *the_user, char *the_input)
       }
    }
 
+   // turn on their echo if it isnt yet
+   the_player->get_connection()->echo_on();
+
    gameflags = the_player->get_gameflags();
    indflags = the_player->get_indflags();
-  
-   if (gameflags->get_flag(GAMEFLAG_MALE))
-      indflags->set_flag(INDFLAG_MALE);
-   else
-      indflags->clr_flag(INDFLAG_MALE);
 
    indflags->clr_flag(INDFLAG_CORPSE);
    indflags->clr_flag(INDFLAG_GHOST);
@@ -610,7 +616,6 @@ int get_new_passwd1(MudObject *the_user, char *the_input)
 
    if (player_input.str_len() <= 0)
    {
-      the_player->echo_on();
       the_player->send_plr("\nCancelling new player creation\n\n");
       the_player->set_initname();
       tmp_handler->replace_input_handler(get_pname, 
@@ -628,6 +633,8 @@ int get_new_passwd1(MudObject *the_user, char *the_input)
   
    tmp_handler->replace_input_handler(get_new_passwd2, 
                       "\nPlease type the same password again: ", 0);
+   tmp_handler->set_input_invis();
+
    return 1;
 }
 
@@ -657,10 +664,10 @@ int get_new_passwd2(MudObject *the_user, char *the_input)
 
    if (player_input.str_len() <= 0)
    {
-      the_player->echo_on();
       the_player->send_plr("\nYou must type the same password both times.\n");
       tmp_handler->replace_input_handler(get_new_passwd1,
                                        "Please enter a password: ", 0);
+      tmp_handler->set_input_invis();
       return 0;
    }
 
@@ -671,17 +678,16 @@ int get_new_passwd2(MudObject *the_user, char *the_input)
       the_player->send_plr("\nPlease type the same password both times.\n");
       tmp_handler->replace_input_handler(get_new_passwd1, 
                                          "Please enter a password: ", 0);
+      tmp_handler->set_input_invis();
       return 0;
    }
 
-   the_player->echo_on();
    the_player->send_plr("\nPassword created.\n\n");
 
    // The next two lines should probably be moved somewhere more appropriate.
    // For now, this works :)
      
-   tmp_handler->replace_input_handler(ask_use_color, 
-                                "Would you like to use color? (y/n) ", 0);
+   tmp_handler->replace_input_handler(ask_use_color,                                 "Would you like to use color? (y/n) ", 0);
 
    return 1;
 }
@@ -701,6 +707,8 @@ int ask_use_color(MudObject *the_user, char *the_input)
    Inp_Handler *tmp_handler;
    Strings     the_file;
    Flags       *game_flags;
+   Area_Dbase  *race_area;
+   Object_List *the_dbase;
 
    if (the_user->get_type() != OBJ_TYPE_PLAYER)
       return -1;
@@ -736,9 +744,35 @@ int ask_use_color(MudObject *the_user, char *the_input)
       return -1;
    }
 
-   mainstruct->display_races(the_player);
-   tmp_handler->replace_input_handler(get_race, 
+   // First, we replace color with get_sex, then possibly stack on the
+   // ask race handler
+   tmp_handler->replace_input_handler(get_sex, 
+                                 "Are you male, female, or neuter? (m/f/n) ", 0);
+
+   // Now we see if they have more than one race loaded and if so, allow the
+   // new player to pick one.  If only one, we just assign them that one
+   the_dbase = mainstruct->get_dbase();
+   if ((race_area = the_dbase->get_area("races")) == NULL)
+     fault("Possibly fatal error!  Missing race area!\n");
+
+   if (race_area->get_num_obj_loaded() < 1)
+   {
+     mainstruct->log_error("No races loaded.  "
+		     "Needs at least one race to login new chars.", "get_sex");
+     fault("Error, no races loaded.  Needs race to login new chars.\n");
+     return -1;
+   }
+   if (race_area->get_num_obj_loaded() >= 2)
+   {
+     mainstruct->display_races(the_player);
+     tmp_handler->push_input_handler(get_race, 
                                 "What race will you be born into? ", 0);
+   }
+   else  // Assign them the one race
+   {
+     race_area->reset_list();
+     the_player->set_race((race_area->get_next_obj())->get_name());
+   }
 
    return 1;
 }
@@ -854,8 +888,7 @@ int confirm_race(MudObject *the_user, char *the_input)
 
    if (!STRNCASECMP("yes", player_input.str_show(), player_input.str_len()))
    {
-      tmp_handler->replace_input_handler(get_sex, 
-                                 "Are you male or female? (m/f) ", 0);
+      tmp_handler->pop_input_handler();
       return 1;      
    }
    else if (!STRNCASECMP("no", player_input.str_show(), 
@@ -908,7 +941,7 @@ int get_sex(MudObject *the_user, char *the_input)
 
    if (player_input.str_len() <= 0)
    {
-      the_player->send_plr("\nPlease enter either male or female.\n");
+      the_player->send_plr("\nPlease enter either male, female or neuter.\n");
       return 0;
    }
 
@@ -917,11 +950,15 @@ int get_sex(MudObject *the_user, char *the_input)
 
    if (player_input.str_n_cmp("male", player_input.str_len()))
    { 
-      the_player->set_sex(1);
+      the_player->set_sex(SEX_MALE);
    }
    else if (player_input.str_n_cmp("female", player_input.str_len()))
    {
-      the_player->set_sex(0);
+      the_player->set_sex(SEX_FEMALE);
+   }
+   else if (player_input.str_n_cmp("neuter", player_input.str_len()))
+   {
+       the_player->set_sex(SEX_NEUTER);
    }
    else
    {
@@ -952,46 +989,55 @@ int get_sex(MudObject *the_user, char *the_input)
    holder.format_for_actions(the_race->get_init_brief(), the_player, NULL);
    the_player->push_brief("main", holder.str_show());
 
-   /* now find the first tutorial and send them into the tutorial handler */
+   // Now we fill up the stack with anything they need to select from
+
+   // First, we put on the ask for intro one, this one will happen
+   tmp_handler->replace_input_handler(ask_see_intro, 
+    				"Do you want to display the intro? (y/n) ", 0);
+   
+   // Now we add on the talent one, if applicable
+   if ((the_dbase->has_talents()) &&
+       (the_race->get_allow_talent() != NULL))
+   {
+     the_player->load_talent_list();
+     tmp_handler->push_input_handler(ask_talents, 
+		     "Which talents would you prefer? (q when done) ", 0);
+   }
+
+   // Now add the inclinations, if applicable
+   if ((the_dbase->has_inclinations()) && 
+	 (the_race->get_allow_incl() != NULL))
+   {
+     tmp_handler->push_input_handler(ask_inclinations, 
+					"Which inclination would you prefer? ", 0);
+   }
+
+   // now find the first tutorial and send them into the tutorial handler
    first_tutorial = the_race->get_next_tutorial(NULL);
 
-   if (first_tutorial.str_show() == NULL)
+   if (first_tutorial.str_show() != NULL)
    {
-      if (the_dbase->has_inclinations())
-      {
-         mainstruct->display_inclinations(the_player);
-         tmp_handler->replace_input_handler(ask_inclinations, 
-                         "Which inclination would you prefer? ", 0);
-      }
-      else if (the_dbase->has_talents())
-      {
-         the_player->load_talent_list();
-         the_player->display_talents();
-         tmp_handler->replace_input_handler(ask_talents, 
-                     "Which talents would you prefer? (q when done) ", 0);
-      }
-      else
-      {
-         tmp_handler->replace_input_handler(ask_see_intro, 
-                         "Do you want to display the intro? (y/n) ", 0);
-      }
+     // we mark which tutorial they are in  
+     the_player->add_status("currenttutorial", first_tutorial.str_show());
 
-      the_player->send_plr("\n");
-      return 1;
-   }
+     // If the tutorial is mandatory, just run it
+     if (the_race->get_tutorial_mandatory(first_tutorial.str_show()))
+     {
+       return the_race->start_tutorial(first_tutorial.str_show(), the_player);
+     }
 
-   /* we mark which tutorial they are in */   
-   the_player->add_status("currenttutorial", first_tutorial.str_show());
-
-   // If the tutorial is mandatory, just run it
-   if (the_race->get_tutorial_mandatory(first_tutorial.str_show()))
-   {
-      return the_race->start_tutorial(first_tutorial.str_show(), the_player);
-   }
-
-   // Otherwise, replace the input handler with the question to run it or not
-   tmp_handler->replace_input_handler(handle_tutorial, 
+     // Otherwise, replace the input handler with the question to run it or not
+     tmp_handler->push_input_handler(handle_tutorial, 
                   the_race->get_tutorial_prompt(first_tutorial.str_show()), 0);
+   }
+
+   // display the list for the next thing displayed
+   if (tmp_handler->get_command() == ask_inclinations)
+     mainstruct->display_inclinations(the_player);
+   else if (tmp_handler->get_command() == ask_talents)
+     the_player->display_talents();
+   
+
    the_player->send_plr("\n");
    return 1;
 }
@@ -1045,6 +1091,7 @@ int handle_tutorial(MudObject *the_user, char *the_input)
    
    if (player_input.str_n_cmp("yes", player_input.str_len()))
    { 
+      tmp_handler->pop_input_handler();
       return the_race->start_tutorial(cur_tutorial.str_show(), the_player);
    }
    else if (player_input.str_n_cmp("no", player_input.str_len()))
@@ -1054,28 +1101,18 @@ int handle_tutorial(MudObject *the_user, char *the_input)
       the_dbase = mainstruct->get_dbase();
       if (next_tutorial.str_show() == NULL)
       {
-         if (the_dbase->has_inclinations())
-         {
-            mainstruct->display_inclinations(the_player);
-            tmp_handler->replace_input_handler(ask_inclinations, 
-                         "Which inclination would you prefer? ", 0);
-         }
-         else if (the_dbase->has_talents())
-         {
-            the_player->load_talent_list();
-            the_player->display_talents();
-            tmp_handler->replace_input_handler(ask_talents, 
-                     "Which talents would you prefer? (q when done) ", 0);
-         }
-         else
-	 {
-            tmp_handler->replace_input_handler(ask_see_intro, 
-                         "Do you want to display the intro? (y/n) ", 0);
-	 }
-         the_player->send_plr("\n");
-         return -1;
-      }
+	tmp_handler->pop_input_handler();
+	
+	// display the list for the next thing displayed
+        if (tmp_handler->get_command() == ask_inclinations)
+	  mainstruct->display_inclinations(the_player);
+	else if (tmp_handler->get_command() == ask_talents)
+	  the_player->display_talents();
 
+	the_player->send_plr("\n");
+	return 0;
+      }
+     
       /* we mark which tutorial they are in */
       the_player->remove_status("currenttutorial");
       the_player->add_status("currenttutorial", next_tutorial.str_show());
@@ -1120,6 +1157,9 @@ int ask_inclinations(MudObject *the_user, char *the_input)
    int         show_desc = 0;
    Strings     the_word;
    Connection  *the_connection;
+   Race        *plr_race;
+   Strings     allow_incl;
+   Strings     holder;
 
    if (the_user->get_type() != OBJ_TYPE_PLAYER)
       return -1;
@@ -1128,6 +1168,15 @@ int ask_inclinations(MudObject *the_user, char *the_input)
 
    tmp_handler = the_player->get_input_handler();
 
+   if ((plr_race = mainstruct->get_race(the_player->get_race())) == NULL)
+   {
+     holder.sprintf("Could not get player race '%s'", the_player->get_race());
+     mainstruct->log_error(holder.str_show(), "ask_inclinations");
+     return -1;
+   }
+
+   allow_incl = plr_race->get_allow_incl();
+   
    player_input = the_input;
    player_input.remove_newline();
 
@@ -1146,7 +1195,9 @@ int ask_inclinations(MudObject *the_user, char *the_input)
 
    obj_list = mainstruct->get_dbase();
 
-   if ((the_inc = obj_list->get_inclination_obj(the_word.str_show())) == NULL)
+   if (((the_inc = obj_list->get_inclination_obj(the_word.str_show())) == NULL) ||
+       ((STRCASECMP(allow_incl.str_show(), "all")) && 
+	(!allow_incl.find_in_str(the_inc->get_name()))))
    {
       the_player->send_plr("I am not aware of the '%s' inclination.\n"
                   "Please select again.\n", the_word.str_show());
@@ -1168,18 +1219,10 @@ int ask_inclinations(MudObject *the_user, char *the_input)
 
    the_inc->set_values(the_player);
 
-   if (obj_list->has_talents())
-   {
-      the_player->load_talent_list();
-      the_player->display_talents();
-      tmp_handler->replace_input_handler(ask_talents, 
-                     "Which talents would you prefer? (q when done) ", 0);
-   }
-   else
-   {
-      tmp_handler->replace_input_handler(ask_see_intro, 
-                         "Do you want to display the intro? (y/n) ", 0);
-   }
+   tmp_handler->pop_input_handler();
+
+   if (tmp_handler->get_command() == ask_talents)
+	  the_player->display_talents();
 
    the_player->send_plr("\n");
    return 1;
@@ -1203,12 +1246,24 @@ int ask_talents(MudObject *the_user, char *the_input)
    int         show_desc = 0;
    Strings     the_word;
    Connection  *the_connection;
+   Race        *plr_race;
+   Strings     allow_talent;
+   Strings     holder;
 
    if (the_user->get_type() != OBJ_TYPE_PLAYER)
       return -1;
 
    the_player = (Player *) the_user;
 
+   if ((plr_race = mainstruct->get_race(the_player->get_race())) == NULL)
+   {
+     holder.sprintf("Could not get player race '%s'", the_player->get_race());
+     mainstruct->log_error(holder.str_show(), "ask_talents");
+     return -1;
+   }
+
+   allow_talent = plr_race->get_allow_talent();
+
    tmp_handler = the_player->get_input_handler();
 
    player_input = the_input;
@@ -1238,16 +1293,17 @@ int ask_talents(MudObject *the_user, char *the_input)
    if (!STRCASECMP(player_input.str_show(), "q"))
    {
       the_player->delete_talent_list();
-      tmp_handler->replace_input_handler(ask_see_intro, 
-                         "Do you want to display the intro? (y/n) ", 0);
+      tmp_handler->pop_input_handler();
       the_player->send_plr("\n");
       return 1;      
    }
 
    talent_list = the_player->get_talent_list();
 
-   if ((the_talent = (Talent *) talent_list->
-                              get_areaobject(the_word.str_show())) == NULL)
+   if (((the_talent = (Talent *) talent_list->
+                              get_areaobject(the_word.str_show())) == NULL) ||
+       ((STRCASECMP(allow_talent.str_show(), "all")) && 
+	(!allow_talent.find_in_str(the_talent->get_name()))))
    {
       the_player->send_plr("I am not aware of the '%s' talent.\n"
                              "Please select again.\n", the_word.str_show());
@@ -1405,6 +1461,7 @@ int ask_see_intro(MudObject *the_user, char *the_input)
       return -1;
    }
 
+
    if (!STRNCASECMP("yes", player_input.str_show(), player_input.str_len()))
    {
       the_file.sprintf("%s/%s%s%s", the_config.basedir.str_show(), 
