@@ -38,6 +38,24 @@
 #include "bulletin.h"
 #include "utils.h"
 
+   char echo_off[] =
+    {
+      (char) IAC,
+      (char) WILL,
+      (char) TELOPT_ECHO,
+      (char) 0
+   };
+
+   char echo_on[] =
+    {
+      (char) IAC,
+      (char) WONT,
+      (char) TELOPT_ECHO,
+      (char) TELOPT_NAOFFD,
+      (char) TELOPT_NAOCRD,
+      (char) 0
+   };
+
 /***********************************************************************
  ** Inp_Handler (constructor) - creates the input handler
  **
@@ -51,6 +69,7 @@ Inp_Handler::Inp_Handler()
 {
    input_stack = NULL;
    pop_handler = NULL;
+   last_invis = 0;
 }
 
 
@@ -72,7 +91,7 @@ Inp_Handler::~Inp_Handler()
    {
       input_stack = input_stack->next_handler;
       if ((tmp_handler->delete_prompt) && (tmp_handler->the_prompt != NULL))
-         delete_Strings(tmp_handler->the_prompt);
+         delete tmp_handler->the_prompt;
 
       if (tmp_handler->del_data)
          switch(tmp_handler->data_type)
@@ -143,7 +162,7 @@ int Inp_Handler::push_input_handler(Inp_Func funct_name, Strings *prompt,
    handler_struct *new_handler;
    handler_struct *temp_handler = NULL;;
 
-   new_handler = new_handler_struct();
+   new_handler = new handler_struct;
    new_handler->the_command = funct_name;
    new_handler->pop_command = NULL;
    new_handler->pop_string = NULL;
@@ -152,6 +171,18 @@ int Inp_Handler::push_input_handler(Inp_Func funct_name, Strings *prompt,
    new_handler->data_type = data_type;
    new_handler->del_data = del_data;
    new_handler->lines_per_handle = 1;
+   new_handler->input_vis = 1;
+
+   // If the last prompt had echo off markers on it, make sure we turn echo back on
+   if (last_invis)
+   {
+	   Strings holder;
+
+	   holder = new_handler->the_prompt;
+	   new_handler->the_prompt->sprintf("%s%s", echo_on, holder.str_show());
+	   last_invis = 0;
+   }
+   
 
    switch(data_type)
    {
@@ -221,7 +252,7 @@ int Inp_Handler::push_input_handler(Inp_Func funct_name, Strings *prompt,
    handler_struct *new_handler;
    handler_struct *temp_handler = NULL;;
 
-   new_handler = new_handler_struct();
+   new_handler = new handler_struct;
    new_handler->the_command = funct_name;
    new_handler->pop_command = NULL;
    new_handler->pop_string = NULL;
@@ -230,6 +261,18 @@ int Inp_Handler::push_input_handler(Inp_Func funct_name, Strings *prompt,
    new_handler->data_type = data_type;
    new_handler->del_data = del_data;
    new_handler->lines_per_handle = lines_per_handle;
+   new_handler->input_vis = 1;
+
+    // If the last prompt had echo off markers on it, make sure we turn echo back on
+   if (last_invis)
+   {
+	   Strings holder;
+
+	   holder = new_handler->the_prompt;
+	   new_handler->the_prompt->sprintf("%s%s", echo_on, holder.str_show());
+	   last_invis = 0;
+   }
+  
    switch(data_type)
    {
       case HANDLER_DATA_INT:
@@ -293,10 +336,10 @@ int Inp_Handler::push_input_handler(Inp_Func funct_name, char *prompt,
    Strings *new_string;
    int     results;
 
-   new_string = new_Strings(prompt);
+   new_string = new Strings(prompt);
    results = push_input_handler(funct_name, new_string, 1, data_type, 1);
    if (results <= 0)
-      delete_Strings(new_string);
+      delete new_string;
    return results; 
 }
 
@@ -412,7 +455,7 @@ int Inp_Handler::pop_input_handler(void)
 
    temp_handler = input_stack->next_handler;
    if ((input_stack->delete_prompt) && (input_stack->the_prompt != NULL))
-      delete_Strings(input_stack->the_prompt);
+      delete input_stack->the_prompt;
 
    if (input_stack->del_data)
       switch(input_stack->data_type)
@@ -464,7 +507,7 @@ int Inp_Handler::pop_input_handler(void)
       {
          if (pop_handler->pop_string != NULL)
 	 {
-            delete_Strings(pop_handler->pop_string);
+            delete pop_handler->pop_string;
             pop_handler->pop_string = NULL;
 	 }
       }
@@ -500,24 +543,32 @@ int Inp_Handler::exec_input_handler(MudObject *the_user, char *the_input)
    char     *tmp_str;
 
    if (input_stack == NULL)
+   {
+      fault("Player with empty input stack!  Possibly fatal!\n");
       return -1;
+   }
 
-   if (the_input == NULL)
-      return 0;
+   // If the input is null, treat it like a carriage return
+/*   if (the_input == NULL)
+      return 0; */
 
    /* if this is not the repeat order, then save it */
    holder = the_input;
-   tmp_str = holder.str_show();
-   while ((*tmp_str) && (*tmp_str != ' ') && (*tmp_str != '\r') && 
-          (*tmp_str != '\n'))
-      tmp_str++;
-   *tmp_str = '\0';
-   if ((STRNCASECMP(holder.str_show(), "repeat", holder.str_len())) &&
-       ((*(holder.str_show()) != '!')))
-   {
-      input_stack->last_command = the_input;
-   }
 
+   // A little tweak for empty strings so it doesn't have a NULL string sent in
+   if (holder.str_show() != NULL)
+   {
+     tmp_str = holder.str_show();
+     while ((*tmp_str) && (*tmp_str != ' ') && (*tmp_str != '\r') && 
+	    (*tmp_str != '\n'))
+       tmp_str++;
+     *tmp_str = '\0';
+     if ((STRNCASECMP(holder.str_show(), "repeat", holder.str_len())) &&
+	 ((*(holder.str_show()) != '!')))
+     {
+       input_stack->last_command = the_input;
+     }
+   }
    temp_command = input_stack->the_command;
 
    return temp_command(the_user, the_input);
@@ -744,10 +795,19 @@ int Inp_Handler::add_pop_function(Pop_Func the_function, char *id1, char *id2,
    
 void Inp_Handler::swap_prompt(Strings *new_prompt)
 {
+   Strings holder;
+
    if ((new_prompt == NULL) || (input_stack == NULL))
       return;
 
+
+   holder = new_prompt->str_show();
    input_stack->the_prompt = new_prompt;
+
+   if (input_stack->input_vis)
+   {
+      input_stack->the_prompt->sprintf("%s%s", holder.str_show(), echo_off);
+   }
 }
 
 
@@ -795,7 +855,7 @@ Inp_Func Inp_Handler::get_command()
 void Inp_Handler::remove_pop_function() 
 {
    input_stack->pop_command = NULL;
-   delete_Strings(input_stack->pop_string);
+   delete input_stack->pop_string;
    input_stack->pop_string = NULL;
 }
 
@@ -808,5 +868,32 @@ void Inp_Handler::set_delete_data()
    input_stack->del_data = 1;
 }
 
+
+/***********************************************************************
+ ** set_input_invis - makes it so what the user types does not appear on
+ **                   their screen
+ ***********************************************************************/
+
+void Inp_Handler::set_input_invis()
+{
+   Strings holder;
+
+   input_stack->input_vis = 0;
+
+   holder = input_stack->the_prompt;
+   input_stack->the_prompt->sprintf("%s%s", holder.str_show(), echo_off);
+   last_invis = 1;
+}
+
+/***********************************************************************
+ ** set_last_invis - tricks the input handler into putting a turn echo on
+ **                  command in the prompt
+ ***********************************************************************/
+
+void Inp_Handler::set_last_invis()
+{
+  last_invis = 1;
+}
+
 #endif
 
