@@ -66,7 +66,7 @@ Level::Level(char *level_name)
    min_str = min_dex = min_intel = min_con = min_wisdom = min_cha = min_exp = 0;
 
    special_req = when_awarded = NULL;
-   lvl_flags = new_Flags(1);
+   lvl_flags = new Flags(1);
 }
 
 
@@ -85,7 +85,7 @@ Level::~Level(void)
       delete_special_holder(special_req);
    if (when_awarded != NULL)
       delete_special_holder(when_awarded);
-   delete_Flags(lvl_flags);
+   delete lvl_flags;
 }
 
 
