@@ -42,9 +42,8 @@
 #include "parse.h"
 #include "input.h"
 #include "lexer.h"
-#include "btree_l.h"
+#include "btree.h"
 #include "area_dbase.h"
-#include "btree_a.h"
 #include "logs.h"
 #include "errlog.h"
 #include "object_list.h"
@@ -65,6 +64,7 @@
 #include "inp_handler.h"
 #include "indflags.h"
 #include "code.h"
+#include "doorflags.h"
 
 char *dir_str[10] = {"North", "South", "East", "West", "Up", "Down", 
                      "Northeast", "Northwest", "Southeast", "Southwest"};
@@ -73,15 +73,17 @@ char *fromdir_str[10] = {"north", "south", "east", "west", "above", "below",
                          "northeast", "northwest", "southeast", "southwest"};
 
 char *terrain_name[] = {"Forest", "Jungle",    "SandDesert", "RockDesert", 
-       "Plains",        "Tundra", "Icesheet",  "Hills",      "Mountains",  
-       "HighMountains", "Swamp",  "Bog",       "City",       "Ocean", 
-       "Lake",          "River",  "PavedRoad", "DirtRoad", 
+       "Plains",        "Tundra", "SnowField",  "Icesheet",  "Hills",      
+       "Mountains",     "HighMountains",        "Swamp",     "Bog",       
+       "ThinForest",    "ThickForest",          "City",      "Ocean",     
+       "Lake",          "River",                "PavedRoad", "DirtRoad",  
+       "Enclosure",  
 			NULL};
 
 float terrain_mult[] = {2.0,      2.5,         2.0,          1.5, 
-       1.0,             1.5,      1.0,         2.0,          3.0,
-       5.0,             3.5,      3.0,         1.5,          2.0,
-       1.0,             1.5,      1.0,         1.0};
+       1.0,             1.5,      2.0,         1.0,          2.0,          3.0,
+       5.0,             3.5,      3.0,         1.5,          2.0,          1.5,
+       2.0,             1.0,      1.5,         1.0,          1.0,          1.0};
 
 char *lighting_name[] = {"FullDark", "Dark", "Shady", "Average", "Bright", 
                          "Blinding", NULL};
@@ -110,7 +112,7 @@ Location::Location(char *the_name, char *the_area)
    /* set the area string to the appropriate area */
    set_area(the_area);
 
-   loc_flags = new_Flags(2);
+   loc_flags = new Flags(2);
 
    room_size = 10;
    the_terrain = Plains;
@@ -130,7 +132,7 @@ Location::Location(char *the_name, char *the_area)
 
 Location::~Location()
 {
-   delete_Flags(loc_flags);
+   delete loc_flags;
 }
       
 
@@ -196,25 +198,40 @@ Location *Location::xget_exit(char *the_exit, char *the_area, int *results)
    if (tmp_obj->get_type() == OBJ_TYPE_DOOR)
    {
       Door *the_door;
-      Flags *tmp_itemflags;
+      Flags *tmp_doorflags;
+      Strings holder;
 
       the_door = (Door *) tmp_obj;
+      if (!the_door->is_visible(this))
+      {
+	*results = 10;
+	return NULL;
+      }
       tmp_obj = the_dbase->get_mudobject(the_area, 
                                    the_door->get_link(this, &tmp_results));
 
       if (tmp_obj == NULL)
       {
-         tmp_itemflags = the_door->get_itemflags();
+         tmp_doorflags = the_door->get_doorflags();
 
-         if ((tmp_itemflags->get_flag(ITEMFLAG_HIDDENDOOR)) &&
-             (the_door->get_door_state() != DOOR_OPEN))
-         {
-            *results = 10;
-            return NULL;
-         }
-
-         *results = tmp_results;
-         return NULL;
+	 // If the door is closed, we have a few checks to perform to see if
+	 // it is hidden or not
+	 if (the_door->get_door_state() != DOOR_OPEN)
+	 {
+	   if ((tmp_doorflags->get_flag(DOORFLAG_HIDDENDOOR)) ||
+	       ((tmp_doorflags->get_flag(DOORFLAG_HIDEEXITIN)) &&
+		(the_door->which_loc(get_name(), get_area()) == 2)) ||
+	       ((tmp_doorflags->get_flag(DOORFLAG_HIDEEXITOUT)) &&
+		(the_door->which_loc(get_name(), get_area()) == 1)))
+	       
+	   {
+	     *results = 10;
+	     return NULL;
+	   }
+	 }
+	 *results = tmp_results;
+	 return NULL;
+     
       }
 
    }
@@ -358,7 +375,7 @@ int Location::show_location(Player *the_player, int brief)
    tmp_adminflags = the_player->get_admflags();
 
    if (tmp_adminflags->get_flag(ADMINFLAG_SHOWNAMES))
-      the_player->send_plr("\n&+GName&+b: &+M%s&*", get_name());
+      the_player->send_plr("\n&+GName&+b: &+M%s@%s&*", get_name(), get_area());
    
    if (!is_lit(the_player))
    {
@@ -654,7 +671,7 @@ int Location::show_exits(Player *the_player){
  **
  ***********************************************************************/
 
-int Location::send_location(char *the_string, Player *not_this){
+int Location::send_location(char *the_string, Individual *not_this){
    return send_location(the_string, not_this, NULL, SEND_ALL);
 }
 
@@ -673,7 +690,7 @@ int Location::send_location(char *the_string, Player *not_this){
  **
  ***********************************************************************/
 
-int Location::send_location(char *the_string, Player *not_this, int can_see){
+int Location::send_location(char *the_string, Individual *not_this, int can_see){
    return send_location(the_string, not_this, NULL, can_see);
 }
 
@@ -690,8 +707,8 @@ int Location::send_location(char *the_string, Player *not_this, int can_see){
  **
  ***********************************************************************/
 
-int Location::send_location(char *the_string, Player *not_this, 
-                                         Player *or_this){
+int Location::send_location(char *the_string, Individual *not_this, 
+                                         Individual *or_this){
    return send_location(the_string, not_this, or_this, SEND_ALL);
 }
 
@@ -706,51 +723,51 @@ int Location::send_location(char *the_string, Player *not_this,
  **
  ***********************************************************************/
 
-int Location::send_location(char *the_string, Player *not_this, 
-                                         Player *or_this, int can_see)
+int Location::send_location(char *the_string, Individual *not_this, Individual *or_this, int can_see)
 {
-   int count = 0; /* the number of players this is sent to */
-   MudObject  *tmp_obj;
-   Player     *player_list;
-   Flags      *gameflag;
-   LinkedNode *placekeeper;
-
-   player_list = mainstruct->get_first_player();
-   inventory.reset_current();
-
-   tmp_obj = inventory.get_next();
-   /* go through all players sending the message */
-   while (tmp_obj != NULL)
-   {
-      if (tmp_obj->get_type() == OBJ_TYPE_PLAYER)
-      {
-         player_list = (Player *) tmp_obj;
-         gameflag = player_list->get_gameflags();
-  
-         if (gameflag->get_flag(GAMEFLAG_ONGAME))
-         {
-   	    /* if this is not the player we aren't supposed to send this to */
-            if (((not_this == NULL) ||
-                 (STRCASECMP(not_this->get_name(), player_list->get_name()))) &&
-                ((or_this == NULL) ||
-                 (STRCASECMP(or_this->get_name(), player_list->get_name()))))
-	    {
-               placekeeper = inventory.store_current();
-               if ((can_see == SEND_ALL) ||
-                   (is_lit(player_list) && can_see) ||
-                   (!is_lit(player_list) && !can_see))
-	       {
-                  player_list->send_plr(the_string);
-                  count++;
-	       }
-               inventory.restore_current(placekeeper);
+    int count = 0; // the number of players this is sent to
+    MudObject  *tmp_obj;
+    Player     *player_list;
+    Flags      *gameflag;
+    
+    if ((not_this != NULL) && (not_this->get_type() != OBJ_TYPE_PLAYER))
+        not_this = NULL;
+    if ((or_this != NULL) && (or_this->get_type() != OBJ_TYPE_PLAYER))
+        or_this = NULL;
+    
+    player_list = mainstruct->get_first_player();
+    inventory.reset_current();
+    
+    tmp_obj = inventory.get_next();
+    // go through all players sending the message 
+    while (tmp_obj != NULL)
+    {
+        if (tmp_obj->get_type() == OBJ_TYPE_PLAYER)
+        {
+            player_list = (Player *) tmp_obj;
+            gameflag = player_list->get_gameflags();
+            
+            if (gameflag->get_flag(GAMEFLAG_ONGAME))
+            {
+                // if this is not the player we aren't supposed to send this to
+                if (((not_this == NULL) || (STRCASECMP(not_this->get_name(), player_list->get_name()))) 
+                &&  ((or_this == NULL) || (STRCASECMP(or_this->get_name(), player_list->get_name()))))
+                {
+                    inventory.push_current();
+                    if ((can_see == SEND_ALL) 
+                    || (is_lit(player_list) && can_see) || (!is_lit(player_list) && !can_see))
+                    {
+                        player_list->send_plr(the_string);
+                        count++;
+                    }
+                    inventory.pop_current();
+                }
             }
-         }
-      }
-      /* go to next player */
-      tmp_obj = inventory.get_next();
-   }
-   return count;
+        }
+        // go to next player
+        tmp_obj = inventory.get_next();
+    }
+    return count;
 }
 
 
@@ -796,6 +813,9 @@ int Location::list_objects(Player *the_player)
    Timespan  the_time;
    Strings   passengers;
    Boat      *the_boat;
+   Flags     *adminflags;
+
+   adminflags = the_player->get_admflags();
 
    /* go through all objects in the location */
    inventory.reset_current();
@@ -805,13 +825,17 @@ int Location::list_objects(Player *the_player)
    while (the_object != NULL)
    {
       if (the_object->is_a_moveable())
-      {  
+      {
          if (the_object->get_type() == OBJ_TYPE_BOAT)
 	 {
             the_boat = (Boat *) the_object;
 
             if (STRNCASECMP(the_boat->get_brief(), "none", 4))
-               the_player->send_plr("%s", the_boat->get_brief());
+	      if (adminflags->get_flag(ADMINFLAG_SHOWNAMES))
+		the_player->send_plr("&+m(%s)&* %s", the_boat->get_name(),
+				     the_boat->get_brief());
+	      else
+		the_player->send_plr("%s", the_boat->get_brief());
 
             the_boat->get_passengers(the_player, &passengers);
             if (passengers.str_show() != NULL)
@@ -820,11 +844,23 @@ int Location::list_objects(Player *the_player)
                                                 passengers.str_show());
             }
          }
-         else
+	 else
+	 {
             if (STRNCASECMP(((Moveable *) the_object)->get_brief(), "none", 4))
-               the_player->send_plr("%s", ((Moveable *) the_object)->
+	    {
+	      if ((the_object->get_type() != OBJ_TYPE_ROPE) ||
+		  (!((Rope *) the_object)->get_itemflags()->
+		   get_flag(ITEMFLAG_ISTIED)))
+	      {
+		if (adminflags->get_flag(ADMINFLAG_SHOWNAMES))
+		  the_player->send_plr("&+m(%s)&* %s", the_object->get_name(),
+				     ((Moveable *) the_object)->get_brief());
+		else
+		  the_player->send_plr("%s", ((Moveable *) the_object)->
                                                              get_brief());
-
+	      }
+	    }
+	 }
       }
       the_object = inventory.get_next();
    }
@@ -845,7 +881,7 @@ int Location::list_immobile(Player *the_player)
 {
    MudObject *the_object;
    Flags     *tmp_admflags;
-   Flags     *tmp_itemflags;
+   Flags     *tmp_doorflags;
 
    /* go through all objects in the location */
    inventory.reset_current();
@@ -858,12 +894,14 @@ int Location::list_immobile(Player *the_player)
    {
       if (the_object->get_type() == OBJ_TYPE_DOOR)
       {
-
-         tmp_itemflags = ((Item *) the_object)->get_itemflags();
-         if ((!tmp_itemflags->get_flag(ITEMFLAG_HIDDENDOOR)) ||
-             (((Door *) the_object)->get_door_state() == DOOR_OPEN)) 
+	if (((Door *) the_object)->is_visible(this))
+	{
+	  tmp_doorflags = ((Door *) the_object)->get_doorflags();
+	  if ((!tmp_doorflags->get_flag(DOORFLAG_HIDDENDOOR)) ||
+	      (((Door *) the_object)->get_door_state() == DOOR_OPEN)) 
             the_player->send_plr("%s", 
-                                   ((Door *) the_object)->get_brief(this));
+				 ((Door *) the_object)->get_brief(this));
+	}
       }
 
       else if ((the_object->get_type() == OBJ_TYPE_MARKER) &&
@@ -890,38 +928,40 @@ int Location::list_immobile(Player *the_player)
  ***********************************************************************/
 
 int Location::list_individuals(Player *the_player){
-
-   MudObject *the_object;
-   Individual *the_ind;
-   Timespan   the_time;
-
-   /* go through all objects in the location */
-   inventory.reset_current();
-
-   /* go through all players in the room */
-   the_object = inventory.get_next();
-   while (the_object != NULL)
-   {
-      if (the_object->is_an_individual())
-      {
-         the_ind = (Individual *) the_object;
-
-         if ((the_ind->get_type() != OBJ_TYPE_PLAYER) || 
-             (the_player != (Player *) the_ind))
-	 {
-            if ((the_ind->get_indflags())->get_flag(INDFLAG_CORPSE))
-	    {
-               the_player->send_plr("A corpse lies here, slowly rotting away.\n");
-	    }
-            else
-	    {
-               the_player->send_plr("%s", the_ind->get_brief());
-	    }
-	 }
-      }
-      the_object = inventory.get_next();
-   }
-   return 1;
+    
+    MudObject *the_object;
+    Individual *the_ind;
+    Timespan   the_time;
+    
+    /* go through all objects in the location */
+    inventory.reset_current();
+    
+    /* go through all players in the room */
+    the_object = inventory.get_next();
+    while (the_object != NULL)
+    {
+        if (the_object->is_an_individual())
+        {
+            the_ind = (Individual *) the_object;
+            
+            if ((the_ind->get_type() != OBJ_TYPE_PLAYER) 
+            ||  (the_player != (Player *) the_ind)
+            ||  ((the_ind->is_vis_game() || the_ind->is_vis_admin()) 
+            && !(((Player *)the_ind)->get_admflags())->get_flag(ADMINFLAG_ADMINISTRATOR)))
+            {
+                if ((the_ind->get_indflags())->get_flag(INDFLAG_CORPSE))
+                {
+                    the_player->send_plr("A corpse lies here, slowly rotting away.\n");
+                }
+                else
+                {
+                    the_player->send_plr("%s", the_ind->get_brief());
+                }
+            }
+        }
+        the_object = inventory.get_next();
+    }
+    return 1;
 }
 
 
@@ -1203,9 +1243,9 @@ int Location::set_attrib(Builder *the_builder, Parse *the_parsed){
  
       if (the_parsed->get_speech() == NULL)
       {
-         the_builder->
-                send_bldr("You need to specify an ExtraDir to set to.\n");
-         return -1;
+		set_extra_dir(NULL);
+		the_builder->send_bldr("ExtraDir on %s cleared.\n", get_name());
+		return 1;
       }
       set_extra_dir(the_parsed->get_speech());
       the_builder->send_bldr("ExtraDir on %s set to: %s\n", get_name(), 
@@ -1388,7 +1428,7 @@ int Location::set_attrib(Builder *the_builder, Parse *the_parsed){
          the_builder->send_bldr("You need to specify a subarea to set to.\n");
          return -1;
       }
-      set_location(the_parsed->get_speech());
+      set_loc_str(the_parsed->get_speech());
       the_builder->send_bldr("Subarea on %s set to: %s\n", get_name(), 
                                                         get_location());
       set_modified(1);
@@ -2012,7 +2052,10 @@ light_type Location::get_lighting()
 
 void Location::set_extra_dir(char *the_str)
 {
-   extra_dir = the_str;
+  if (the_str == NULL)
+    extra_dir.truncate(0);
+  else
+    extra_dir = the_str;
 }
 
 
@@ -2102,7 +2145,7 @@ int Location::auto_associate(Builder *the_builder, int the_exit, char *new_loc)
                 the_loc->get_area(), the_loc->get_exit(opposite_exit[the_exit]));
       tmp_handler->push_input_handler(confirm_assoc_replace, 
                                     "Would you like to replace it? (y/n) ", 0);
-      pop_loc = new_Strings();
+      pop_loc = new Strings();
       pop_loc->sprintf("%s@%s", the_loc->get_name(), the_loc->get_area());
       tmp_handler->add_pop_function(replace_exit, 
                 the_builder->get_name(), dir_str[opposite_exit[the_exit]], 
@@ -2447,7 +2490,7 @@ int Location::cleanup_marks(int distance, int from_dir)
  **                 is still enough distance remaining, fans out from that
  **                 room as well
  **
- ** Parameters: the_player - the player running this special, if any
+ ** Parameters: the_user - the user running this special, if any
  **             the_special - the special to execute in this room
  **             distance - the distance to apply this special, based on
  **                        the size of subsequent rooms
@@ -2457,7 +2500,7 @@ int Location::cleanup_marks(int distance, int from_dir)
  **
  ***********************************************************************/
 
-int Location::apply_special(Player *the_player, Specials *the_special, 
+int Location::apply_special(Individual *the_user, Specials *the_special, 
                                                 int distance, int from_dir)
 {
    int         dist_traveled;
@@ -2484,12 +2527,12 @@ int Location::apply_special(Player *the_player, Specials *the_special,
    {
       fill_param.primary_obj = this;
       fill_param.secondary_obj = NULL;
-      fill_param.this_obj = the_player;
+      fill_param.this_obj = the_user;
 
       environment.trig_used = "onapply";
       environment.target_str = fromdir_str[from_dir];
       environment.exec_vars = NULL;
-      the_special->run_special(the_player, &fill_param, &environment);
+      the_special->run_special(the_user, &fill_param, &environment);
    }
 
    marked = 2;
@@ -2508,7 +2551,7 @@ int Location::apply_special(Player *the_player, Specials *the_special,
       if ((i != from_dir) &&
           ((new_loc = get_exit(i, get_area(), &results)) != NULL))
       {
-         new_loc->apply_special(the_player, the_special, 
+         new_loc->apply_special(the_user, the_special, 
                                (distance - dist_traveled), opposite_exit[i]);
       }
    }
