@@ -1203,7 +1203,7 @@ int mailer_command_handler(MudObject *the_obj, char *the_input)
       the_player->send_plr("&+gFrom: &*%s\n", the_player->get_title());
       the_mailer->set_current_ltr(new_ltr);
 
-      prompt = new_Strings("&+gSubject:&* ");
+      prompt = new Strings("&+gSubject:&* ");
 
       /* get the subject from the user */
       tmp_handler->push_input_handler(mailer_get_subject, 
