@@ -169,15 +169,18 @@ int main(int argc, char *argv[]) {
 
 
 #if defined( AIME_DAEMONIZABLE )
+   if ((!the_config.conf_flags->get_flag(CF_CRASHSEGFLT)) ||
+       (!the_config.conf_flags->get_flag(CF_CRASHSIGNAL)))
+   {
+     if (!quiet_mode)
+       sysmessage(_("Trapping Signals..."));
+     trap_signals();
+     if (!quiet_mode)
+        sysmessage(_("Ok\n"));
+   }
+
    if (the_config.conf_flags->get_flag(CF_DAEMONIZE))
    {
-
-      if (!quiet_mode)
-         sysmessage(_("Trapping Signals..."));
-      trap_signals();
-      if (!quiet_mode)
-         sysmessage(_("Ok\n"));
-
       if (!quiet_mode)
          sysmessage(_("Daemonizing mud..."));
       fflush(stdout);
@@ -253,21 +256,34 @@ int main(int argc, char *argv[]) {
  ***************************************************************************/
 void trap_signals()
 {  
+
+   // If they want a controlled crash on segfault
+   if (!the_config.conf_flags->get_flag(CF_CRASHSEGFLT))
+   {
+     signal(SIGSEGV,crash_on_signal);
+     signal(SIGBUS,crash_on_signal);
+     signal(SIGILL,crash_on_signal);
+     signal(SIGFPE,crash_on_signal);
+   }
+
+   // Make sure sigsegv crashes, it doesn't for some reason
+   else
+     signal(SIGSEGV, SIG_DFL);
+    
+   if (!the_config.conf_flags->get_flag(CF_CRASHSIGNAL))
+   {
 #if !defined( __CYGWIN__ )
-   signal(SIGPWR,signal_shutdown);
+      signal(SIGPWR,signal_shutdown);
 #endif
 
-   signal(SIGHUP,ignore_signals);
-   signal(SIGCHLD,ignore_signals);
-   signal(SIGPIPE,ignore_signals);
-   signal(SIGINT,ignore_signals);
-   signal(SIGSEGV,crash_on_signal);
-   signal(SIGBUS,crash_on_signal);
-   signal(SIGILL,crash_on_signal);
-   signal(SIGFPE,crash_on_signal);
-   signal(SIGQUIT,signal_shutdown);
-   signal(SIGABRT,signal_shutdown);
-   signal(SIGTERM,signal_shutdown);
+      signal(SIGHUP,ignore_signals);
+      signal(SIGPIPE,ignore_signals);
+
+      signal(SIGINT, signal_shutdown);  // Hitting Ctrl-C
+      signal(SIGQUIT,signal_shutdown);  
+      signal(SIGABRT,signal_shutdown);
+      signal(SIGTERM,signal_shutdown);
+   }
 }
 
 void ignore_signals(int sig)
