@@ -94,6 +94,21 @@ Mobile::~Mobile()
 }
 
 
+bool Mobile::can_see_ind(Individual *the_ind)
+{
+    int the_num;
+
+    if (the_ind->is_visible())
+        return true;
+
+    if (the_ind->is_vis_incog() 
+    && (the_ind->get_loc())->find_contained(get_name(), &the_num))
+        return true;
+
+    return false;
+}
+
+
 /***********************************************************************
  ** write_object - writes the mobile to a specified file in specified
  **                file format
@@ -136,9 +151,19 @@ void Mobile::write_object(FILE *the_file, int build_format)
 
    tmp_indflag = get_indflags();
    tmp_indflag->write_flag(the_file);
+
+   fprintf(the_file, "%d\n", get_sex());
+   fprintf(the_file, "%d\n", get_vislvl());
+
    fprintf(the_file, "%d\n", get_speed());
    fprintf(the_file, "%d\n", get_aggression());
 
+   /******** Stuff added for version 0.59.2 *******/
+   fprintf(the_file, "%d\n", get_wimpy());
+   fprintf(the_file, "%d\n", get_max_magic());
+   fprintf(the_file, "%d\n", get_max_endurance());
+   write_ranks(the_file);
+
    tmp_list = tell_list;
    while (tmp_list != NULL)
    {
@@ -163,48 +188,48 @@ void Mobile::describe(Builder *the_builder)
    int counter = 0;
    Com_List *tmp_list;
 
-   the_builder->send_bldr("\n&+GMobile: \t\t&+M%s&*\n", get_name());
-   the_builder->send_bldr("&+GTitle: \t\t\t&+w%s&*\n", get_title());
-   the_builder->send_bldr("&+GAltnames: \t\t&+g%s&*\n", get_altname());
-   the_builder->send_bldr("&+GClones: \t\t&+g%s&*\n", get_clones());
-   the_builder->send_bldr("&+GSpecials: \t\t&+g%s&*\n", get_special_str());
-   the_builder->send_bldr("&+GLocation (Starting): \t&+M%s&*\n", 
-                                                        get_location());
-   the_builder->send_bldr("&+GSubareas: \t\t&+g%s&*\n", get_subarea());
-   the_builder->send_bldr("&+GBareWeapon: \t\t&+w%s&*\n", 
-                                                  get_bare_weapon());
-   the_builder->send_bldr("&+GWield(Left): \t\t&+M%s&*\n", 
-                                                  get_start_wield(Left));
-   the_builder->send_bldr("&+GWield(Right): \t\t&+M%s&*\n", 
-                                                  get_start_wield(Right));
-   the_builder->send_bldr("&+GWear: \t\t\t&+M%s&*\n", get_start_wear());
-   the_builder->send_bldr("&+GSpeed: \t\t\t&+w%d&*\n", get_speed());
-   the_builder->send_bldr("&+GAggression: \t\t&+w%d&*\n", get_aggression());
-   the_builder->send_bldr("&+GStrength: \t\t&+w%d&*\n", get_strength());
-   the_builder->send_bldr("&+GDexterity: \t\t&+w%d&*\n", get_dexterity());
-   the_builder->send_bldr("&+GConstitution: \t\t&+w%d&*\n", 
-                                                        get_constitution());
-   the_builder->send_bldr("&+GIntel: \t\t\t&+w%d&*\n", get_intel());
-   the_builder->send_bldr("&+GWisdom: \t\t&+w%d&*\n", get_wisdom());
-   the_builder->send_bldr("&+GCharisma: \t\t&+w%d&*\n", get_charisma());
+   the_builder->send_bldr("\n&+G      Mobile: &+M%s&*\n", get_name());
+   the_builder->send_bldr("&+G       Title: &+w%s&*\n", get_title());
+   the_builder->send_bldr("&+G    Altnames: &+g%s&*\n", get_altname());
+   the_builder->send_bldr("&+G      Clones: &+g%s&*\n", get_clones());
+   the_builder->send_bldr("&+G    Specials: &+g%s&*\n", get_special_str());
+   the_builder->send_bldr("&+G    Subareas: &+g%s&*\n", get_subarea());
+   the_builder->send_bldr("&+G  BareWeapon: &+w%s&*\n", get_bare_weapon());
+   the_builder->send_bldr("&+G    StartLoc: &+M%s&*\n", get_location());
+   the_builder->send_bldr("&+G Wield(Left): &+M%s&*\n", get_start_wield(Left));
+   the_builder->send_bldr("&+GWield(Right): &+M%s&*\n", get_start_wield(Right));
+   the_builder->send_bldr("&+G        Wear: &+M%s&*\n", get_start_wear());
+   the_builder->send_bldr("&+G       Speed: &+w%d&*\n", get_speed());
+   the_builder->send_bldr("&+G         Sex: &+w%s&*\n", get_sex_str());
+   the_builder->send_bldr("&+G  Aggression: &+w%d&*\n", get_aggression());
+   the_builder->send_bldr("&+G    Strength: &+w%d&*\n", get_strength());
+   the_builder->send_bldr("&+G   Dexterity: &+w%d&*\n", get_dexterity());
+   the_builder->send_bldr("&+GConstitution: &+w%d&*\n", get_constitution());
+   the_builder->send_bldr("&+G       Intel: &+w%d&*\n", get_intel());
+   the_builder->send_bldr("&+G      Wisdom: &+w%d&*\n", get_wisdom());
+   the_builder->send_bldr("&+G    Charisma: &+w%d&*\n", get_charisma());
+   the_builder->send_bldr("&+G       Wimpy: &+w%d&*\n", get_wimpy());
+   the_builder->send_bldr("&+G    MaxMagic: &+w%d&*\n", get_max_magic());
+   the_builder->send_bldr("&+G    MaxEndur: &+w%d&*\n", get_max_endurance());
    the_builder->send_bldr("&+GBrief:&*\n%s\n", get_brief());
    the_builder->send_bldr("&+GDesc:&*\n%s\n", get_desc());
 
    the_builder->send_bldr("\n");
 
    if (get_shop() != NULL)
-      the_builder->send_bldr("&+G\nShop assigned with name&+W: &+w%s\n\n", 
-                                        the_shop->get_name());
+      the_builder->send_bldr("&+G\nShop assigned with name&+W: &+w%s\n\n", the_shop->get_name());
+
+   if (get_ranks() != NULL)
+     the_builder->send_bldr("&+GThis mobile has proficiencies assigned to it.&*\n");
 
    tmp_list = tell_list;
+   
    while (tmp_list != NULL)
    {
       counter++;
       the_builder->send_bldr("&+GTell Reply [&+B%d&+G]:\n", counter);
-      the_builder->send_bldr("   &+GKeywords: &+g%s\n", 
-                                         tmp_list->the_keywords.str_show());
-      the_builder->send_bldr("   &+GReply: \n\t&+w%s&*\n", 
-                                         tmp_list->the_reply.str_show());
+      the_builder->send_bldr("   &+GKeywords: &+g%s\n", tmp_list->the_keywords.str_show());
+      the_builder->send_bldr("   &+GReply: \n\t&+w%s&*\n", tmp_list->the_reply.str_show());
       tmp_list = tmp_list->next_com;
    }
 }
@@ -224,64 +249,59 @@ void Mobile::describe(Player *the_player)
    MudObject *tmp_container;
    Strings   container_name;
 
-   the_player->send_plr("\n&+GMobile: \t\t&+M%s&*\n", get_name());
-   the_player->send_plr("&+GTitle: \t\t\t&+w%s&*\n", get_title());
-   the_player->send_plr("&+GKeywords: \t\t&+w%s&*\n", get_keywords());
-   the_player->send_plr("&+GAltnames: \t\t&+g%s&*\n", get_altname());
-   the_player->send_plr("&+GClones: \t\t&+g%s&*\n", get_clones());
-   the_player->send_plr("&+GSpecials: \t\t&+g%s&*\n", get_special_str());
-   the_player->send_plr("&+GStartLoc: \t\t&+M%s&*\n", get_location());
+   the_player->send_plr("\n&+G      Mobile: &+M%s&*\n", get_name());
+   the_player->send_plr("&+G       Title: &+w%s&*\n", get_title());
+   the_player->send_plr("&+G    Keywords: &+w%s&*\n", get_keywords());
+   the_player->send_plr("&+G    Altnames: &+g%s&*\n", get_altname());
+   the_player->send_plr("&+G      Clones: &+g%s&*\n", get_clones());
+   the_player->send_plr("&+G    Specials: &+g%s&*\n", get_special_str());
+   the_player->send_plr("&+G    StartLoc: &+M%s&*\n", get_location());
 
    tmp_container = get_contained_by();
    if (tmp_container == NULL)
       container_name = "nowhere";
    else
-      container_name.sprintf("%s@%s", tmp_container->get_name(), 
-                                         tmp_container->get_area());
+      container_name.sprintf("%s@%s", tmp_container->get_name(), tmp_container->get_area());
 
-   the_player->send_plr("&+GCurrentLoc: \t\t&+M%s&*\n", 
-                                                 container_name.str_show());
-
-   the_player->send_plr("&+GSubareas: \t\t&+g%s&*\n", get_subarea());
-   the_player->send_plr("&+GBareWeapon: \t\t&+w%s&*\n", 
-                                                  get_bare_weapon());
-   the_player->send_plr("&+GWield(Left): \t\t&+M%s&*\n", 
-                                                  get_start_wield(Left));
-   the_player->send_plr("&+GWield(Right): \t\t&+M%s&*\n", 
-                                                  get_start_wield(Right));
-   the_player->send_plr("&+GWear: \t\t\t&+M%s&*\n", get_start_wear());
-   the_player->send_plr("&+GSpeed: \t\t\t&+w%d&*\n", get_speed());
-   the_player->send_plr("&+GAggression: \t\t&+w%d&*\n", get_aggression());
-   the_player->send_plr("&+GStrength: \t\t&+w%d&*\n", get_strength());
-   the_player->send_plr("&+GConstitution: \t\t&+w%d&*\n", 
-                                                    get_constitution());
-   the_player->send_plr("&+GDexterity: \t\t&+w%d&*\n", get_dexterity());
-   the_player->send_plr("&+GHealth: \t\t&+w%d\\&+W%d&*\n", 
-                                          get_health(), get_maxhealth());
-   the_player->send_plr("&+GIntel: \t\t\t&+w%d&*\n", get_intel());
-   the_player->send_plr("&+GWisdom: \t\t&+w%d&*\n", get_wisdom());
-   the_player->send_plr("&+GCharisma: \t\t&+w%d&*\n", get_charisma());
+   the_player->send_plr("&+G  CurrentLoc: &+M%s&*\n", container_name.str_show());
+   the_player->send_plr("&+G    Subareas: &+g%s&*\n", get_subarea());
+   the_player->send_plr("&+G  BareWeapon: &+w%s&*\n", get_bare_weapon());
+   the_player->send_plr("&+G Wield(Left): &+M%s&*\n", get_start_wield(Left));
+   the_player->send_plr("&+GWield(Right): &+M%s&*\n", get_start_wield(Right));
+   the_player->send_plr("&+G        Wear: &+M%s&*\n", get_start_wear());
+   the_player->send_plr("&+G       Speed: &+w%d&*\n", get_speed());
+   the_player->send_plr("&+G         Sex: &+w%s&*\n", get_sex_str());
+   the_player->send_plr("&+G  Aggression: &+w%d&*\n", get_aggression());
+   the_player->send_plr("&+G    Strength: &+w%d&*\n", get_strength());
+   the_player->send_plr("&+GConstitution: &+w%d&*\n", get_constitution());
+   the_player->send_plr("&+G   Dexterity: &+w%d&*\n", get_dexterity());
+   the_player->send_plr("&+G      Health: &+w%d\\&+W%d&*\n", get_health(), get_maxhealth());
+   the_player->send_plr("&+G       Intel: &+w%d&*\n", get_intel());
+   the_player->send_plr("&+G      Wisdom: &+w%d&*\n", get_wisdom());
+   the_player->send_plr("&+G    Charisma: &+w%d&*\n", get_charisma());
+   the_player->send_plr("&+G       Wimpy: &+w%d&*\n", get_wimpy());
+   the_player->send_plr("&+G    MaxMagic: &+w%d&*\n", get_max_magic());
+   the_player->send_plr("&+G    MaxEndur: &+w%d&*\n", get_max_endurance());
+   the_player->send_plr("&+Y        Size: &+W%d&*\n", get_mem_size());
    the_player->send_plr("&+GBrief:&*\n%s\n", get_brief());
    the_player->send_plr("&+GDesc:&*\n%s\n", get_desc());
-   the_player->send_plr("&+YSize: \t\t\t&+W%d&*\n", get_mem_size());
 
    list_specials(the_player);
-
    the_player->send_plr("\n");
 
    if (get_shop() != NULL)
-      the_player->send_plr("&+G\nShop assigned with name&+W: &+w%s\n\n", 
-                                        the_shop->get_name());
+      the_player->send_plr("&+G\nShop assigned with name&+W: &+w%s\n\n", the_shop->get_name());
+
+   if (get_ranks() != NULL)
+     the_player->send_plr("&+GThis mobile has proficiencies assigned to it.&*\n");
 
    tmp_list = tell_list;
    while (tmp_list != NULL)
    {
       counter++;
       the_player->send_plr("&+GTell Reply [&+B%d&+G]:\n", counter);
-      the_player->send_plr("   &+GKeywords: &+g%s\n", 
-                                         tmp_list->the_keywords.str_show());
-      the_player->send_plr("   &+GReply: \n\t&+w%s&*\n", 
-                                         tmp_list->the_reply.str_show());
+      the_player->send_plr("   &+GKeywords: &+g%s\n", tmp_list->the_keywords.str_show());
+      the_player->send_plr("   &+GReply: \n\t&+w%s&*\n", tmp_list->the_reply.str_show());
       tmp_list = tmp_list->next_com;
    }
 }
@@ -301,16 +321,16 @@ int Mobile::set_attrib(Builder *the_builder, Parse *the_parsed){
 
    if (the_parsed->get_target1() == NULL)
    {   the_builder->
-           send_bldr("You can set the following attributes on a merger.\n"
-       "   title, altnames, desc, location, indflags, clones, brief,\n"
+           send_bldr("You can set the following attributes on a mobile.\n"
+       "   title, altnames, desc, location, indflags, clones, brief, sex,\n"
        "   subareas, wear, speed, aggression, strength, dexterity,\n "
        "   constitution, reply, currency, itemname, wielded, specials, \n"
-       "   intel, wisdom, charisma, value, numberof and type");
+       "   intel, wisdom, charisma, wimpy, maxmagic, maxendur, value, \n"
+       "   numberof, type, profname, rank and probability");
        return -1;
    }
 
-   if (!STRNCASECMP(the_parsed->get_target1(), "title",
-                               strlen(the_parsed->get_target1())))
+   if (!STRNCASECMP(the_parsed->get_target1(), "title", strlen(the_parsed->get_target1())))
    {
       return set_attrib_title(the_parsed, the_builder);
    }
@@ -598,22 +618,19 @@ int Mobile::set_attrib(Builder *the_builder, Parse *the_parsed){
                                  get_aggression(), get_name());
       return 1;
    }
-   if (!STRNCASECMP(the_parsed->get_target1(), "strength",
-                               strlen(the_parsed->get_target1())))
+   if (!STRNCASECMP(the_parsed->get_target1(), "strength", strlen(the_parsed->get_target1())))
    {
       int the_strength;
 
       if (the_parsed->get_speech() == NULL)
       {
-         the_builder->
-                  send_bldr("You need to specify a number for strength.\n");
+         the_builder->send_bldr("You need to specify a number for strength.\n");
          return -1;
       }
  
       if (!isdigit(*(the_parsed->get_speech()))) 
       {
-         the_builder->
-              send_bldr("You need to specify strength as a number.\n");
+         the_builder->send_bldr("You need to specify strength as a number.\n");
          return -1;
       }
 
@@ -625,10 +642,35 @@ int Mobile::set_attrib(Builder *the_builder, Parse *the_parsed){
       }      
 
       set_strength(the_strength);
-      the_builder->send_bldr("Strength set to %d on mobile object %s.\n",
-                                 get_strength(), get_name());
+      the_builder->send_bldr("Strength set to %d on mobile object %s.\n",get_strength(), get_name());
       return 1;
    }
+    if (!STRNCASECMP(the_parsed->get_target1(), "sex", strlen(the_parsed->get_target1())))
+    {
+        if (the_parsed->get_speech() == NULL)
+        {
+            the_builder->send_bldr("You need to specify a sex to set to.\n");
+            return -1;
+        }
+        if (!STRNCASECMP(the_parsed->get_speech(), "male", strlen(the_parsed->get_speech()))) {
+            the_builder->send_bldr("Sex changed from %s to male.\n", get_sex_str());
+            set_sex(SEX_MALE);
+        }
+        else if (!STRNCASECMP(the_parsed->get_speech(), "female", strlen(the_parsed->get_speech()))) {
+            the_builder->send_bldr("Sex changed from %s to female.\n", get_sex_str());
+            set_sex(SEX_FEMALE);
+        }
+        else if (!STRNCASECMP(the_parsed->get_speech(), "neuter", strlen(the_parsed->get_speech()))) {
+            the_builder->send_bldr("Sex changed from %s to neuter.\n", get_sex_str());
+            set_sex(SEX_NEUTER);
+        }
+        else {
+            the_builder->send_bldr("Valid sexes are male, female, and neuter.\n");
+            return -1;
+        }
+
+        return 1;
+    }
    if (!STRNCASECMP(the_parsed->get_target1(), "dexterity",
                                strlen(the_parsed->get_target1())))
    {
@@ -691,6 +733,98 @@ int Mobile::set_attrib(Builder *the_builder, Parse *the_parsed){
                                  get_constitution(), get_name());
       return 1;
    }
+   if (!STRNCASECMP(the_parsed->get_target1(), "wimpy",
+                               strlen(the_parsed->get_target1())))
+   {
+      int the_wimpy;
+
+      if (the_parsed->get_speech() == NULL)
+      {
+         the_builder->send_bldr("You need to specify a number for wimpy.\n");
+         return -1;
+      }
+ 
+      if (!isdigit(*(the_parsed->get_speech()))) 
+      {
+         the_builder->
+              send_bldr("You need to specify wimpy as a number ( >= 0 ).\n");
+         return -1;
+      }
+
+      the_wimpy = atoi(the_parsed->get_speech());
+      if (the_wimpy < 0)
+      {
+         the_builder->send_bldr("Wimpy must be greater than or equal to 0.\n");
+         return -1;
+      }      
+
+      set_wimpy(the_wimpy);
+      the_builder->send_bldr("Wimpy set to %d on mobile object %s.\n",
+			                          get_wimpy(), get_name());
+      return 1;
+   }
+   if (!STRNCASECMP(the_parsed->get_target1(), "maxmagic",
+                               strlen(the_parsed->get_target1())))
+   {
+      int max_magic;
+
+      if (the_parsed->get_speech() == NULL)
+      {
+         the_builder->send_bldr("You need to specify a number for MaxMagic.\n");
+         return -1;
+      }
+ 
+      if (!isdigit(*(the_parsed->get_speech()))) 
+      {
+         the_builder->
+              send_bldr("You need to specify MaxMagic as a number ( >= 0 ).\n");
+         return -1;
+      }
+
+      max_magic = atoi(the_parsed->get_speech());
+      if (max_magic < 0)
+      {
+         the_builder->send_bldr("MaxMagic must be greater than or equal to 0.\n");
+         return -1;
+      }      
+
+      set_max_magic(max_magic);
+      the_builder->send_bldr("MaxMagic set to %d on mobile object %s.\n",
+			                          get_max_magic(), get_name());
+      return 1;
+   }
+   if (!STRNCASECMP(the_parsed->get_target1(), "maxendur",
+                               strlen(the_parsed->get_target1())))
+   {
+      int max_endur;
+
+      if (the_parsed->get_speech() == NULL)
+      {
+         the_builder->send_bldr("You need to specify a number for MaxEndur.\n");
+         return -1;
+      }
+ 
+      if (!isdigit(*(the_parsed->get_speech()))) 
+      {
+         the_builder->
+              send_bldr("You need to specify MaxEndur as a number ( >= 0 ).\n");
+         return -1;
+      }
+
+      max_endur = atoi(the_parsed->get_speech());
+      if (max_endur < 0)
+      {
+         the_builder->send_bldr("MaxEndur must be greater than or equal to 0.\n");
+         return -1;
+      }      
+
+      set_max_endurance(max_endur);
+      the_builder->send_bldr("MaxEndur set to %d on mobile object %s.\n",
+			                          get_max_endurance(), get_name());
+      return 1;
+   }
+
+
    if (!STRNCASECMP(the_parsed->get_target1(), "reply",
                     strlen(the_parsed->get_target1())))
    {  Strings   tmp_str;
@@ -742,6 +876,192 @@ int Mobile::set_attrib(Builder *the_builder, Parse *the_parsed){
       set_modified(1);
       return 1;
    }
+   if (!STRNCASECMP(the_parsed->get_target1(), "profname",
+                    strlen(the_parsed->get_target1())))
+   {  Strings   tmp_str;
+      Strings   tmp_word;
+      Strings   new_name;
+      int       profnr;
+      rank_list *tmp_list;
+      int       counter = 1;
+
+      tmp_str = the_parsed->get_speech();
+
+      tmp_word.assign_word(tmp_str.str_show(), 1);
+      new_name.assign_word(tmp_str.str_show(), 2);
+
+      if ((tmp_word.str_show() == NULL) || (new_name.str_show() == NULL))
+      {
+         the_builder->send_bldr("Usage: set profname <nr> <name>\n");
+         return -1;
+      }
+
+      if (isdigit(*(tmp_word.str_show())))
+      {  
+         profnr = atoi(tmp_word.str_show());
+      }
+      else
+      {  the_builder->send_bldr("Usage: set profname <nr> <name>\n");
+         return -1;
+      }
+
+      tmp_list = get_ranks();
+
+      while (tmp_list != NULL)
+      {
+         if (counter == profnr)
+            break;
+         tmp_list = tmp_list->next_rank;
+         counter++;
+      }
+      if ((counter != profnr) || (tmp_list == NULL))
+      {
+         the_builder->send_bldr("That proficiency doesn't exist.\n");
+         return -1;
+      }
+      
+      tmp_list->rank_name = new_name.str_show();
+
+      the_builder->send_bldr("Proficiency %d profname set to: %s\n", 
+                        profnr,  tmp_list->rank_name.str_show());
+     
+      set_modified(1);
+      return 1;
+   }
+   if (!STRNCASECMP(the_parsed->get_target1(), "rank",
+                    strlen(the_parsed->get_target1())))
+   {  Strings   tmp_str;
+      Strings   tmp_word;
+      Strings   new_rank;
+      int       profnr;
+      int       ranknum;
+      rank_list *tmp_list;
+      int       counter = 1;
+
+      tmp_str = the_parsed->get_speech();
+
+      tmp_word.assign_word(tmp_str.str_show(), 1);
+      new_rank.assign_word(tmp_str.str_show(), 2);
+
+      if ((tmp_word.str_show() == NULL) || (new_rank.str_show() == NULL))
+      {
+         the_builder->send_bldr("Usage: set rank <nr> <ranknr>\n");
+         return -1;
+      }
+
+      if (isdigit(*(tmp_word.str_show())))
+      {  
+         profnr = atoi(tmp_word.str_show());
+      }
+      else
+      {  the_builder->send_bldr("Usage: set rank <nr> <ranknr>\n");
+         return -1;
+      }
+
+      if (isdigit(*(new_rank.str_show())))
+      {  
+         ranknum = atoi(new_rank.str_show());
+      }
+      else
+      {  the_builder->send_bldr("Usage: set rank <nr> <ranknr>\n");
+         return -1;
+      }
+
+      tmp_list = get_ranks();
+
+      while (tmp_list != NULL)
+      {
+         if (counter == profnr)
+            break;
+         tmp_list = tmp_list->next_rank;
+         counter++;
+      }
+      if ((counter != profnr) || (tmp_list == NULL))
+      {
+         the_builder->send_bldr("That proficiency doesn't exist.\n");
+         return -1;
+      }
+      
+      if (ranknum < 0)
+      {
+	the_builder->send_bldr("Rank must be greater than 0.\n");
+	return -1;
+      }
+      
+      tmp_list->the_rank = ranknum;
+      the_builder->send_bldr("Proficiency %d rank set to: %d\n", 
+                        profnr,  tmp_list->the_rank);
+     
+      set_modified(1);
+      return 1;
+   }
+   if (!STRNCASECMP(the_parsed->get_target1(), "probability",
+                    strlen(the_parsed->get_target1())))
+   {  Strings   tmp_str;
+      Strings   tmp_word;
+      Strings   new_prob;
+      int       probnr;
+      int       probnum;
+      rank_list *tmp_list;
+      int       counter = 1;
+
+      tmp_str = the_parsed->get_speech();
+
+      tmp_word.assign_word(tmp_str.str_show(), 1);
+      new_prob.assign_word(tmp_str.str_show(), 2);
+
+      if ((tmp_word.str_show() == NULL) || (new_prob.str_show() == NULL))
+      {
+         the_builder->send_bldr("Usage: set probability <nr> <probability>\n");
+         return -1;
+      }
+
+      if (isdigit(*(tmp_word.str_show())))
+      {  
+         probnr = atoi(tmp_word.str_show());
+      }
+      else
+      {  the_builder->send_bldr("Usage: set probability <nr> <probability>\n");
+         return -1;
+      }
+
+      if (isdigit(*(new_prob.str_show())))
+      {  
+         probnum = atoi(new_prob.str_show());
+      }
+      else
+      {  the_builder->send_bldr("Usage: set probability <nr> <probability>\n");
+         return -1;
+      }
+
+      tmp_list = get_ranks();
+
+      while (tmp_list != NULL)
+      {
+         if (counter == probnr)
+            break;
+         tmp_list = tmp_list->next_rank;
+         counter++;
+      }
+      if ((counter != probnr) || (tmp_list == NULL))
+      {
+         the_builder->send_bldr("That proficiency doesn't exist.\n");
+         return -1;
+      }
+      
+      if ((probnum < 0) || (probnum > 100))
+      {
+	the_builder->send_bldr("Probability must be between 0 and 100.\n");
+	return -1;
+      }
+      
+      tmp_list->the_exp_prob = probnum;
+      the_builder->send_bldr("Proficiency %d probability set to: %d\n", 
+                        probnr,  tmp_list->the_exp_prob);
+     
+      set_modified(1);
+      return 1;
+   }
    if (!STRNCASECMP(the_parsed->get_target1(), "currency",
                                strlen(the_parsed->get_target1())))
    {
@@ -1309,7 +1629,7 @@ int Mobile::check_mobile(void)
             holder.sprintf("%s enters the room.\n", mob_name.str_show());
             new_loc->send_location(holder.str_show(), NULL);
 
-            if (set_location(new_loc, get_loc()) == -1)
+            if (set_location(new_loc) == -1)
             {
                mainstruct->log_error("Could not set mobile location!", 
                                                                "check_mobile");
@@ -1872,8 +2192,7 @@ char *Mobile::get_start_wear()
  **
  ***********************************************************************/
 
-int Mobile::read_mobile_attrib(FILE *read_file, ErrLog *error_log, 
-                                                        int for_build_port)
+int Mobile::read_mobile_attrib(FILE *read_file, ErrLog *error_log, int for_build_port)
 {
    token_record *the_token;
    Strings      holder;
@@ -1947,9 +2266,7 @@ int Mobile::read_mobile_attrib(FILE *read_file, ErrLog *error_log,
    the_token = get_token(read_file, '\0');
    if (the_token->token_type != T_NUMERICAL)
    {
-      holder.
-         sprintf("Invalid format for attribute dexterity in mudobject %s", 
-                                                              get_name());
+      holder.sprintf("Invalid format for attribute dexterity in mudobject %s", get_name());
       error_log->log_err(holder.str_show(), "read_mobile_attrib");
       return -1;
    }
@@ -2015,9 +2332,27 @@ int Mobile::read_mobile_attrib(FILE *read_file, ErrLog *error_log,
    indflags->clr_frozen(indflagfrozen);
    indflags->set_flag(INDFLAG_ATTACKPLAYER);
 
+   // Set sex
+   the_token = get_token(read_file, '\0');
+   if (the_token->token_type != T_NUMERICAL)
+   {
+       holder.sprintf("Invalid format for attribute sex in mudobject %s", get_name());
+       error_log->log_err(holder.str_show(), "read_mobile_attrib");
+       return -1;
+   }
+   set_sex(atoi(the_token->the_string));
+
+   the_token = get_token(read_file, '\0');
+   if (the_token->token_type != T_NUMERICAL)
+   {
+       holder.sprintf("Invalid format for attribute vislvl in mudobject %s", get_name());
+       error_log->log_err(holder.str_show(), "read_mobile_attrib");
+       return -1;
+   }
+   set_vislvl(atoi(the_token->the_string));
+
    /* Set speed */
    the_token = get_token(read_file, '\0');
-     
    if (the_token->token_type != T_NUMERICAL)
    {
       holder.sprintf("Invalid format for attribute speed in mudobject %s", 
@@ -2039,7 +2374,50 @@ int Mobile::read_mobile_attrib(FILE *read_file, ErrLog *error_log,
       return -1;
    }
    set_aggression(atoi(the_token->the_string));
- 
+
+   /* Set wimpy */
+   the_token = get_token(read_file, '\0');
+     
+   if (the_token->token_type != T_NUMERICAL)
+   {
+      holder.
+         sprintf("Invalid format for attribute wimpy in mudobject %s", 
+                                                                get_name());
+      error_log->log_err(holder.str_show(), "read_mobile_attrib");
+      return -1;
+   }
+   set_wimpy(atoi(the_token->the_string));
+
+   /* Set max_magic */
+   the_token = get_token(read_file, '\0');
+     
+   if (the_token->token_type != T_NUMERICAL)
+   {
+      holder.
+         sprintf("Invalid format for attribute max_magic in mudobject %s", 
+                                                                get_name());
+      error_log->log_err(holder.str_show(), "read_mobile_attrib");
+      return -1;
+   }
+   set_max_magic(atoi(the_token->the_string));
+
+   /* Set max_endurance */
+   the_token = get_token(read_file, '\0');
+     
+   if (the_token->token_type != T_NUMERICAL)
+   {
+      holder.
+         sprintf("Invalid format for attribute max_endurance in mudobject %s", 
+                                                                get_name());
+      error_log->log_err(holder.str_show(), "read_mobile_attrib");
+      return -1;
+   }
+   set_max_endurance(atoi(the_token->the_string));
+
+   // Read all ranks of abilities or combat skills
+   if (read_ranks(read_file) < 0)
+     return -1;
+
    /* get the talk structs */
    the_token = get_token(read_file,'\0');
    while (the_token->token_type != T_POUND)
@@ -2119,7 +2497,7 @@ int Mobile::start_wield(Object_List *obj_dbase, ErrLog *error_log)
 {
    playerhand the_hand = Left;
    MudObject  *wield_obj;
-   LinkedList *the_inv;
+   Inventory  *the_inv;
    Strings    holder;
    MudObject  *new_obj;
    int        i;
@@ -2173,7 +2551,7 @@ int Mobile::start_wield(Object_List *obj_dbase, ErrLog *error_log)
 
 int Mobile::start_wear(Object_List *obj_dbase, ErrLog *error_log)
 {
-   LinkedList *the_inv;
+   Inventory  *the_inv;
    Strings    holder;
    MudObject  *new_obj;
    MudObject  *wear_obj;
@@ -2242,7 +2620,7 @@ int Mobile::check_aggression(Individual *the_ind)
 {
    Individual *attack_them;
    MudObject  *tmp_obj;
-   LinkedList *in_room;
+   Inventory  *in_room;
    Strings    holder;
    MudObject  *attack_obj = NULL;
    Flags      *tmp_indflags;
@@ -2254,6 +2632,11 @@ int Mobile::check_aggression(Individual *the_ind)
    if (tmp_indflags->get_flag(INDFLAG_FIGHTING))
       return 0;
 
+   // If they are dead, no attack, that would be silly
+   if ((tmp_indflags->get_flag(INDFLAG_CORPSE)) ||
+       (tmp_indflags->get_flag(INDFLAG_GHOST)))
+     return 0;
+
    if (((get_loc())->get_locflags())->get_flag(LOCFLAG_PEACEFUL))
    {
       return 0;
@@ -2330,7 +2713,7 @@ int Mobile::check_aggression(Individual *the_ind)
 int Mobile::check_get()
 {
    Flags      *tmp_indflags;
-   LinkedList *in_room;
+   Inventory  *in_room;
    MudObject  *tmp_obj;
 
    tmp_indflags = get_indflags();
@@ -2501,6 +2884,18 @@ int Mobile::get_mem_size()
    return size;
 }
 
+/***********************************************************************
+ ** send_plr - as this is not a player, does nothing if called
+ **
+ ** Returns: 1 for success, -1 for failure
+ **
+ ***********************************************************************/
+
+int Mobile::send_plr(char *new_str, ...)
+{
+  return 1;
+}
+
 /***********************************************************************
  ** get_mem_size_dynamic - gets how much memory is taken up by pointers
  **                        pointing to other objects, not including the
@@ -2540,4 +2935,96 @@ int Mobile::get_mem_size_dynamic()
    return size;
 }
 
+
+/***********************************************************************
+ ** attack - attacks another individual by choosing an attack (spell, skill,
+ **          or swinging the weapon) and using it
+ **
+ ** Returns: 1 for success, -1 for failure
+ **
+ ***********************************************************************/
+
+int Mobile::attack(Individual *target)
+{
+  rank_list *tmp_rank;
+  int       rand_num;
+  Ability   *the_ability;
+
+  if ((get_target() == NULL) || (get_target()->get_loc() != get_loc()))
+  {
+    stop_fighting();
+    return 0;
+  }
+
+  // First, lets check their spells and skills to see if its a castin time!
+  tmp_rank = get_ranks();
+  while (tmp_rank != NULL)
+  {
+    if ((tmp_rank->the_type == OBJ_TYPE_SPELL) || 
+	(tmp_rank->the_type == OBJ_TYPE_SKILL))
+    {
+      // If random chance happens to specify using this ability
+      rand_num = (int) (100.0*(rand()/(RAND_MAX+1.0)));
+      if (rand_num < tmp_rank->the_exp_prob)
+      {
+
+	// If this ability doesn't seem to exist, go onto the next one
+	if ((the_ability = 
+	     mainstruct->get_ability(tmp_rank->rank_name.str_show())) == NULL)
+	{ 
+	  tmp_rank = tmp_rank->next_rank;
+	  continue;
+	}
+
+	// If they don't have enough juice to use this, go onto the next one
+	if (((the_ability->get_type() == OBJ_TYPE_SPELL) && 
+	     (the_ability->get_drain() > get_magic())) || 
+	    ((the_ability->get_type() == OBJ_TYPE_SKILL) && 
+	     (the_ability->get_drain() > get_endurance())))
+	{
+	  tmp_rank = tmp_rank->next_rank;
+	  continue;
+	}
+
+        return the_ability->use_ability(this, target, NULL);
+      }
+    }
+    tmp_rank = tmp_rank->next_rank;
+  }
+
+  return use_weapon(target);
+}
+
+
+/***********************************************************************
+ ** coord_ranks - coordinates the ranks in a mobile, setting the types
+ **               if it can figure it out
+ **
+ ** Returns: 1 for success, -1 for failure
+ **
+ ***********************************************************************/
+
+int Mobile::coord_ranks(Object_List *the_dbase)
+{
+  rank_list *tmp_rank;
+  Ability *the_ability;
+
+  tmp_rank = get_ranks();
+  while (tmp_rank != NULL)
+  {
+    if ((the_ability = 
+	 the_dbase->get_ability_obj(tmp_rank->rank_name.str_show())) != NULL)
+    {
+      tmp_rank->the_type = the_ability->get_type();
+    }
+    else
+      tmp_rank->the_type = OBJ_TYPE_WEAPON;
+
+    tmp_rank = tmp_rank->next_rank;
+  }
+  return 1;
+}
+
+
 #endif
+
