@@ -93,6 +93,12 @@ MudObject::~MudObject()
 {
    special_holder *tmp_special;
 
+   // First, if it is still contained, we fault
+   if (contained_by != NULL)
+   {
+     fault("Object being deleted still contained in something.");
+   }
+
    /* delete the special holders */
    tmp_special = special_list;
    while (tmp_special != NULL)
@@ -220,6 +226,9 @@ int MudObject::find_contained(MudObject *the_obj)
 int MudObject::remove_contained(MudObject *the_object)
 {
 
+   if (the_object == NULL)
+     return 0;
+
    if ((get_type() == OBJ_TYPE_PLAYER) || (get_type() == OBJ_TYPE_MOBILE))
    {
       Individual *the_ind;
@@ -233,12 +242,25 @@ int MudObject::remove_contained(MudObject *the_object)
 
    }
 
+   // If it doesn't look like it is a reload all, clear the location string
+   if (the_object->get_type() != OBJ_TYPE_DOOR)
+   {
+     if ((the_object->get_type() != OBJ_TYPE_PLAYER)||
+	 ((Individual *) the_object)->get_loc() != NULL)
+     {
+        the_object->set_loc_str("none");
+     }
+   }
+
    if ((the_object->get_type() == OBJ_TYPE_PLAYER) || 
        (the_object->get_type() == OBJ_TYPE_MOBILE))
       ((Individual *)the_object)->clr_curr_loc();
 
-
-   the_object->set_contained_by(NULL);
+   if ((the_object->get_type() == OBJ_TYPE_ROPE) && 
+       (((Rope *)the_object)->get_other_loc() == this))
+     ((Rope*) the_object)->set_other_loc(NULL);
+   else
+     the_object->set_contained_by(NULL);
 
    return inventory.del_entry(the_object);
 }
@@ -258,9 +280,6 @@ int MudObject::add_contained(MudObject *the_object)
    Merger *add_merger;
    int    old_value = 0;
 
-   if (!STRNCASECMP(the_object->get_name(), "bridge", 6))
-      raise(11);
-
    if (the_object->is_merger())
    {
       add_merger = (Merger *) the_object;
@@ -289,7 +308,7 @@ int MudObject::add_contained(MudObject *the_object)
  ** Returns:  1 if success, 0 if not
  **
  ***********************************************************************/
-LinkedList *MudObject::get_inventory()
+Inventory *MudObject::get_inventory()
 {   return &inventory;
 }
 
@@ -333,56 +352,36 @@ int MudObject::add_special_holder(special_holder *new_holder)
  ** set_location - sets the location for an object
  **
  ** Parameters: new_loc - the new location for the object
- **             prev_loc - the old location, so we can remove it
  **
  ** Returns:  1 if success
  **          -1 if failure
  **
  ***********************************************************************/
 
-int MudObject::set_location(MudObject *new_loc, MudObject *prev_loc)
+int MudObject::set_location(MudObject *new_loc)
 {
-   if ((prev_loc != NULL) && (!prev_loc->remove_contained(this)))
-   {  
-      printf("Obj %s has previous loc, but was not contained in that loc\n", 
-                                                                 get_name());
-      return -1;
-   }
-
-   if (new_loc != NULL)
-   {
-      new_loc->add_contained(this);
-   }
-
-   if (new_loc != NULL)
-      location.sprintf("%s@%s", new_loc->get_name(), new_loc->get_area());  
-   else
-      location = "none";
-
-   if ((get_type() == OBJ_TYPE_PLAYER) || 
-       (get_type() == OBJ_TYPE_MOBILE))
-   {
-      Individual *the_ind;
-
-      if (new_loc->get_type() != OBJ_TYPE_LOCATION)
-      {
-         if (new_loc->get_type() == OBJ_TYPE_BOAT)
-            new_loc = new_loc->get_contained_by();
-         
-         if (new_loc->get_type() != OBJ_TYPE_LOCATION)
-	 {
-            printf("attempt to assign individual to non-location\n");
-            return -1;
-	 }
-      }
-
-      the_ind = (Individual *) this;
-      the_ind->set_curr_loc((Location *) new_loc);
-   }
-
-   return 1;   
+  fault("Error, mudobject set_location function called.  It never should be.\n");
+  return -1;
 }
 
+/***********************************************************************
+ ** set_loc_str - sets the location string to a specified location
+ **
+ ** Parameters: the_loc - the new loc to set it to
+ **
+ ** Returns:  1 if success
+ **          -1 if failure
+ **
+ ***********************************************************************/
+
+int MudObject::set_loc_str(char *the_loc)
+{
+  /*  if ((!STRCASECMP(the_loc, "none")) &&
+      (!STRCASECMP(get_name(), "slate")))
+      raise(11);*/
+  location = the_loc;
+  return 1;
+}
 
 /***********************************************************************
  ** set_dual_loc - sets the object to a location, but also sets it as
@@ -402,56 +401,8 @@ int MudObject::set_location(MudObject *new_loc, MudObject *prev_loc)
 int MudObject::set_dual_loc(char *loc1_name, char *loc2_name, 
                                                   Object_List *the_dbase)
 {
-   MudObject *tmp_obj;
-   LinkedList *the_inv;
-   MudObject *loc1;
-   MudObject *loc2;
-
-   if ((loc1_name == NULL) || (loc2_name == NULL))
-      return -1;
-
-   if ((loc1 = the_dbase->get_mudobject(get_area(), loc1_name)) == NULL)
-   {
-      return -1;
-   }
-
-   if ((loc2 = the_dbase->get_mudobject(get_area(), loc2_name)) == NULL)
-   {
-      return -1;
-   }
-
-   the_inv = loc1->get_inventory();
-   the_inv->reset_current();
-   tmp_obj = the_inv->get_next();
-   while ((tmp_obj != NULL) && (tmp_obj != this))
-   {
-      tmp_obj = the_inv->get_next();
-   }
-
-   /* if it is null, it is not already in location 1 */
-   if (tmp_obj == NULL)
-   {
-      loc1->add_contained(this);
-      location.sprintf("%s@%s", loc1->get_name(), loc1->get_area());
-   }
-   
-   /* add to location 2, but don't modify the location string since we
-      already did with location 1 */
-   the_inv = loc2->get_inventory();
-   the_inv->reset_current();
-   tmp_obj = the_inv->get_next();
-   while ((tmp_obj != NULL) && (tmp_obj != this))
-   {
-      tmp_obj = the_inv->get_next();
-   }
-
-   /* if it is null, it is not already in location 1 */
-   if (tmp_obj == NULL)
-   {
-      loc2->add_contained(this);
-   }
-   
-   return 1;   
+  fault("Set_dual_loc should not have been called on this object.\n");
+  return -1;
 }
 
 /***********************************************************************
@@ -464,16 +415,18 @@ int MudObject::set_dual_loc(char *loc1_name, char *loc2_name,
  **          -1 if failure
  **
  ***********************************************************************/
-
+// Deprecated I think
+/*
 int MudObject::set_location(char *the_loc)
 {
    location.assign_word(the_loc, 1);
    return 1;
-}
+}*/
 
 
 /***********************************************************************
- ** get_location - gets the location of the object
+ ** get_location - gets the location string of the object
+ ** get_loc_str - same thing, different name
  **
  ** Parameters: None
  **
@@ -486,6 +439,11 @@ char *MudObject::get_location()
    return location.str_show();
 }
 
+char *MudObject::get_loc_str()
+{
+   return get_location();
+}
+
 /***********************************************************************
  ** assign_keywords - assigns the keywords from the string passed in
  **
@@ -971,7 +929,6 @@ int MudObject::set_attrib_title(Parse *the_parsed, Builder *the_builder)
    return 1;
 }
 
-
 /***********************************************************************
  ** set_attrib_altnames - for set attribute command, sets the altname attribute
  **
@@ -1035,9 +992,9 @@ int MudObject::set_attrib_loc(Parse *the_parsed, Builder *the_builder)
       the_builder->send_bldr("You need to specify a location to set to.\n");
       return -1;
    }
-   set_location(the_parsed->get_speech());
+   set_loc_str(the_parsed->get_speech());
    the_builder->send_bldr("Location on %s set to: %s\n", get_name(), 
-                                                        get_location());
+                                                        get_loc_str());
    set_modified(1);
    return 1;
 }
@@ -1128,7 +1085,7 @@ MudObject *MudObject::get_contained_by()
 
 
 /***********************************************************************
- ** set_contained_by - returns a pointer to the object that contains
+ ** set_contained_by - sets a pointer to the object that contains
  **                    this object
  **
  **
@@ -1141,6 +1098,7 @@ void MudObject::set_contained_by(MudObject *the_obj)
    else if (get_type() == OBJ_TYPE_DOOR)
    RAISE(1); */
 
+   
    contained_by = the_obj;
 }
 
@@ -1159,8 +1117,8 @@ int MudObject::write_mudobject_attrib(FILE *the_file)
    fprintf(the_file, "^%s^\n", get_title());
    fprintf(the_file, "^%s^\n", (get_altname() == NULL) ? "" : get_altname());
    fprintf(the_file, "^%s^\n", (get_clones() == NULL) ? "" : get_clones());
-   fprintf(the_file, "%s\n", (get_location() == NULL) ? "needloc" : 
-                                                            get_location());
+   fprintf(the_file, "%s\n", (get_loc_str() == NULL) ? "needloc" : 
+                                                            get_loc_str());
    fprintf(the_file, "^%s^\n", (get_special_str() == NULL) ? "" : 
                                                      get_special_str());
    fprintf(the_file, "^%s^\n", (desc.str_show() == NULL) ? "" : 
@@ -1251,7 +1209,7 @@ int MudObject::read_mudobject_attrib(FILE *read_file, char *areaname,
 
    /* get the object location */
    the_token = get_token(read_file, '\0');
-   set_location(the_token->the_string);
+   set_loc_str(the_token->the_string);
 
 
    /* get the next item, it should be a '^', if not, raise error */
@@ -1520,8 +1478,7 @@ int MudObject::add_clones(Object_List *obj_dbase, ErrLog *error_log)
                      cloned_mob->add_clones(obj_dbase, error_log);
                      cloned_mob->start_wield(obj_dbase, error_log);
                      cloned_mob->start_wear(obj_dbase, error_log);
-                     cloned_mob->set_location(((Location *) this), 
-                                                  cloned_mob->get_loc());
+                     cloned_mob->set_location(((Location *) this));
 		  }
 	       }
                else
@@ -1756,7 +1713,7 @@ int MudObject::copy_mudobject_attrib(MudObject *copy_from)
    set_title(copy_from->get_title());
    set_desc(copy_from->get_desc());
    set_altname(copy_from->get_altname());
-   set_location(copy_from->get_location());
+   set_loc_str(copy_from->get_loc_str());
    set_clones(copy_from->get_clones());
    set_special_str(copy_from->get_special_str());
    special_list = copy_from->copy_specials();
@@ -1849,6 +1806,22 @@ int MudObject::remove_status(char *the_name)
 }
 
 
+/***********************************************************************
+ ** get_loc_obj - gets the location object per the loc string
+ ***********************************************************************/
+
+MudObject *MudObject::get_loc_obj(void)
+{
+  Strings holder;
+  if (location.num_char('@') == 0)
+    holder.sprintf("%s@%s", location.str_show(), get_area());
+  else
+    holder = location.str_show();
+
+  return mainstruct->get_object(holder.str_show());
+}
+
+
 /***********************************************************************
  ** contains_lit - object contains an object that is giving off light
  **
@@ -1860,7 +1833,7 @@ int MudObject::remove_status(char *the_name)
 
 int MudObject::contains_lit(void)
 {
-   LinkedList *loc_list;
+   Inventory *loc_list;
    MudObject  *next_obj;
    Item       *an_item;
    Flags      *itemflags;
@@ -1906,7 +1879,7 @@ int MudObject::contains_lit(void)
 
 MudObject *MudObject::find_fire(void)
 {
-   LinkedList *loc_list;
+   Inventory  *loc_list;
    MudObject  *next_obj;
    Item       *an_item;
    Flags      *itemflags;
