@@ -61,8 +61,7 @@
 #include "shop.h"
 #include "pager.h"
 #include "strings.h"
-#include "btree_l.h"
-#include "btree_a.h"
+#include "btree.h"
 #include "code.h"
 #include "mailer.h"
 #include "individual.h"
@@ -97,7 +96,7 @@
  ** Parameters: the_num - the number of flag units of 32 to create
  **
  ***********************************************************************/
-
+/*
 Flags *new_Flags(int the_num)
 {
 #ifdef DEBUG_MEM
@@ -116,7 +115,7 @@ void delete_Flags(Flags *the_flag)
       delete the_flag;
    }
 }
-
+*/
 
 /***********************************************************************
  ** new_Action
@@ -375,7 +374,7 @@ void delete_Moveable(Moveable *the_moveable)
  **             the_area - the area this belongs to 
  **
  ***********************************************************************/
-
+/*
 Wearable *new_Wearable(char *the_name, char *the_area)
 {
 #ifdef DEBUG_MEM
@@ -394,7 +393,7 @@ void delete_Wearable(Wearable *the_wearable)
       delete the_wearable;
    }
 }
-
+*/
 
 /***********************************************************************
  ** new_Rope
@@ -659,7 +658,7 @@ void delete_Food(Food *the_food)
  **             the_area - the area this belongs to 
  **
  ***********************************************************************/
-
+/*
 Specials *new_Specials(char *the_name, char *the_area)
 {
 #ifdef DEBUG_MEM
@@ -679,14 +678,14 @@ void delete_Specials(Specials *the_special)
    }
 }
 
-
+*/
 /***********************************************************************
  ** new_Spell
  **
  ** Parameters: the_name - the name to give this
  **
  ***********************************************************************/
-
+/*
 Spell *new_Spell(char *the_name)
 {
 #ifdef DEBUG_MEM
@@ -705,7 +704,7 @@ void delete_Spell(Spell *the_spell)
       delete the_spell;
    }
 }
-
+*/
 
 /***********************************************************************
  ** new_Skill
@@ -838,7 +837,7 @@ void delete_Pager(Pager *the_pager)
    }
 }
 
-
+/*
 b_node_a *new_b_node_a()
 {
 #ifdef DEBUG_MEM
@@ -854,11 +853,13 @@ void delete_b_node_a(b_node_a *the_obj)
 #ifdef DEBUG_MEM
       del_mem_unit("b_node_a");
 #endif
+	  
       delete the_obj;
    }
 }
 
-b_node_l *new_b_node_l()
+
+b_node *new_b_node_l()
 {
 #ifdef DEBUG_MEM
    add_mem_unit("b_node_l");
@@ -876,7 +877,7 @@ void delete_b_node_l(b_node_l *the_obj)
       delete the_obj;
    }
 }
-
+*/
 
 /***********************************************************************
  ** new_char
@@ -1001,7 +1002,7 @@ void delete_Editor(Editor *the_obj)
  ** Parameters: areaname - the area we are creating
  **
  ***********************************************************************/
-
+/*
 Area_Dbase *new_Area_Dbase(char *areaname)
 {
 #ifdef DEBUG_MEM
@@ -1020,8 +1021,8 @@ void delete_Area_Dbase(Area_Dbase *the_obj)
       delete the_obj;
    }
 }
-
-
+*/
+/*
 
 params *new_params()
 {
@@ -1042,6 +1043,7 @@ void delete_params(params *the_obj)
    }
 }
 
+*/
 
 /***********************************************************************
  ** new_Strings
@@ -1049,7 +1051,7 @@ void delete_params(params *the_obj)
  ** Parameters: the_str - the string to set this String object to
  **
  ***********************************************************************/
-
+/*
 Strings *new_Strings(char *the_str)
 {
 #ifdef DEBUG_MEM
@@ -1078,8 +1080,8 @@ void delete_Strings(Strings *the_obj)
       delete the_obj;
    }
 }
-
-long *new_long()
+*/
+/*long *new_long()
 {
 #ifdef DEBUG_MEM
    add_mem_unit("long");
@@ -1096,7 +1098,7 @@ void delete_long(long *the_obj)
 #endif
       delete the_obj;
    }
-}
+}*/
 
 int *new_int()
 {
@@ -1123,14 +1125,14 @@ void delete_int(int *the_obj)
  ** Parameters: the_str - the code to set this Code object to
  **
  ***********************************************************************/
-
+/*
 Code *new_Code(char *the_str)
 {
 #ifdef DEBUG_MEM
    add_mem_unit("code");
 #endif
    return new Code(the_str);
-}
+}*/
 
 
 /***********************************************************************
@@ -1139,14 +1141,14 @@ Code *new_Code(char *the_str)
  ** Parameters: the_func - the function to set this Code object to
  **
  ***********************************************************************/
-
+/*
 Code *new_Code(Spec_Func the_func)
 {
 #ifdef DEBUG_MEM
    add_mem_unit("code");
 #endif
    return new Code(the_func);
-}
+} 
 
 void delete_Code(Code *the_obj)
 {
@@ -1158,7 +1160,7 @@ void delete_Code(Code *the_obj)
       delete the_obj;
    }
 }
-
+*/
 
 /***********************************************************************
  ** new_Player
@@ -1330,7 +1332,7 @@ void delete_Edit_Line(Edit_Line *the_obj)
    }
 }*/
 
-
+/*
 worn_item *new_worn_item()
 {
 #ifdef DEBUG_MEM
@@ -1349,7 +1351,7 @@ void delete_worn_item(worn_item *the_obj)
       delete the_obj;
    }
 }
-
+*/
 
 handler_struct *new_handler_struct()
 {
@@ -1665,7 +1667,7 @@ void delete_Level_Chain(Level_Chain *the_obj)
  ** Parameters: the_node - the name of the node
  **
  ***********************************************************************/
-
+/*
 LinkedNode *new_LinkedNode(MudObject *the_node)
 {
 #ifdef DEBUG_MEM
@@ -1684,7 +1686,7 @@ void delete_LinkedNode(LinkedNode *the_obj)
       delete the_obj;
    }
 }
-
+*/
 
 Mud *new_Mud(bool quiet_mode)
 {
@@ -2004,6 +2006,7 @@ void delete_Verb(Verb *the_obj)
  **
  ***********************************************************************/
 
+/*
 Race *new_Race(char *the_name)
 {
 #ifdef DEBUG_MEM
@@ -2022,6 +2025,7 @@ void delete_Race(Race *the_obj)
       delete the_obj;
    }
 }
+*/
 
 /***********************************************************************
  ** new_Inclination
@@ -2029,7 +2033,7 @@ void delete_Race(Race *the_obj)
  ** Parameters: the_name - the name to give the inclination
  **
  ***********************************************************************/
-
+/*
 Inclination *new_Inclination(char *the_name)
 {
 #ifdef DEBUG_MEM
@@ -2047,7 +2051,7 @@ void delete_Inclination(Inclination *the_obj)
 #endif
       delete the_obj;
    }
-}
+} */
 
 /***********************************************************************
  ** new_Talent
@@ -2055,7 +2059,7 @@ void delete_Inclination(Inclination *the_obj)
  ** Parameters: the_name - the name to give the talent
  **
  ***********************************************************************/
-
+/*
 Talent *new_Talent(char *the_name)
 {
 #ifdef DEBUG_MEM
@@ -2074,7 +2078,7 @@ void delete_Talent(Talent *the_obj)
       delete the_obj;
    }
 }
-
+*/
 
 /***********************************************************************
  ** new_Mask
