@@ -36,9 +36,8 @@
 #include "mudtypes.h"
 #include "mudobject.h"
 #include "location.h"
-#include "btree_l.h"
+#include "btree.h"
 #include "area_dbase.h"
-#include "btree_a.h"
 #include "logs.h"
 #include "errlog.h"
 #include "object_list.h"
@@ -99,13 +98,14 @@ Object_List::Object_List(ErrLog *error_log, bool quiet_mode)
    char         areaname[129]; /* name of the area we're loading */  
    char         *charptr;        /* used to move along string */
    char         *prevptr = NULL; /* used to move along string */
-   FILE         *lsfile = NULL;         /* the directory listing */
    FILE         *areafile = NULL;       /* the area file we are reading */
    int          results;
    DirRead      *dirptr = NULL;
    Area_Dbase   *temp_area;
 
 
+   the_dbase.set_del_data();
+
    loaded = max_lookup = avg_lookup = num_lookups = 0;
    min_lookup = 10000;
    
@@ -115,7 +115,6 @@ Object_List::Object_List(ErrLog *error_log, bool quiet_mode)
                                                        "Object_List");
       return;
    }
-
    
    dirname.sprintf("%s%s%s%s", the_config.basedir.str_show(), DSEP, AREADIR, DSEP);
    dirptr = new DirRead(dirname.str_show());
@@ -168,7 +167,7 @@ Object_List::Object_List(ErrLog *error_log, bool quiet_mode)
       /* if we successfully opened the file, add the area to the arealist */
       if (areafile != NULL)
       {  
-         temp_area = new_Area_Dbase(areaname);
+         temp_area = new Area_Dbase(areaname);
 
          if (!quiet_mode)
 		 {
@@ -181,21 +180,15 @@ Object_List::Object_List(ErrLog *error_log, bool quiet_mode)
 		 {
             status.sprintf("%s%s%s%s%s.area", the_config.basedir.str_show(), 
 			   DSEP, AREADIR, DSEP, areaname);
-			delete_Area_Dbase(temp_area);
+			delete temp_area;
 			return;
 		 }		
 	     else
-            delete_Area_Dbase(temp_area);
+            delete temp_area;
       }
    }
    if (dirptr != NULL)
      delete dirptr;
-
-   if (load_abilities(error_log) == -2)
-   {
-      status.sprintf("%s%s%s%sabilities.dat", the_config.basedir.str_show(), DSEP, DATA_DIR, DSEP);
-	  return; 
-   }
   
    if (the_config.conf_flags->get_flag(CF_USEQUESTS))
    {
@@ -206,6 +199,12 @@ Object_List::Object_List(ErrLog *error_log, bool quiet_mode)
 	  }
    }
 
+   if (load_abilities(error_log) == -2)
+   {
+      status.sprintf("%s%s%s%sabilities.dat", the_config.basedir.str_show(), DSEP, DATA_DIR, DSEP);
+	  return; 
+   }
+
    if (load_races(error_log) == -2)
    {
       status.sprintf("%s%s%s%sraces.dat", the_config.basedir.str_show(), DSEP, DATA_DIR, DSEP);
@@ -226,13 +225,17 @@ Object_List::Object_List(ErrLog *error_log, bool quiet_mode)
 
    if (load_bulletins(error_log) == -2)
    {
-      status.sprintf("%s%s%s%sbulletins.dat", the_config.basedir.str_show(), DSEP, DATA_DIR, DSEP);
-	  return; 
+      status.sprintf("%s%s%s%sbulletins.dat", the_config.basedir.str_show(), 
+		     DSEP, DATA_DIR, DSEP);
+      printf("loading bulletins failed.\n");
+      return; 
    }
 
    if (load_masks(error_log) == -2)
-
-   xfclose(lsfile, "area_dir");
+   {
+      status.sprintf("%s%s%s%smasks.dat", the_config.basedir.str_show(), DSEP, DATA_DIR, DSEP);
+	  return; 
+   }
 
    coordinate(error_log);
    loaded = 1;
@@ -267,6 +270,7 @@ Object_List::~Object_List()
    /* we need to check to see if anyone is in the bulletin board and
       if so, pop their input handlers to take them out of it */
    mainstruct->clear_bulletin_users();
+   empty_objects();
 }
 
 
@@ -727,20 +731,20 @@ int Object_List::coordinate(ErrLog *error_log)
    Area_Dbase *cur_area = NULL;  /* holds a temp area for checking */
    Strings   holder;
 
-   the_dbase.reset_next_in_list();
-   cur_area = the_dbase.get_next_in_list();
+   the_dbase.reset_current();
+   cur_area = the_dbase.get_next();
    while (cur_area != NULL)
    {
       cur_area->coord_area1(error_log, this);
-      cur_area = the_dbase.get_next_in_list();
+      cur_area = the_dbase.get_next();
    }
 
-   the_dbase.reset_next_in_list();
-   cur_area = the_dbase.get_next_in_list();
+   the_dbase.reset_current();
+   cur_area = the_dbase.get_next();
    while (cur_area != NULL)
    {
       cur_area->coord_area2(error_log, this);
-      cur_area = the_dbase.get_next_in_list();
+      cur_area = the_dbase.get_next();
    }
       
    return 1;
@@ -766,18 +770,20 @@ int Object_List::add_hardcoded(ErrLog *error_log)
    Area_Dbase *tmp_area;
    Mobile    *ghost_mob;
 
-   tmp_area = new_Area_Dbase(the_config.hardcoded_areaname.str_show());
+   tmp_area = new Area_Dbase(the_config.hardcoded_areaname.str_show());
    add_area(tmp_area, error_log);
 
    void_loc = new_Location(the_config.backup_locname.str_show(), 
                                       the_config.hardcoded_areaname.str_show());
    void_loc->set_title(the_config.backup_loctitle.str_show());
    void_loc->set_desc(0, the_config.backup_locdesc.str_show());
+   void_loc->set_desc(1, the_config.backup_locdesc.str_show());
+   void_loc->set_desc(2, the_config.backup_locdesc.str_show());
 
    if (add_mudobject(the_config.hardcoded_areaname.str_show(), 
                                                       (MudObject *) void_loc) < 1)
    {
-		raise(11);   
+      raise(11);   
    }
   
    void_loc = new_Location(the_config.entry_locname.str_show(), 
@@ -788,7 +794,7 @@ int Object_List::add_hardcoded(ErrLog *error_log)
    if (add_mudobject(the_config.hardcoded_areaname.str_show(), 
                                                    (MudObject *) void_loc) < 1)
    {
-		raise(11);   
+      raise(11);   
    }
 
    /* create the ghost mobile so we can clone it later on */
@@ -798,7 +804,7 @@ int Object_List::add_hardcoded(ErrLog *error_log)
    ghost_mob->set_brief(the_config.ghost_brief.str_show());
    ghost_mob->set_desc(the_config.ghost_desc.str_show());
    ghost_mob->set_altname(the_config.ghost_altnames.str_show());
-   ghost_mob->set_location("none");
+   ghost_mob->set_loc_str("none");
    (ghost_mob->get_indflags())->set_flag(INDFLAG_GHOST);
 
    add_mudobject(the_config.hardcoded_areaname.str_show(), ghost_mob);
@@ -816,9 +822,9 @@ int Object_List::add_hardcoded(ErrLog *error_log)
  **
  ***********************************************************************/
 
-int Object_List::reset_list()
+void Object_List::reset_list()
 {
-   return the_dbase.reset_next_in_list();
+   the_dbase.reset_current();
 }
    
 
@@ -834,7 +840,7 @@ int Object_List::reset_list()
 
 Area_Dbase *Object_List::get_next_area()
 {
-   return the_dbase.get_next_in_list();
+   return the_dbase.get_next();
 }
 
 
@@ -886,7 +892,6 @@ MudObject *Object_List::clone_object(MudObject *orig_obj)
       {
          if (new_object != NULL)
             mainstruct->delete_entity(new_object);
-         printf("test2\n");
 
          new_object = NULL;
       }
@@ -913,13 +918,13 @@ int Object_List::display_data(Player *the_player)
    int num_areas = 0;
    Area_Dbase *tmp_area;
 
-   the_dbase.reset_next_in_list();
-   tmp_area = the_dbase.get_next_in_list();
+   the_dbase.reset_current();
+   tmp_area = the_dbase.get_next();
    while (tmp_area != NULL)
    {
       num_areas++;
       num_obj += tmp_area->get_num_obj_loaded();
-      tmp_area = the_dbase.get_next_in_list();
+      tmp_area = the_dbase.get_next();
    }
    the_player->send_plr("\n&+GObject Database Statistics&*\n");
    the_player->send_plr("&+B-----------------------------&*\n\n");
@@ -958,13 +963,13 @@ int Object_List::display_list_data(Player *the_player)
    the_player->send_plr("&+B----------------------------------------"
                         "---------------------------&*\n");
   
-   the_dbase.reset_next_in_list();
-   tmp_area = the_dbase.get_next_in_list();
+   the_dbase.reset_current();
+   tmp_area = the_dbase.get_next();
    while (tmp_area != NULL)
    {
       tmp_area->display_brief_data(the_player);
       count++;
-      tmp_area = the_dbase.get_next_in_list();
+      tmp_area = the_dbase.get_next();
    }
    
    the_player->send_plr("&+B----------------------------------------"
@@ -976,12 +981,12 @@ int Object_List::display_list_data(Player *the_player)
 
 void Object_List::save_state(void)
 {
-   the_dbase.save_state();
+   the_dbase.push_current();
 }
 
 void Object_List::restore_state(void)
 {
-   the_dbase.restore_state();
+   the_dbase.pop_current();
 }
 
 
@@ -1014,17 +1019,17 @@ int Object_List::load_abilities(ErrLog *error_log)
    /* if we successfully opened the file, add the area to the arealist */
    if (abilities_file != NULL)
    {  
-      tmp_area = new_Area_Dbase("abilities");
+      tmp_area = new Area_Dbase("abilities");
 
       if ((results = tmp_area->load_area(abilities_file, error_log, 0, 0)) >= 0)
          add_area(tmp_area, error_log);
       else if (results == -2)
 	  {
-	     delete_Area_Dbase(tmp_area);
+	     delete tmp_area;
 		 return -2;
 	  }
 	  else
-         delete_Area_Dbase(tmp_area);
+         delete tmp_area;
    }
    return 1;
 }
@@ -1084,17 +1089,17 @@ int Object_List::load_races(ErrLog *error_log)
    /* if we successfully opened the file, add the area to the arealist */
    if (races_file != NULL)
    {  
-      tmp_area = new_Area_Dbase("races");
+      tmp_area = new Area_Dbase("races");
 
       if ((results = tmp_area->load_area(races_file, error_log, 0, 0)) >= 0)
          add_area(tmp_area, error_log);
       else if (results == -2)
 	  {
-	     delete_Area_Dbase(tmp_area);
+	     delete tmp_area;
 		 return -2;
 	  }
       else
-         delete_Area_Dbase(tmp_area);
+         delete tmp_area;
    }
 
    return 1;
@@ -1159,17 +1164,17 @@ int Object_List::load_inclinations(ErrLog *error_log)
    /* if we successfully opened the file, add the area to the arealist */
    if (inclinations_file != NULL)
    {  
-      tmp_area = new_Area_Dbase("inclinations");
+      tmp_area = new Area_Dbase("inclinations");
 
       if ((results = tmp_area->load_area(inclinations_file, error_log, 0, 0)) >= 0)
          add_area(tmp_area, error_log);
       else if (results == -2)
 	  {
-	     delete_Area_Dbase(tmp_area);
+	     delete tmp_area;
 		 return -2;
 	  }
       else
-         delete_Area_Dbase(tmp_area);
+         delete tmp_area;
    }
 
    return 1;
@@ -1231,17 +1236,17 @@ int Object_List::load_talents(ErrLog *error_log)
    /* if we successfully opened the file, add the area to the arealist */
    if (talents_file != NULL)
    {  
-      tmp_area = new_Area_Dbase("talents");
+      tmp_area = new Area_Dbase("talents");
 
       if ((results = tmp_area->load_area(talents_file, error_log, 0, 0)) >= 0)
          add_area(tmp_area, error_log);
       else if (results == -2)
 	  {
-	     delete_Area_Dbase(tmp_area);
+	     delete tmp_area;
 		 return -2;
 	  }
       else
-         delete_Area_Dbase(tmp_area);
+         delete tmp_area;
    }
 
    return 1;
@@ -1303,17 +1308,17 @@ int Object_List::load_masks(ErrLog *error_log)
    /* if we successfully opened the file, add the area to the arealist */
    if (masks_file != NULL)
    {  
-      tmp_area = new_Area_Dbase("masks");
+      tmp_area = new Area_Dbase("masks");
 
       if ((results = tmp_area->load_area(masks_file, error_log, 0, 0)) >= 0)
          add_area(tmp_area, error_log);
       else if (results == -2)
 	  {
-	     delete_Area_Dbase(tmp_area);
+	     delete tmp_area;
 		 return -2;
 	  }
       else
-         delete_Area_Dbase(tmp_area);
+         delete tmp_area;
    }
 
    return 1;
@@ -1353,20 +1358,22 @@ int Object_List::load_bulletins(ErrLog *error_log)
    }
 
    /* if we successfully opened the file, add the area to the arealist */
-   tmp_area = new_Area_Dbase("bulletins");
+   tmp_area = new Area_Dbase("bulletins");
 
-   if ((results = tmp_area->load_area(dirptr, "bulletins", error_log, 0, 0)) >= 0)
+   if ((results = tmp_area->load_area(dirptr, "btn", error_log, 0, 0)) >= 0)
    {
       add_area(tmp_area, error_log);
    }
    else if (results == -2)
    {
      delete dirptr;
-     delete_Area_Dbase(tmp_area);
+     delete tmp_area;
 	 return -2;
    }
    else
-      delete_Area_Dbase(tmp_area);
+   {
+     delete tmp_area;
+   }
    delete dirptr;
 
    return 1;
@@ -1428,17 +1435,17 @@ int Object_List::load_quests(ErrLog *error_log)
    /* if we successfully opened the file, add the area to the arealist */
    if (quests_file != NULL)
    {  
-      tmp_area = new_Area_Dbase("quests");
+      tmp_area = new Area_Dbase("quests");
 
       if ((results = tmp_area->load_area(quests_file, error_log, 0, 0)) >= 0)
          add_area(tmp_area, error_log);
       else if (results == -2)
 	  {
-	     delete_Area_Dbase(tmp_area);
+	     delete tmp_area;
 		 return -2;
 	  }
       else
-         delete_Area_Dbase(tmp_area);
+         delete tmp_area;
    }
 
    return 1;
@@ -2151,6 +2158,9 @@ int Object_List::display_inclinations(Player *the_player)
    Strings     holder;
    int         num_in_line = 0;
    int         count = 0;
+   int         show_all = 0;
+   Race        *plr_race;
+   Strings     incl_list;
 
    if ((inclination_area = get_area("inclinations")) == NULL)
    {
@@ -2164,6 +2174,18 @@ int Object_List::display_inclinations(Player *the_player)
 
    the_player->send_plr("\n\n&+WAvailable Inclinations:&*\n");
    the_player->send_plr("&+B-----------------------------------&*\n");
+
+   if ((plr_race = mainstruct->get_race(the_player->get_race())) == NULL)
+   {
+     holder.sprintf("Could not get player race '%s'", the_player->get_race());
+     mainstruct->log_error(holder.str_show(), "display_inclinations");
+     return -1;
+   }
+
+   incl_list = plr_race->get_allow_incl();
+   if (!STRCASECMP(incl_list.str_show(), "all"))
+     show_all = 1;
+     
    while ((tmp_obj = inclination_area->get_next_obj()) != NULL)
    {
       if (tmp_obj->get_type() != OBJ_TYPE_INCLINAT)
@@ -2175,20 +2197,24 @@ int Object_List::display_inclinations(Player *the_player)
          return -1;
       }
       tmp_inclination = (Inclination *) tmp_obj;
-      inclination_name = tmp_inclination->get_name();
-      if (inclination_name.str_len() > 15)
-         inclination_name.truncate(15);
-      inclination_name.upper(0);
-      sprintf(tmp_line, "%-15s", inclination_name.str_show());
-      holder.str_cat(tmp_line);
-      num_in_line++;
-      if (num_in_line == 3)
+
+      if (show_all || (incl_list.find_in_str(tmp_inclination->get_name())))
       {
-         the_player->send_plr("&+g%s&*\n", holder.str_show());
-         holder.truncate(0);
-         num_in_line = 0;
+	inclination_name = tmp_inclination->get_name();
+	if (inclination_name.str_len() > 15)
+	  inclination_name.truncate(15);
+	inclination_name.upper(0);
+	sprintf(tmp_line, "%-15s", inclination_name.str_show());
+	holder.str_cat(tmp_line);
+	num_in_line++;
+	if (num_in_line == 3)
+	{
+	  the_player->send_plr("&+g%s&*\n", holder.str_show());
+	  holder.truncate(0);
+	  num_in_line = 0;
+	}
+	count++;
       }
-      count++;
    }
    if (num_in_line > 0)
    {
@@ -2410,5 +2436,27 @@ char * Object_List::get_status()
 	return status.str_show();
 }
 
+
+/***********************************************************************
+ ** empty_objects - clears all objects of their inventory that are being
+ **                 deleted and removes them from their location
+ ***********************************************************************/
+
+int Object_List::empty_objects()
+{
+	Area_Dbase *tmp_area;
+
+	the_dbase.reset_current();
+	tmp_area = the_dbase.get_next();
+	while (tmp_area != NULL)
+	{
+		tmp_area->empty_objects();
+		tmp_area = the_dbase.get_next();
+	}
+	return 1;
+}
+
+
+
 #endif
 
