@@ -35,9 +35,8 @@
 #include "mudtypes.h"
 #include "mudobject.h"
 #include "location.h"
-#include "btree_l.h"
+#include "btree.h"
 #include "area_dbase.h"
-#include "btree_a.h"
 #include "individual.h"
 #include "player.h"
 #include "login.h"
@@ -72,6 +71,7 @@
 #include "adminflags.h"
 #include "comflags.h"
 #include "talent.h"
+#include "race.h"
 
 // This is the ranks at which the experience required increases
 int cutoff_rank[5] = {5, 10, 20, 30, 40};
@@ -99,7 +99,6 @@ Player::Player(void)
 
    // Initialize some variables
    next_player = NULL;
-   player_ranks = NULL;
    player_levels = NULL;
 
    player_quests = NULL;
@@ -119,7 +118,8 @@ Player::Player(void)
 
    holder.sprintf("%s@%s", the_config.entry_locname.str_show(),
                                     the_config.hardcoded_areaname.str_show());
-   set_location(holder.str_show());
+   set_loc_str(holder.str_show());
+
 
    if (input_handler.push_input_handler(main_plr_handler, &(prompt->the_prompt),
                                                             0, 0, 0) <= 0)
@@ -159,11 +159,88 @@ Player::Player(void)
 
    set_area("player");
    set_desc("You see an ordinary player.\n");
-   max_endurance = endurance = the_config.default_maxendur;
-   max_magic = magic = the_config.default_maxmagic;
-   wimpy = the_config.default_wimpy;
    experience = 0;
    talent_funds = 0;
+   set_vislvl(0);
+
+   pager_lines = the_config.default_pager_lines;
+   the_mail = NULL;
+   cur_brief = NULL;
+   talent_list = NULL;
+   login_player((void *) this);
+}
+
+
+/***********************************************************************
+ ** _Player (constructor) - creates a player and assigns a socket passed
+ **                         in.  Logs in the player and loads
+ **                         the player information into the player
+ **                         object
+ **
+ ** Parameters: new_sock - the connection to use for this
+ **
+ ** Returns: Nothing
+ **
+ ***********************************************************************/
+
+Player::Player(Connection *new_sock)
+{
+   Strings holder;
+   Flags   *gameflags;
+
+   // Initialize some variables
+   next_player = NULL;
+   player_levels = NULL;
+
+   player_quests = NULL;
+
+   /* this should be the only place that this is set */
+   obj_type = OBJ_TYPE_PLAYER;
+
+   still_on = 1;
+   quitting = 0;
+
+   set_capacity(300);
+   gameflags = get_gameflags();
+   gameflags->clr_flag(GAMEFLAG_ONGAME);
+
+   prompt = NULL;
+   push_prompt("main", "&+bAIME&+W>&* ");;
+
+   holder.sprintf("%s@%s", the_config.entry_locname.str_show(),
+                                    the_config.hardcoded_areaname.str_show());
+   set_loc_str(holder.str_show());
+
+   if (input_handler.push_input_handler(main_plr_handler, &(prompt->the_prompt),
+                                                            0, 0, 0) <= 0)
+   {
+      mainstruct->log_error("Error loading main input handler for player",
+                                          "Player constructor");
+      exit(0);
+   }
+
+   /* assign the connection */
+   
+   the_socket = new_sock;
+   the_socket->set_owner(this);
+
+   set_initname();
+
+   if (the_socket->lost_link())
+   {
+      still_on = 0;
+      return;
+   }
+
+   the_socket->set_valid();
+
+   /* initalize variables */
+
+   set_area("player");
+   set_desc("You see an ordinary player.\n");
+   experience = 0;
+   talent_funds = 0;
+   set_vislvl(0);
 
    pager_lines = the_config.default_pager_lines;
    the_mail = NULL;
@@ -196,8 +273,8 @@ Player::Player(char *the_name)
    quitting = 0;
    experience = 0;
    talent_funds = 0;
+   set_vislvl(0);
    pager_lines = the_config.default_pager_lines;
-   wimpy = the_config.default_wimpy;
 
    prompt = NULL;
    push_prompt("main", "&+bAIME&+W>&* ");;
@@ -207,21 +284,18 @@ Player::Player(char *the_name)
 
    holder.sprintf("%s@%s", the_config.entry_locname.str_show(),
                            the_config.hardcoded_areaname.str_show());
-   set_location(holder.str_show());
+   set_loc_str(holder.str_show());
 
    set_name(the_name);
 
    /* initalize variables */
    next_player = NULL;
-   player_ranks = NULL;
    player_levels = NULL;
 
    player_quests = NULL;
 
    set_area("player");
    set_desc("You see an ordinary player.\n");
-   max_endurance = endurance = the_config.default_maxendur;
-   max_magic = magic = the_config.default_maxmagic;
 
    the_socket = NULL;
    cur_brief = NULL;
@@ -242,7 +316,6 @@ Player::Player(char *the_name)
 Player::~Player()
 {
    Location        *this_loc;
-   rank_list       *tmp_rank;
    quest_list      *tmp_quest;
    brief_stack     *tmp_brief;
    prompt_stack    *tmp_prompt;
@@ -251,13 +324,6 @@ Player::~Player()
    /* releases all objects the player is carrying, placing them nowhere */
    release_all_inv();
 
-   /* deletes all ranks from the player */
-   while (player_ranks != NULL)
-   {
-      tmp_rank = player_ranks->next_rank;
-      delete_rank_list(player_ranks);
-      player_ranks = tmp_rank;
-   }
 
    /* deletes all briefs */
    while (cur_brief != NULL)
@@ -311,6 +377,24 @@ Player::~Player()
       delete_Connection(the_socket);
 }
 
+bool Player::can_see_ind(Individual *the_ind)
+{
+    int the_num;
+
+    if (the_ind->is_visible())
+        return true;
+
+    if (the_ind->is_vis_incog() 
+    && (the_ind->get_loc())->find_contained(get_name(), &the_num)
+    || get_admflags()->get_flag(ADMINFLAG_ADMINISTRATOR))
+        return true;
+
+    if (the_ind->is_vis_admin() && get_admflags()->get_flag(ADMINFLAG_ADMINISTRATOR))
+        return true;
+
+    return false;
+}
+
 
 /***********************************************************************
  ** release_all_inv - releases all inventory objects, making their locations
@@ -373,10 +457,12 @@ int Player::check_connection()
    if (((sock_result = the_socket->check_socket()) > 0) ||
        (the_socket->has_input()))
    {
-       if (the_socket->has_input())
-       {
-           the_input =
-              the_socket->get_input(input_handler.get_lines_per_handle());
+      if (the_socket->has_input())
+	  {
+		// Loop through and handle lines
+		for (int i=0; i<input_handler.get_lines_per_handle(); i++)
+		{
+           the_input = the_socket->get_input();
 
            if (the_input != NULL)
            {
@@ -384,37 +470,40 @@ int Player::check_connection()
                              "&+g%s's input:&* %s", get_title(),
                                                        the_input->str_show());
               get_connection()->send_to_snoopers(holder.str_show());
-           }
-
-           if (the_input != NULL)
               input_handler.exec_input_handler((MudObject *) this,
                                                      the_input->str_show());
-           if (the_input != NULL)
-               delete_Strings(the_input);
-
-		   // If this player has lost its connection, exit out
-		   if (the_socket == NULL)
+			  delete the_input;
+		   }
+	       else
 		   {
-		      return -5;				
+			  sysmessage("Lost input.\r\n");
+	          break;
+		   }
+
+	       // If this player has lost its connection, exit out
+	       if (the_socket == NULL)
+		   {
+	          return -5;				
 		   }
 
            if (!is_quitting() && is_on())
            {
-              the_socket->send_to_socket(input_handler.get_prompt(), COOKED);
+	          the_socket->send_to_socket(input_handler.get_prompt(), COOKED);
            }
 
            had_input = 1;
-       }
+		}
+      }
 
-       if (the_socket->has_output())
-       {
-           if (!had_input && !is_quitting() && is_on())
-           {
-             the_socket->send_to_socket(input_handler.get_prompt(), COOKED);
-           }
-           the_socket->flush();
-       }
-       return 1;
+      if (the_socket->has_output())
+      {
+		if (!had_input && !is_quitting() && is_on())
+		{
+            the_socket->send_to_socket(input_handler.get_prompt(), COOKED);
+        }
+        the_socket->flush();
+      }
+      return 1;
    }
    else if (sock_result == -3)
    {
@@ -460,6 +549,8 @@ int Player::send_plr(char *new_str, ...)
    char *dig_ptr;
    int  format = 0;
 
+   if (the_socket == NULL)
+     return 0;
 
    /* we have to first estimate the size of a string we need to allocate
       to put this into. This is not an easy task, so we have to search
@@ -955,18 +1046,33 @@ Connection *Player::get_connection()
 int Player::check_player(void)
 {
    int conn_result;
+   int counter = 0;
 
 #ifdef WIN32
    // If we have windows, we need to take into account multiple threads that could
    // access the connection concurrently.  Handle this by locking the connection
    while (the_socket->set_locked() == FALSE)
-	   Sleep(10);
+   {
+	   // If the socket got stuck on, ignore the lock...cheating but I couldn't figure out
+	   // why if you take over a connection in the windows port, it won't unlock properly
+	   // Maybe someday need to look into this
+	   if (counter > 50)
+		   break;
+
+	   Sleep(7);
+	   counter++;
+   }
 
 #endif
    if ((conn_result = check_connection()) < 0)
    {
       if (conn_result == -5)
+	  {
+#ifdef WIN32
+		  the_socket->unlock();
+#endif
 		  return -2;
+	  }
 
       if ((time(0) - the_socket->lost_link()) > the_config.secs_till_timeout)
       {
@@ -1006,7 +1112,7 @@ int Player::check_player(void)
    }
 
 #ifdef WIN32
-		 the_socket->unlock();
+	the_socket->unlock();
 #endif
 
    return 1;
@@ -1161,8 +1267,10 @@ int Player::game_put_obj(MudObject *the_obj, MudObject *to_obj, int has_to,
    {
       if (is_male())
          sex1 = "his";
-      else
+      else if (is_female())
          sex1 = "her";
+      else
+          sex1 = "its";
    }
       else
          sex1 = "the";
@@ -1171,8 +1279,10 @@ int Player::game_put_obj(MudObject *the_obj, MudObject *to_obj, int has_to,
    {
       if (is_male())
          sex2 = "his";
-      else
+      else if (is_female())
          sex2 = "her";
+      else
+          sex2 = "its";
    }
       else
          sex2 = "the";
@@ -1360,7 +1470,6 @@ int Player::read_inventory(FILE *the_file)
    int          worn;
    Strings      holder;
 
-
    the_token = get_token(the_file, '\0');
    while ((the_token->token_type != T_POUND) && (the_token->token_type > 0))
    {
@@ -1405,106 +1514,6 @@ int Player::read_inventory(FILE *the_file)
 }
 
 
-/***********************************************************************
- ** write_ranks - writes the ranks this player has to the player
- **               file to save for later
- **
- ** Parameters: None
- **
- ** Returns: 1 for success, -1 for failure, 0 for no write
- **
- ***********************************************************************/
-
-int Player::write_ranks(FILE *the_file)
-{
-   rank_list *tmp_rank;
-
-   tmp_rank = player_ranks;
-   if (tmp_rank == NULL)
-      return 0;
-
-   fprintf(the_file, "rank\n");
-   /* write all the ranks to file */
-   while (tmp_rank != NULL)
-   {
-      fprintf(the_file, "%s %d %d\n", tmp_rank->rank_name.str_show(),
-                        tmp_rank->the_rank, tmp_rank->the_exp);
-      tmp_rank = tmp_rank->next_rank;
-   }
-   fprintf(the_file, "#\n");
-
-   return 1;
-}
-
-
-/***********************************************************************
- ** read_ranks - reads in the player's ranks from the user file
- **
- ** Parameters: the_file - the file we read in the inventory from
- **
- ** Returns: 1 for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::read_ranks(FILE *the_file)
-{
-   Ability      *tmp_ability = NULL;
-   Strings      rank_name;
-   token_record *the_token;
-   Strings      holder;
-   int          has_errors = 0;
-   int          the_rank;
-   int          the_exp;
-   int          rank_type = 0;
-
-
-   the_token = get_token(the_file, '\0');
-   while ((the_token->token_type != T_POUND) && (the_token->token_type > 0))
-   {
-      if ((tmp_ability = mainstruct->get_ability(the_token->the_string)) == NULL)
-      {
-         rank_name = the_token->the_string;
-         rank_type = 0;
-      }
-      else
-      {
-         rank_type = tmp_ability->get_type();
-         rank_name = tmp_ability->get_name();
-      }
-
-      /* Set rank value */
-      the_token = get_token(the_file, '\0');
-      if (the_token->token_type != T_NUMERICAL)
-      {
-         holder.sprintf("Rank %s in user %s missing rank value",
-                                 rank_name.str_show(), get_name());
-         mainstruct->log_error(holder.str_show(), "read_ranks");
-         has_errors = 1;
-      }
-      the_rank = atoi(the_token->the_string);
-
-      /* Set exp value */
-      the_token = get_token(the_file, '\0');
-      if (the_token->token_type != T_NUMERICAL)
-      {
-         holder.sprintf("Rank %s in user %s missing exp value",
-                       rank_name.str_show(), get_name());
-         mainstruct->log_error(holder.str_show(), "read_ranks");
-         has_errors = 1;
-      }
-      the_exp = atoi(the_token->the_string);
-
-      if (!has_errors)
-      {
-         add_rank(rank_name.str_show(), rank_type, the_rank, the_exp);
-      }
-      the_token = get_token(the_file, '\0');
-   }
-
-   return 1;
-}
-
-
 /***********************************************************************
  ** read_carried - reads in an item from the carried file and clones an
  **                object based on the info read in
@@ -1580,255 +1589,6 @@ MudObject *Player::read_carried(FILE *the_file, token_record **the_token)
 }
 
 
-/***********************************************************************
- ** add_rank - adds a rank to this player
- **
- ** Parameters: the_name - the name of the rank to add
- **             type     - the type of rank
- **             the_rank - the rank of the player with this rank
- **             the_exp  - the experience achieved since last rank
- **
- ** Returns: 1 for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::add_rank(char *the_name, int type, int the_rank, int the_exp)
-{
-   rank_list *new_rank;
-   rank_list *tmp_rank;
-
-   if (the_name == NULL)
-      return -1;
-
-   if ((type != OBJ_TYPE_SPELL) && (type != OBJ_TYPE_SKILL) && (type != 0))
-      return -1;
-
-   new_rank = new_rank_list();
-   new_rank->rank_name = the_name;
-   new_rank->the_type = type;
-   new_rank->the_rank = the_rank;
-   new_rank->the_exp = the_exp;
-   new_rank->next_rank = NULL;
-
-   tmp_rank = player_ranks;
-   player_ranks = new_rank;
-   player_ranks->next_rank = tmp_rank;
-   return 1;
-}
-
-
-/***********************************************************************
- ** remove_rank - removes an rank from this player
- **
- ** Parameters: the_name - the name of the rank to add
- **
- ** Returns: 1 for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::remove_rank(char *the_name)
-{
-   rank_list *tmp_rank;
-   rank_list *prev_rank = NULL;
-
-   if (player_ranks == NULL)
-      return -1;
-
-   tmp_rank = player_ranks;
-   while (STRCASECMP(tmp_rank->rank_name.str_show(), the_name))
-   {
-      prev_rank = tmp_rank;
-      tmp_rank = tmp_rank->next_rank;
-      if (tmp_rank == NULL)
-         return -1;
-   }
-   if (prev_rank == NULL)
-   {
-      tmp_rank = player_ranks;
-      player_ranks = player_ranks->next_rank;
-      delete_rank_list(tmp_rank);
-   }
-   else
-   {
-      prev_rank->next_rank = tmp_rank->next_rank;
-      delete_rank_list(tmp_rank);
-   }
-   return 1;
-}
-
-
-/***********************************************************************
- ** find_ability - finds if a player has an ability
- **
- ** Parameters: the_name - the name of the ability to find
- **
- ** Returns: 1 for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::find_ability(char *the_name)
-{
-   rank_list *tmp_ability;
-
-   if (player_ranks == NULL)
-      return 0;
-
-   tmp_ability = player_ranks;
-   while ((STRCASECMP(tmp_ability->rank_name.str_show(), the_name)) ||
-          ((tmp_ability->the_type != OBJ_TYPE_SPELL) && 
-           (tmp_ability->the_type != OBJ_TYPE_SKILL)))
-   {
-      tmp_ability = tmp_ability->next_rank;
-      if (tmp_ability == NULL)
-         return 0;
-   }
-   return 1;
-}
-
-
-/***********************************************************************
- ** find_rank - finds if a player has a rank
- **
- ** Parameters: the_name - the name of the rank to find
- **
- ** Returns: 1 for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::find_rank(char *the_name)
-{
-   rank_list *tmp_rank;
-
-   if (player_ranks == NULL)
-      return 0;
-
-   tmp_rank = player_ranks;
-   while (STRCASECMP(tmp_rank->rank_name.str_show(), the_name))
-   {
-      tmp_rank = tmp_rank->next_rank;
-      if (tmp_rank == NULL)
-         return 0;
-   }
-   return 1;
-}
-
-
-/***********************************************************************
- ** get_rank_number - gets the numerical rank of the rank indicated
- **
- ** Parameters: the_name - the name of the rank to find
- **
- ** Returns: 1 for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::get_rank_number(char *the_name)
-{
-   rank_list *tmp_rank;
-
-   if (player_ranks == NULL)
-      return 0;
-
-   tmp_rank = player_ranks;
-   while (STRCASECMP(tmp_rank->rank_name.str_show(), the_name))
-   {
-      tmp_rank = tmp_rank->next_rank;
-      if (tmp_rank == NULL)
-         return -1;
-   }
-   return tmp_rank->the_rank;
-}
-
-
-/***********************************************************************
- ** set_rank_number - sets the numerical rank of the rank indicated
- **
- ** Parameters: the_name - the name of the rank to find
- **             the_num - the number to set the rank to
- **
- ** Returns: 1 for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::set_rank_number(char *the_name, int the_num)
-{
-   rank_list *tmp_rank;
-
-   if (player_ranks == NULL)
-      return 0;
-
-   if (the_num < 0)
-      return -1;
-
-   tmp_rank = player_ranks;
-   while (STRCASECMP(tmp_rank->rank_name.str_show(), the_name))
-   {
-      tmp_rank = tmp_rank->next_rank;
-      if (tmp_rank == NULL)
-         return -1;
-   }
-   tmp_rank->the_rank = the_num;
-   return 1;
-}
-
-
-/***********************************************************************
- ** get_rank_exp - gets the experience of the rank indicated
- **
- ** Parameters: the_name - the name of the rank to find
- **
- ** Returns: 1 for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::get_rank_exp(char *the_name)
-{
-   rank_list *tmp_rank;
-
-   if (player_ranks == NULL)
-      return 0;
-
-   tmp_rank = player_ranks;
-   while (STRCASECMP(tmp_rank->rank_name.str_show(), the_name))
-   {
-      tmp_rank = tmp_rank->next_rank;
-      if (tmp_rank == NULL)
-         return -1;
-   }
-   return tmp_rank->the_exp;
-}
-
-
-/***********************************************************************
- ** set_rank_exp - sets the experience of the rank indicated
- **
- ** Parameters: the_name - the name of the rank to find
- **             the_num - the number to set the exp to
- **
- ** Returns: 1 for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::set_rank_exp(char *the_name, int the_num)
-{
-   rank_list *tmp_rank;
-
-   if (player_ranks == NULL)
-      return 0;
-
-   if (the_num < 0)
-      return -1;
-
-   tmp_rank = player_ranks;
-   while (STRCASECMP(tmp_rank->rank_name.str_show(), the_name))
-   {
-      tmp_rank = tmp_rank->next_rank;
-      if (tmp_rank == NULL)
-         return -1;
-   }
-   tmp_rank->the_exp = the_num;
-   return 1;
-}
 
 /***********************************************************************
  ** display_abilities - displays all the abilities that the player has
@@ -1848,7 +1608,7 @@ void Player::display_abilities()
    send_plr("&+GCurrent abilities:&*\n\n");
    send_plr("&+CSpells&*\n");
    send_plr("&+B-------------------------------&*\n");
-   tmp_rank = player_ranks;
+   tmp_rank = get_ranks();
    while (tmp_rank != NULL)
    {
       for (i=0; i<5; i++)
@@ -1861,7 +1621,7 @@ void Player::display_abilities()
       {
          sprintf(tmp_chars, "&+G   %-10s &+cRank: &+W%-5d &+c(%d%%)&*\n",
               tmp_rank->rank_name.str_show(), tmp_rank->the_rank,
-           (int) ((((float) tmp_rank->the_exp) / 
+           (int) ((((float) tmp_rank->the_exp_prob) / 
                                      ((float) cutoff_exp[i])) * 100.0));
          send_plr("%s", tmp_chars);
          count++;
@@ -1874,7 +1634,7 @@ void Player::display_abilities()
 
    send_plr("\n\n&+CSkills&*\n");
    send_plr("&+B-------------------------------&*\n");
-   tmp_rank = player_ranks;
+   tmp_rank = get_ranks();
    while (tmp_rank != NULL)
    {
       for (i=0; i<5; i++)
@@ -1887,7 +1647,7 @@ void Player::display_abilities()
       {
          sprintf(tmp_chars, "&+G   %-10s &+cRank: &+W%-5d &+c(%d%%)&*\n",
               tmp_rank->rank_name.str_show(), tmp_rank->the_rank,
-           (int) ((((float) tmp_rank->the_exp) / 
+           (int) ((((float) tmp_rank->the_exp_prob) / 
                                      ((float) cutoff_exp[i])) * 100.0));
 
          send_plr("%s", tmp_chars);
@@ -1920,7 +1680,7 @@ void Player::display_weapons()
 
    send_plr("&+GCurrent weapon proficiencies:&*\n\n");
    send_plr("&+B-------------------------------&*\n");
-   tmp_rank = player_ranks;
+   tmp_rank = get_ranks();
    while (tmp_rank != NULL)
    {
       for (i=0; i<5; i++)
@@ -1933,7 +1693,7 @@ void Player::display_weapons()
       {
          sprintf(tmp_chars, "&+G   %-10s &+cRank: &+W%-5d &+c(%d%%)&*\n",
               tmp_rank->rank_name.str_show(), tmp_rank->the_rank,
-           (int) ((((float) tmp_rank->the_exp) / 
+           (int) ((((float) tmp_rank->the_exp_prob) / 
                                      ((float) cutoff_exp[i])) * 100.0));
 
          send_plr("%s", tmp_chars);
@@ -1947,153 +1707,10 @@ void Player::display_weapons()
 }
 
 
-/***********************************************************************
- ** add_rank_list - adds a list of ranks in a space delineated
- **                 string to the player
- **
- ** Parameters: the_list - the list of ranks to add
- **
- ** Returns: num added for success, -1 for failure
- **
- ***********************************************************************/
-
-int Player::add_rank_list(char *the_list)
-{
-   Strings tmp_str;
-   int     counter = 1;
-   Ability *tmp_ability;
-   Strings holder;
-
-   tmp_str.assign_word(the_list, counter);
-   while (tmp_str.str_show() != NULL)
-   {
-      /* if we can't find an ability, it must be a weapon */
-      if ((tmp_ability =
-                  mainstruct->get_ability(tmp_str.str_show())) == NULL)
-      {
-         add_rank(tmp_str.str_show(), 0, 0, 0);
-      }
-      else
-         add_rank(tmp_ability->get_name(), tmp_ability->get_type(), 0, 0);
-
-      counter++;
-      tmp_str.assign_word(the_list, counter);
-   }
-   return counter-1;
-}
-
-
-/***********************************************************************
- ** get_max_magic - returns the max magic the player is capable of
- **
- **
- ***********************************************************************/
-
-int Player::get_max_magic()
-{
-   return max_magic;
-}
-
-
-/***********************************************************************
- ** set_max_magic - sets the max magic the player is capable of
- **
- ** Parameters: the_num - the new max_magic value
- **
- ***********************************************************************/
-
-void Player::set_max_magic(int the_num)
-{
-   if (the_num > 0)
-      max_magic = the_num;
-}
-
-
-/***********************************************************************
- ** get_max_endurance - gets the endurance the player is capable of
- **
- **
- ***********************************************************************/
-
-int Player::get_max_endurance()
-{
-   return max_endurance;
-}
-
-
-/***********************************************************************
- ** set_max_endurance - sets the endurance the player is capable of
- **
- ** Parameters: the_num - the new max_endurance value
- **
- ***********************************************************************/
-
-void Player::set_max_endurance(int the_num)
-{
-   if (the_num > 0)
-      max_endurance = the_num;
-}
-
-
-/***********************************************************************
- ** get_magic - gets the current magic level the player has
- **
- **
- ***********************************************************************/
-
-int Player::get_magic()
-{
-   return magic;
-}
-
-/***********************************************************************
- ** set_magic - sets the magic level the player is currently at
- **
- ** Parameters: the_num - the new magic value
- **
- ***********************************************************************/
-
-void Player::set_magic(int the_num)
-{
-   if (the_num > 0)
-      magic = the_num;
-   else
-      magic = 0;
-}
-
-
-/***********************************************************************
- ** get_endurance - gets the endurance the player has left
- **
- **
- ***********************************************************************/
-
-int Player::get_endurance()
-{
-   return endurance;
-}
-
-
-/***********************************************************************
- ** set_endurance - sets the endurance the player is currently at
- **
- ** Parameters: the_num - the new endurance value
- **
- ***********************************************************************/
-
-void Player::set_endurance(int the_num)
-{
-   if (the_num > 0)
-      endurance = the_num;
-   else
-      endurance = 0;
-}
-
-
 /***********************************************************************
  ** get_weight_capacity - gets how much weight the player can carry
  **
- ** Parameters: the_num - the new endurance value
+ ** Parameters: the_num - the new capacity value
  **
  ***********************************************************************/
 
@@ -2117,32 +1734,6 @@ int Player::repeat_last_command()
 }
 
 
-/***********************************************************************
- ** get_wimpy - gets the wimpy point the player has set
- **
- **
- ***********************************************************************/
-
-int Player::get_wimpy()
-{
-   return wimpy;
-}
-
-
-/***********************************************************************
- ** set_wimpy - sets the flee point the player currently has
- **
- ** Parameters: the_num - the new wimpy value
- **
- ***********************************************************************/
-
-void Player::set_wimpy(int the_num)
-{
-   if (the_num > 0)
-      wimpy = the_num;
-   else
-      wimpy = 0;
-}
 
 
 /***********************************************************************
@@ -2322,29 +1913,6 @@ void Player::add_initial_obj()
 }
 
 
-/***********************************************************************
- ** add_initial_obj - adds initial objects to the player's inventory, such
- **                   as the tutorial scrolls
- **
- ** Parameters: is_male - is the player male (1) or female (0)
- **
- ***********************************************************************/
-
-void Player::set_sex(int is_male)
-{
-   if (is_male)
-   {
-      indflags->set_flag(INDFLAG_MALE);
-      game_flags.set_flag(GAMEFLAG_MALE);
-   }
-   else
-   {
-      indflags->clr_flag(INDFLAG_MALE);
-      game_flags.clr_flag(GAMEFLAG_MALE);
-   }
-}
-
-
 /***********************************************************************
  ** change_level - changes the level of this player for a specified chain
  **
@@ -2837,13 +2405,13 @@ void Player::display_quests()
  **
  ***********************************************************************/
 
-void Player::set_pronouns(LinkedList *the_inv)
+void Player::set_pronouns(Inventory *the_inv)
 {
    MudObject  *the_obj;
    Individual *ind_him = NULL;
    Individual *ind_her = NULL;
+   Individual *ind_it = NULL;
    MudObject  *obj_it = NULL;
-   Flags      *tmp_indflags;
 
 
    him.truncate(0);
@@ -2856,22 +2424,25 @@ void Player::set_pronouns(LinkedList *the_inv)
    {
       if (the_obj->is_an_individual())
       {
-         tmp_indflags = ((Individual *) the_obj)->get_indflags();
-
-         if (tmp_indflags->get_flag(INDFLAG_MALE))
+         if (((Individual *) the_obj)->is_male())
             ind_him = ((Individual *) the_obj);
-         else
+         else if (((Individual *) the_obj)->is_female())
             ind_her = ((Individual *) the_obj);
+         else
+             ind_it = ((Individual *) the_obj);
       }
       else
          obj_it = the_obj;
 
       the_obj = the_inv->get_next();
    }
+
    if (ind_him != NULL)
       him = ind_him->get_title();
    if (ind_her != NULL)
       her = ind_her->get_title();
+   if (ind_it != NULL)
+      it  = ind_it->get_title();
    if (obj_it != NULL)
       it = obj_it->get_title();
 }
@@ -3248,7 +2819,7 @@ void Player::increase_rank_exp(int difficulty, Entity *the_object,
       add_rank(rank_name.str_show(), the_type, 0, 0);
    }
 
-   the_exp = get_rank_exp(rank_name.str_show());
+   the_exp = get_rank_exp_prob(rank_name.str_show());
    the_rank = get_rank_number(rank_name.str_show());
 
    /* first we calculate the decrease amount based on how much they
@@ -3301,7 +2872,7 @@ void Player::increase_rank_exp(int difficulty, Entity *the_object,
 
    if (!no_change)
       set_rank_number(rank_name.str_show(), the_rank);
-   set_rank_exp(rank_name.str_show(), the_exp);
+   set_rank_exp_prob(rank_name.str_show(), the_exp);
 }
 
 
@@ -3359,10 +2930,8 @@ Strings *Player::get_misc_string( void )
  ** reset_player: resets all of the player's variables to default
  **
  ***********************************************************************/
-
 void Player::reset_player( void )
 {
-   rank_list       *tmp_rank;
    quest_list      *tmp_quest;
    brief_stack     *tmp_brief;
    prompt_stack    *tmp_prompt;
@@ -3374,22 +2943,19 @@ void Player::reset_player( void )
    get_comflags( )->clr_all( comflagnames );
    set_desc( "You see an ordinary player.\n" );
    set_capacity( 300 );
-   max_endurance = endurance = the_config.default_maxendur;
-   max_magic = magic = the_config.default_maxmagic;
-   wimpy = the_config.default_wimpy;
+   set_max_endurance(the_config.default_maxendur);
+   set_endurance(the_config.default_maxendur);
+   set_max_magic(the_config.default_maxmagic);
+   set_magic(the_config.default_maxmagic);
+   set_wimpy(the_config.default_wimpy);
    pager_lines = the_config.default_pager_lines;
    experience = 0;
 
    /* releases all objects the player is carrying, placing them nowhere */
    release_all_inv();
 
-   /* deletes all ranks from the player */
-   while (player_ranks != NULL)
-   {
-      tmp_rank = player_ranks->next_rank;
-      delete_rank_list(player_ranks);
-      player_ranks = tmp_rank;
-   }
+
+   delete_ranks();
 
    /* deletes all briefs */
    while (cur_brief != NULL)
@@ -3459,9 +3025,9 @@ int Player::load_talent_list()
    }
 
    if (talent_list != NULL)
-      delete_Area_Dbase(talent_list);
+      delete talent_list;
 
-   talent_list = new_Area_Dbase("talents_player");
+   talent_list = new Area_Dbase("talents_player");
 
    talent_area->reset_list();
    tmp_entity = talent_area->get_next_obj();
@@ -3472,7 +3038,7 @@ int Player::load_talent_list()
 
       tmp_talent = (Talent *) tmp_entity;
 
-      new_talent = new_Talent(tmp_talent->get_name());
+      new_talent = new Talent(tmp_talent->get_name());
       new_talent->copy_object(tmp_talent);
 
       talent_list->add_areaobject(new_talent);
@@ -3500,6 +3066,9 @@ int Player::display_talents()
    Strings    holder;
    int        num_in_line = 0;
    int        count = 0;
+   Strings    allow_talent;
+   int        show_all = 0;
+   Race       *plr_race;
 
    if (talent_list == NULL)
    {
@@ -3518,6 +3087,18 @@ int Player::display_talents()
    send_plr("&+B-----------------------------------------------------------&*\n");
    send_plr("&+B| &+GName                &+B| &+GCost &+B| &+GName                &+B| &+GCost &+B|\n");
    send_plr("&+B-----------------------------------------------------------&*\n");
+
+   if ((plr_race = mainstruct->get_race(get_race())) == NULL)
+   {
+     holder.sprintf("Could not get player race '%s'", get_race());
+     mainstruct->log_error(holder.str_show(), "display_talents");
+     return -1;
+   }
+
+   allow_talent = plr_race->get_allow_talent();
+   if (!STRCASECMP(allow_talent.str_show(), "all"))
+     show_all = 1;
+
    while ((tmp_obj = talent_list->get_next_obj()) != NULL)
    {
       if (tmp_obj->get_type() != OBJ_TYPE_TALENT)
@@ -3528,21 +3109,26 @@ int Player::display_talents()
          return -1;
       }
       tmp_talent = (Talent *) tmp_obj;
-      talent_name = tmp_talent->get_name();
-      if (talent_name.str_len() > 19)
-         talent_name.truncate(19);
-      talent_name.upper(0);
-      tmp_line.sprintf("&+B| &+g%-19s&* &+B| %3d  ", talent_name.str_show(),
-                                                     tmp_talent->get_cost());
-      holder.str_cat(tmp_line.str_show());
-      num_in_line++;
-      if (num_in_line == 2)
+
+      if (show_all || (allow_talent.find_in_str(tmp_talent->get_name())))
       {
-         send_plr("&+g%s&+B|&*\n", holder.str_show());
-         holder.truncate(0);
-         num_in_line = 0;
+
+	talent_name = tmp_talent->get_name();
+	if (talent_name.str_len() > 19)
+	  talent_name.truncate(19);
+	talent_name.upper(0);
+	tmp_line.sprintf("&+B| &+g%-19s&* &+B| %3d  ", talent_name.str_show(),
+                                                     tmp_talent->get_cost());
+	holder.str_cat(tmp_line.str_show());
+	num_in_line++;
+	if (num_in_line == 2)
+	{
+	  send_plr("&+g%s&+B|&*\n", holder.str_show());
+	  holder.truncate(0);
+	  num_in_line = 0;
+	}
+	count++;
       }
-      count++;
    }
    if (num_in_line > 0)
    {
@@ -3578,12 +3164,30 @@ int Player::delete_talent_list()
    if (talent_list == NULL)
       return -1;
 
-   delete_Area_Dbase(talent_list);
+   delete talent_list;
    talent_list = NULL;
    return 1;
 }
 
 
+/***********************************************************************
+ ** attack - attacks another individual by using the weapon
+ **
+ ** Returns: 1 for success, -1 for failure
+ **
+ ***********************************************************************/
+
+int Player::attack(Individual *target)
+{
+  if ((get_target() == NULL) || (get_target()->get_loc() != get_loc()))
+  {
+    stop_fighting();
+    return 0;
+  }
+
+  return use_weapon(target);
+}
+
 #endif
 
 
