@@ -619,7 +619,7 @@ int Quest::set_attrib(Builder *the_builder, Parse *the_parsed){
    
 void Quest::write_object(FILE *the_file, int build_format)
 {
-   fprintf(the_file, "\n%s\n", get_name());
+   fprintf(the_file, "\nquest %s\n", get_name());
    if (build_format)
       fprintf(the_file, "%d\n", is_modified());
 
