@@ -41,6 +41,9 @@
 #include "global.h"
 #include "specials.h"
 #include "code.h"
+#include "inp_funct.h"
+#include "comflags.h"
+#include "adminflags.h"
 
 /***********************************************************************
  ** Race (constructor) - loads race name and attributes
@@ -66,6 +69,8 @@ Race::Race(char *race_name)
    set_init_location("needloc@needarea");
    set_death_location("needloc@needarea");
    set_death_text("No text.\n");
+   set_allow_incl("all");
+   set_allow_talent("all");
 
    init_str = init_dex = init_intel = init_con = init_wis = init_cha = 0;
 
@@ -209,9 +214,9 @@ char *Race::get_init_brief(void)
 void Race::set_init_ability(char *the_string)
 {
    if (the_string == NULL)
-      return;
-
-   init_ability = the_string;
+     init_ability.truncate(0);
+   else
+     init_ability = the_string;
 }
 
 /***********************************************************************
@@ -341,9 +346,9 @@ char *Race::get_death_text(void)
 void Race::set_allow_incl(char *the_string)
 {
    if (the_string == NULL)
-      return;
-
-   allow_incl = the_string;
+      allow_incl.truncate(0);
+   else
+     allow_incl = the_string;
 }
 
 /***********************************************************************
@@ -372,9 +377,9 @@ char *Race::get_allow_incl(void)
 void Race::set_allow_talent(char *the_string)
 {
    if (the_string == NULL)
-      return;
-
-   allow_talent = the_string;
+      allow_talent.truncate(0);
+   else
+     allow_talent = the_string;
 }
 
 /***********************************************************************
@@ -824,6 +829,8 @@ void Race::describe(Builder *the_builder)
    the_builder->send_bldr("&+GInitAbility: \t&+w%s&*\n", get_init_ability());
    the_builder->send_bldr("&+GDeathLoc: \t&+w%s&*\n", get_death_location());
    the_builder->send_bldr("&+GDeathText:&* \n%s&*\n", get_death_text());
+   the_builder->send_bldr("&+GAllowIncl: \t&+w%s&*\n", get_allow_incl());
+   the_builder->send_bldr("&+GAllowTalent: \t&+w%s&*\n", get_allow_talent());
    the_builder->send_bldr("&+GInitStr: \t&+w%d&*\n", get_init_str());
    the_builder->send_bldr("&+GInitDex: \t&+w%d&*\n", get_init_dex());
    the_builder->send_bldr("&+GInitIntel: \t&+w%d&*\n", get_init_intel());
@@ -871,6 +878,8 @@ void Race::describe(Player *the_player)
    the_player->send_plr("&+GInitAbility: \t&+w%s&*\n", get_init_ability());
    the_player->send_plr("&+GDeathLoc: \t&+w%s&*\n", get_death_location());
    the_player->send_plr("&+GDeathText:&* \n%s&*\n", get_death_text());
+   the_player->send_plr("&+GAllowIncl: \t&+w%s&*\n", get_allow_incl());
+   the_player->send_plr("&+GAllowTalent: \t&+w%s&*\n", get_allow_talent());
    the_player->send_plr("&+GInitStr: \t&+w%d&*\n", get_init_str());
    the_player->send_plr("&+GInitDex: \t&+w%d&*\n", get_init_dex());
    the_player->send_plr("&+GInitIntel: \t&+w%d&*\n", get_init_intel());
@@ -915,10 +924,10 @@ int Race::set_attrib(Builder *the_builder, Parse *the_parsed){
    if (the_parsed->get_target1() == NULL)
    {   the_builder->
         send_bldr("You can set the following attributes on a race.\n"
-               "   desc, initability, deathloc, deathtext, initstr, \n"
-               "   initdex, initintel, initcon, initwis, initcha,\n"
-	       "   initbrief, initdesc, sequence, prompt, special,\n"
-	       "   and mandatory\n");
+               "   desc, initability, deathloc, deathtext, allowincl,\n"
+	       "   allowtalent, initstr, initdex, initintel, initcon,\n"
+	       "   initwis, initcha, initbrief, initdesc, sequence,\n"
+	       "   prompt, special, and mandatory\n");
        return -1;
    }
 
@@ -984,6 +993,32 @@ int Race::set_attrib(Builder *the_builder, Parse *the_parsed){
       return 1;
    }
 
+   if (!STRNCASECMP(the_parsed->get_target1(), "allowincl",
+                               strlen(the_parsed->get_target1())))
+   {
+      Strings holder;
+       
+      set_allow_incl(the_parsed->get_speech());
+
+      the_builder->send_bldr("AllowIncl on %s set to: %s\n", get_name(), 
+                                                     get_allow_incl());
+      set_modified(1);
+      return 1;
+   }
+
+   if (!STRNCASECMP(the_parsed->get_target1(), "allowtalent",
+                               strlen(the_parsed->get_target1())))
+   {
+      Strings holder;
+       
+      set_allow_talent(the_parsed->get_speech());
+
+      the_builder->send_bldr("AllowTalent on %s set to: %s\n", get_name(), 
+                                                     get_allow_talent());
+      set_modified(1);
+      return 1;
+   }
+
    if (!STRNCASECMP(the_parsed->get_target1(), "initbrief",
                                strlen(the_parsed->get_target1())))
    {
@@ -1010,14 +1045,7 @@ int Race::set_attrib(Builder *the_builder, Parse *the_parsed){
                                strlen(the_parsed->get_target1())))
    {
       Strings holder;
-      
-      if (the_parsed->get_speech() == NULL)
-      {
-         the_builder->
-             send_bldr("You need to specify an InitAbility to set to.\n");
-         return -1;
-      }
- 
+       
       set_init_ability(the_parsed->get_speech());
 
       the_builder->send_bldr("InitAbility on %s set to: %s\n", get_name(), 
@@ -1206,7 +1234,7 @@ int Race::set_attrib(Builder *the_builder, Parse *the_parsed){
          return -1;
       }
 
-      set_init_con(value);
+      set_init_cha(value);
       the_builder->send_bldr("InitCha set to %d on race object %s.\n",
                                           get_init_cha(), get_name());
       return 1;
@@ -1495,14 +1523,22 @@ int Race::add_tutorial(char *the_name)
    }
 
    if (!STRCASECMP(tutorial_list->name.str_show(), the_name))
+   {
+	  delete new_tutorial;
+	  sysmessage("deleting it!\n");
       return -2;
+   }
 
    tmp_tutorial = tutorial_list;
    while (tmp_tutorial->next_tutorial != NULL)
    {
       tmp_tutorial = tmp_tutorial->next_tutorial;
       if (!STRCASECMP(tmp_tutorial->name.str_show(), the_name))
-         return -2;
+	  {
+		 delete new_tutorial;
+  	     sysmessage("deleting it!\n");
+	     return -2;
+	  }
    }
 
    tmp_tutorial->next_tutorial = new_tutorial;
@@ -1816,11 +1852,17 @@ char *Race::get_next_tutorial(char *previous_name)
          tmp_tutorial = tmp_tutorial->next_tutorial;
    }
    
-   if ((tmp_tutorial == NULL) || (tmp_tutorial->next_tutorial == NULL))
+   if (tmp_tutorial == NULL)
       return NULL;
 
    if (previous_name == NULL)
-      return tmp_tutorial->name.str_show();
+   {
+     return tmp_tutorial->name.str_show();
+   }
+
+   if (tmp_tutorial->next_tutorial == NULL)
+     return NULL;
+
    return tmp_tutorial->next_tutorial->name.str_show();
 }
 
@@ -1892,6 +1934,9 @@ int Race::start_tutorial(char *the_name, Player *the_player)
    Inp_Handler *the_handler;
    Strings     holder;   
    in_params   fill_param;
+   Strings     *tutorial = new Strings("&+BTutorial&+C>&* ");
+   Object_List *tmp_dbase;
+   Mask        *the_mask;
 
    tmp_tutorial = tutorial_list;
 
@@ -1915,9 +1960,53 @@ int Race::start_tutorial(char *the_name, Player *the_player)
       return -1;
    }
 
-   if (!tmp_tutorial->mandatory)
-      the_handler->pop_input_handler();
+   if (the_handler->push_input_handler(main_plr_handler, tutorial,
+                                                            1, 0, 0) <= 0)
+   {
+      mainstruct->log_error("Error loading tutorial main input handler for player",
+                                          "start_tutorial");
+      exit(0);
+   }
 
+
+   // Try to apply the tutorial mask if it exists
+   tmp_dbase = mainstruct->get_dbase();
+   if ((the_mask = tmp_dbase->get_mask_obj("tutorial")) != NULL)
+   {
+     Flags *mask_comflags;
+     Flags *mask_admflags;
+     Flags *tmp_comflags = the_player->get_comflags();
+     Flags *tmp_admflags = the_player->get_admflags();
+     int i;
+     int num_of[2];
+
+     mask_comflags = the_mask->get_comflags();
+     mask_admflags = the_mask->get_admflags();
+
+     i=0;
+     while (comflagnames[i] != NULL)
+       i++;
+     num_of[0] = i;
+     
+     i=0;
+     while (admflagnames[i] != NULL)
+       i++;
+     num_of[1] = i;
+     
+     for (i=0; i<num_of[0]; i++)
+     {
+       if (mask_comflags->get_flag(i))
+	 tmp_comflags->set_flag(i);
+     }
+     
+     for (i=0; i<num_of[0]; i++)
+     {
+       if (mask_admflags->get_flag(i))
+	 tmp_admflags->set_flag(i);
+     }
+    
+   }
+   
    fill_param.primary_obj = NULL;
    fill_param.secondary_obj = NULL;
    fill_param.this_obj = the_player;
@@ -1980,10 +2069,48 @@ int Race::copy_object(Entity *copy_obj)
    set_death_location(copy_from->get_death_location());
    set_death_text(copy_from->get_death_text());
 
+   tutorial_list = copy_from->copy_tutorial_list();
+
    return 1;
 }
 
 
+/***********************************************************************
+ ** copy_tutorial_list - copies the tutorials into a new list and passes
+ **                      a pointer to that list back
+ **
+ ***********************************************************************/
+Tutorial *Race::copy_tutorial_list()
+{
+  Tutorial *tmp_tut;
+  Tutorial *new_list = NULL;
+  Tutorial *return_list = NULL;
+
+  tmp_tut = tutorial_list;
+  while (tmp_tut != NULL)
+  {
+    if (new_list == NULL)
+    {
+      new_list = new Tutorial(tmp_tut->name.str_show());
+      return_list = new_list;
+    }
+    else
+    {
+      new_list->next_tutorial = new Tutorial(tmp_tut->name.str_show());
+      new_list = new_list->next_tutorial;
+    }
+
+    new_list->sequence = tmp_tut->sequence;
+    new_list->prompt = tmp_tut->prompt.str_show();
+    new_list->tutorial_special = tmp_tut->tutorial_special.str_show();
+    new_list->mandatory = tmp_tut->mandatory;   
+
+    tmp_tut = tmp_tut->next_tutorial;
+  }
+  return return_list;
+}
+
+
 /***********************************************************************
  ** get_mem_size - gets how much memory this special is taking up
  **
