@@ -469,7 +469,7 @@ int Shop::display_will_buy(Player *the_plr)
 {
    shop_item  *tmp_item;
    Money      *currency_obj;
-   LinkedList *plr_inventory;
+   Inventory  *plr_inventory;
    MudObject  *the_obj;
    int        value;
    Strings    full_name;
