@@ -60,7 +60,7 @@ Specials::~Specials()
    while (tmp_code != NULL)
    {
       the_code = tmp_code->get_next_code();
-      delete_Code(tmp_code);
+      delete tmp_code;
       tmp_code = the_code;
    }
    
@@ -271,13 +271,13 @@ int Specials::read_code(FILE *the_file, ErrLog *the_log, int is_build_port)
       the_token = get_token(the_file, '\0');
       if (the_token->token_type == T_LPAREN)
       {
-         code_holder = new_Code(functname.str_show());
+         code_holder = new Code(functname.str_show());
          if (!code_holder->check_valid())
          {
             holder.sprintf("Unrecognized function '%s' in special %s", 
                              functname.str_show(), get_name());
             the_log->log_err(holder.str_show(), "load_from_file");
-            delete_Code(code_holder);
+            delete code_holder;
             return -1;
          }
 
@@ -286,7 +286,7 @@ int Specials::read_code(FILE *the_file, ErrLog *the_log, int is_build_port)
             holder.sprintf("Error in function '%s' in special %s", 
                           functname.str_show(), get_name());
             the_log->log_err(holder.str_show(), "read_code");
-            delete_Code(code_holder);
+            delete code_holder;
             return -1;
          }
 
@@ -296,7 +296,7 @@ int Specials::read_code(FILE *the_file, ErrLog *the_log, int is_build_port)
             holder.sprintf("Missing semicolon after function '%s' "
                           "for special %s", functname.str_show(), get_name());
             the_log->log_err(holder.str_show(), "read_code");
-            delete_Code(code_holder);
+            delete code_holder;
             return -1;
          }
 
@@ -306,14 +306,14 @@ int Specials::read_code(FILE *the_file, ErrLog *the_log, int is_build_port)
       }
       else if (the_token->token_type == T_EQUALS)
       {
-         code_holder = new_Code("assign");
+         code_holder = new Code("assign");
 
          if (code_holder->load_from_file(the_file, the_log, FORMAT_EQ) <=0)
          {
             holder.sprintf("Error in function '%s' in special %s", 
                           functname.str_show(), get_name());
             the_log->log_err(holder.str_show(), "read_code");
-            delete_Code(code_holder);
+            delete code_holder;
             return -1;
          }
 
@@ -385,7 +385,7 @@ char *Specials::get_trigger(void)
  **
  ***********************************************************************/
 
-int Specials::run_special(Player *the_player, in_params *the_params, 
+int Specials::run_special(Individual *the_user, in_params *the_params, 
                                                    special_env *environment)
 {
    int results = 0;
@@ -409,7 +409,7 @@ int Specials::run_special(Player *the_player, in_params *the_params,
    {
 
       (environment->stack_pointer)->
-         execute_command(this, the_player, the_params, &results, environment);
+         execute_command(this, the_user, the_params, &results, environment);
 
       if (results != 2)
          environment->stack_pointer = 
@@ -907,7 +907,7 @@ Code *Specials::copy_code()
    next_code = the_code;
    while (next_code != NULL)
    {
-      new_code = new_Code(next_code->get_funct_ptr());
+      new_code = new Code(next_code->get_funct_ptr());
       new_code->copy_code(next_code);
       if (last_added == NULL)
       {
@@ -955,16 +955,16 @@ vars *Specials::copy_var_list()
          case VAR_TYPE_OBJNAME:
          case VAR_TYPE_VAR:
             new_var->the_ptr.a_string = 
-                     new_Strings(next_var->the_ptr.a_string->str_show());
+                     new Strings(next_var->the_ptr.a_string->str_show());
             break;
          case VAR_TYPE_INT:
-            new_var->the_ptr.an_int = new_long();
+            new_var->the_ptr.an_int = new long;
             *(new_var->the_ptr.an_int) = *(next_var->the_ptr.an_int);
             break;
 
          case VAR_TYPE_CODE:
             new_var->the_ptr.a_code = 
-                new_Code(next_var->the_ptr.a_code->get_funct_ptr());
+                new Code(next_var->the_ptr.a_code->get_funct_ptr());
             new_var->the_ptr.a_code->copy_code(next_var->the_ptr.a_code);
             break;
 
