@@ -1381,6 +1381,34 @@ int Strings::operator = (Strings *x)
    return str_copy(x->str_show());
 }
 
+/***********************************************************************
+ ** find_letter - finds a letter and returns the position on the string
+ **
+ ** Parameters: the_letter - the letter to find
+ **
+ ** Returns: position if found
+ **          -1 if not found
+ **
+ ***********************************************************************/
+
+int Strings::find_letter(char the_letter)
+{
+  char *tmp_str;
+  int count = 0;
+
+  tmp_str = str;
+  while ((tmp_str) && (*tmp_str != '\0') && (*tmp_str != the_letter))
+  {
+    count++;
+    tmp_str++;
+  }
+
+  if ((!tmp_str) || (*tmp_str == '\0'))
+    return -1;
+
+  return count;
+}
+
 
 /***********************************************************************
  ** find_in_str - finds a string inside another string divided by ' '
@@ -1762,9 +1790,9 @@ int Strings::format_for_actions(char *the_string, MudObject *the_user,
 	 {
             sex = -1;
             if (*(tmp_str+1) == '[')
-               sex = ((Player *) the_user)->is_male();
+               sex = ((Player *) the_user)->get_sex();
             else if (the_target != NULL)
-               sex = ((Individual *) the_target)->is_male();
+               sex = ((Individual *) the_target)->get_sex();
             
             if (sex != -1)
 	    {
@@ -1825,8 +1853,10 @@ int Strings::format_for_actions(char *the_string, MudObject *the_user,
             }
             if (((Player *)the_user)->is_male())
                str_cat("his");
-            else
+            else if (((Player *)the_user)->is_female())
                str_cat("her");
+            else
+                str_cat("its");
             tmp_str += 2;
             start_str = tmp_str;
          }
@@ -1840,8 +1870,10 @@ int Strings::format_for_actions(char *the_string, MudObject *the_user,
             }
             if (((Player *) the_user)->is_male())
                str_cat("him");
-            else
+            else if (((Player *)the_user)->is_female())
                str_cat("her");
+            else
+                str_cat("its");
             tmp_str += 2;
             start_str = tmp_str;
          }
@@ -1871,7 +1903,7 @@ int Strings::format_for_actions(char *the_string, MudObject *the_user,
  **
  ***********************************************************************/
 
-int Strings::format_for_abilities(char *the_string, Player *the_player, 
+int Strings::format_for_abilities(char *the_string, Individual *the_user, 
                                                   MudObject *the_target)
 {
    char *tmp_str;
@@ -1879,7 +1911,7 @@ int Strings::format_for_abilities(char *the_string, Player *the_player,
    char *str_holder;
    int  sex = -1;
 
-   if ((the_string == NULL) || (the_player == NULL))
+   if ((the_string == NULL) || (the_user == NULL))
       return -1;
 
    if (str != NULL)
@@ -1905,7 +1937,7 @@ int Strings::format_for_abilities(char *the_string, Player *the_player,
                *tmp_str = '\0';
                str_cat(start_str);
             }
-            str_cat(the_player->get_title());
+            str_cat(the_user->get_title());
             tmp_str += 2;
             start_str = tmp_str;
          }
@@ -1927,9 +1959,9 @@ int Strings::format_for_abilities(char *the_string, Player *the_player,
 	 {
             sex = -1;
             if (*(tmp_str+1) == '[')
-               sex = the_player->is_male();
+               sex = the_user->get_sex();
             else if (the_target != NULL)
-               sex = ((Individual *) the_target)->is_male();
+               sex = ((Individual *) the_target)->get_sex();
             
             if (sex != -1)
 	    {
@@ -1987,10 +2019,12 @@ int Strings::format_for_abilities(char *the_string, Player *the_player,
                *tmp_str = '\0';
                str_cat(start_str);
             }
-            if (the_player->is_male())
+            if (the_user->is_male())
                str_cat("his");
-            else
+            else if (the_user->is_female())
                str_cat("her");
+            else
+                str_cat("its");
             tmp_str += 2;
             start_str = tmp_str;
          }
@@ -2002,10 +2036,12 @@ int Strings::format_for_abilities(char *the_string, Player *the_player,
                *tmp_str = '\0';
                str_cat(start_str);
             }
-            if (the_player->is_male())
+            if (the_user->is_male())
                str_cat("him");
-            else
+            else if (the_user->is_female())
                str_cat("her");
+            else
+                str_cat("its");
             tmp_str += 2;
             start_str = tmp_str;
          }
