@@ -78,8 +78,9 @@ Talent::Talent(char *talent_name)
  **
  ***********************************************************************/
 
-Talent::~Talent(void)
+Talent::~Talent()
 {
+	return;
 }
 
 
