@@ -75,13 +75,18 @@ User_Dbase::~User_Dbase()
  ** write_user - writes a user to the appropriate file
  **
  ** Parameters: the_player - a pointer to the player struct to write
+ **             death - has the player died, if so mark it as such
  **
  ** Returns: 0 for success
  **          -1 for failure
  **
  ***********************************************************************/
-
 int User_Dbase::write_user(Player *the_player)
+{
+  return write_user(the_player, 0);
+}
+
+int User_Dbase::write_user(Player *the_player, int death)
 {
    Flags       *tmp_comflags;
    Flags       *tmp_admflags;
@@ -111,12 +116,11 @@ int User_Dbase::write_user(Player *the_player)
                 USERDATADIR, user_dir, username.str_show(), USEREXTENTION);
 
    /* if they have something, open the file for writing it */
-   if ((the_file = xfopen(filename.str_show(), "w+", "user_file")) == NULL)
-   {
-      mainstruct->log_error("Could not open player data file", 
-                                                          "write_user");
-      return -1;
-   }
+    if ((the_file = xfopen(filename.str_show(), "w+", "user_file")) == NULL)
+    {
+        mainstruct->log_error("Could not open player data file", "write_user");
+        return -1;
+    }
 
    tmp_comflags = the_player->get_comflags();
    tmp_admflags = the_player->get_admflags();
@@ -124,11 +128,13 @@ int User_Dbase::write_user(Player *the_player)
  
    fprintf(the_file, "name %s\n", the_player->get_name());
    fprintf(the_file, "^%s^\n", the_player->get_passwd());
- 
+
    tmp_comflags->write_flag(the_file);
    tmp_admflags->write_flag(the_file);
    tmp_gameflags->write_flag(the_file);
 
+   if ((the_config.conf_flags->get_flag(CF_PERMDEATH) && (death)))
+      fprintf(the_file, "xxx\n"); 
    if (the_player->get_strength() != the_config.default_strength)
       fprintf(the_file, "str %d\n", the_player->get_strength());
    if (the_player->get_dexterity() != the_config.default_dexterity)
@@ -149,6 +155,8 @@ int User_Dbase::write_user(Player *the_player)
       fprintf(the_file, "exp %ld\n", the_player->get_exp());
    if (the_player->get_pager_lines() != the_config.default_pager_lines)
       fprintf(the_file, "pag %d\n", the_player->get_pager_lines());
+   fprintf(the_file, "sex %d\n", the_player->get_sex());
+   fprintf(the_file, "vislvl %d\n", the_player->get_vislvl());
 
    fprintf(the_file, "desc ^%s^\n", the_player->get_desc());
    fprintf(the_file, "bri ^%s^\n", the_player->get_brief("main"));
@@ -181,8 +189,7 @@ int User_Dbase::write_user(Player *the_player)
  **
  ***********************************************************************/
 
-int User_Dbase::read_user(char *the_name, Player *the_player)
-{
+int User_Dbase::read_user(char *the_name, Player *the_player){
    Strings       username;
    char          user_dir;
    Strings       filename;
@@ -248,11 +255,6 @@ int User_Dbase::read_user(char *the_name, Player *the_player)
    tmp_admflags->read_flags(the_file, mainstruct->get_log());
    tmp_gameflags->read_flags(the_file, mainstruct->get_log());
 
-   if (tmp_gameflags->get_flag(GAMEFLAG_MALE))
-      tmp_indflags->set_flag(INDFLAG_MALE);
-   else
-      tmp_indflags->clr_flag(INDFLAG_MALE);
-
    if (tmp_gameflags->get_flag(GAMEFLAG_NIGHTVISION))
       tmp_indflags->set_flag(INDFLAG_NIGHTVISION);
    else
@@ -273,6 +275,12 @@ int User_Dbase::read_user(char *the_name, Player *the_player)
          }
          the_player->set_strength(atoi(the_token->the_string));
       }
+
+      // If they have died and it is permanent, report back
+      else if ((the_config.conf_flags->get_flag(CF_PERMDEATH)) && 
+	       (!STRCASECMP(the_token->the_string, "xxx")))
+	return -2;
+
       else if (!STRCASECMP(the_token->the_string, "dex"))
       {
          the_token = get_token(the_file, '\0');
@@ -384,6 +392,33 @@ int User_Dbase::read_user(char *the_name, Player *the_player)
          }
          the_player->set_pager_lines(atoi(the_token->the_string));
       }
+      else if (!STRCASECMP(the_token->the_string, "sex"))
+      {
+          the_token = get_token(the_file, '\0');
+          if (the_token->token_type != T_NUMERICAL)
+          {
+              holder.sprintf("Missing number for sex attribute, %s datafile.", the_name);
+              mainstruct->log_error(holder.str_show(), "read_user");
+              return 0;
+          }
+          if (tmp_gameflags->get_flag(GAMEFLAG_MALE)) {
+              the_player->set_sex(SEX_MALE);
+              tmp_gameflags->clr_flag(GAMEFLAG_MALE);
+          } 
+          else
+            the_player->set_sex(atoi(the_token->the_string));
+      }
+      else if (!STRCASECMP(the_token->the_string, "vislvl"))
+      {
+          the_token = get_token(the_file, '\0');
+          if (the_token->token_type != T_NUMERICAL)
+          {
+              holder.sprintf("Missing number for vislvl attribute, %s datafile.", the_name);
+              mainstruct->log_error(holder.str_show(), "read_user");
+              return 0;
+          }
+          the_player->set_vislvl(atoi(the_token->the_string));
+      }
       else if (!STRCASECMP(the_token->the_string, "bir"))
       {
          the_token = get_token(the_file, '\0');
@@ -474,7 +509,7 @@ int User_Dbase::read_user(char *the_name, Player *the_player)
       {
          the_token = get_token(the_file, '\0');
 
-         the_player->set_location(the_token->the_string);
+         the_player->set_loc_str(the_token->the_string);
       }
       else if (!STRCASECMP(the_token->the_string, "inv"))
       {
@@ -610,6 +645,10 @@ int User_Dbase::read_user(char *the_name, Builder *the_builder)
       {
          the_token = get_token(the_file, '\0');
       }
+      else if (!STRCASECMP(the_token->the_string, "xxx"))
+      {
+	// Do nothing
+      }
       else if (!STRCASECMP(the_token->the_string, "maxm"))
       {
          the_token = get_token(the_file, '\0');
@@ -642,7 +681,21 @@ int User_Dbase::read_user(char *the_name, Builder *the_builder)
       {
          the_token = get_token(the_file, '\0');
       }
-
+      else if (!STRCASECMP(the_token->the_string, "sex"))
+      {
+          the_token = get_token(the_file, '\0');
+      }
+      else if (!STRCASECMP(the_token->the_string, "vislvl"))
+      {
+          the_token = get_token(the_file, '\0');
+          if (the_token->token_type != T_NUMERICAL)
+          {
+              holder.sprintf("Missing number for vislvl attribute, %s datafile.", the_name);
+              mainstruct->log_error(holder.str_show(), "read_user");
+              return 0;
+          }
+          the_builder->set_vislvl(atoi(the_token->the_string));
+      }
       else if (!STRCASECMP(the_token->the_string, "pag"))
       {
          the_token = get_token(the_file, '\0');
