@@ -33,6 +33,9 @@
 #include "objtype.h"
 #include "flags.h"
 #include "player.h"
+#include "specials.h"
+#include "code.h"
+#include "global.h"
 
 /***********************************************************************
  ** Weapon (constructor)
@@ -748,6 +751,78 @@ int Weapon::get_mem_size_dynamic()
 }
 
 
+/***********************************************************************
+ ** swing - uses the weapon and if a range weapon, decrements one ammo
+ **
+ ** Returns: 1 for success, 0 for no ammo available
+ **
+ ***********************************************************************/
+
+int Weapon::swing(Individual *attacker, Individual *target, Merger **proj_return)
+{
+   Inventory  *weapon_inv;
+   MudObject  *projectile;
+   special_holder  *proj_special;
+   in_params  fill_param;
+   Player     *tmp_player = NULL;
+   int        results;
+
+   /* does the attacker wield a long range weapon (bow, slingshot, etc) */
+   if (STRCASECMP(get_weapon_class(), "bow"))
+   {
+     *proj_return = NULL;
+     return 1;
+   }
+
+   weapon_inv = get_inventory();
+   weapon_inv->reset_current();
+   projectile = weapon_inv->get_next();
+
+   while (projectile != NULL)
+   {
+      if ((proj_special = projectile->find_special("on_launch")) != NULL)
+      {
+         break;
+      }
+      projectile = weapon_inv->get_next();
+   }
+
+   // They have nothing loaded
+   if ((projectile == NULL) || (projectile->get_type() != OBJ_TYPE_MERGER))
+   {
+     return 0;
+   }
+
+   // We pass back the projectile name
+   (*proj_return) = (Merger *) projectile;
+
+   // Now we run the fire special which should decrement the number of
+   // projectiles and display the fire message 
+
+   if (attacker->get_type() == OBJ_TYPE_PLAYER)
+      tmp_player = (Player *) attacker;
+
+   fill_param.primary_obj = (MudObject *) target;
+   fill_param.secondary_obj = (MudObject *) attacker;
+   fill_param.this_obj = (MudObject *) projectile;
+
+   results = (proj_special->the_special)->
+             run_special(tmp_player, &fill_param, &proj_special->environment);
+   if (results == 0)
+      return 1;
+   if (results == 2)
+   {
+      attacker->send_plr("&+RYou have run out of %s!&*\n", 
+                                            projectile->get_title());
+      remove_contained(projectile);
+      mainstruct->delete_object(projectile);
+      return 0;
+   }
+
+   return 1;
+}
+
+
 #endif
 
 
