@@ -74,7 +74,7 @@ Wearable::Wearable(char *the_name, char *the_area)
 
    size = weight = state = armor = 0;
 
-   wear_flags = new_Flags(1);
+   wear_flags = new Flags(1);
 }
 
 /***********************************************************************
@@ -88,7 +88,7 @@ Wearable::Wearable(char *the_name, char *the_area)
 
 Wearable::~Wearable()
 {
-   delete_Flags(wear_flags);
+   delete wear_flags;
 }
 
 
