@@ -209,7 +209,7 @@ flag_name oflags_item[NUM_OFLAGS_ITEM] = {
   {"CantPick",    NULL}};
 
 
-/* left side is oflag equivalent to the right side itemflag. */
+/* left side is oflag equivalent to the right side wearflag. */
 
 #define NUM_OFLAGS_WEAR 42
 
@@ -291,7 +291,7 @@ int ap_convert(FILE *read_file, FILE *write_file, char *filename, float version)
    while (the_token->token_type > 0)
    {
       /* ignore comments in the file */
-      if (the_token->token_type == T_DIVIDE)
+      if (the_token->token_type == T_SLASH)
       {
          the_token = get_token(read_file, '\0');
          if (the_token->token_type == T_MULT)
@@ -421,6 +421,11 @@ int ap_get_loc_element(FILE *read_file, token_record **the_token)
 	       {
                   a_loc.lflags->set_flag(i);
                }
+	       else if (!STRCASECMP(lflags[i].aberflag, "dark"))
+	       {
+		  a_loc.is_dark = 1;
+	       }
+
                i = NUM_LFLAGS;
                found = 1;
             }
@@ -843,6 +848,11 @@ int ap_get_obj_element(FILE *read_file, token_record **the_token)
          if (!STRCASECMP((*the_token)->the_string, "NoGet"))
             an_obj.poss_type.str_cat("This might be a marker\n");
 
+         if (!STRCASECMP((*the_token)->the_string, "Rope"))
+            an_obj.poss_type.str_cat("This might be a rope\n");
+
+	 found = 0;
+
          /* first check the itemflags for a match */
          for (i=0; i<NUM_OFLAGS_ITEM; i++)
          {
@@ -1227,9 +1237,9 @@ int ap_read_object(FILE *read_file, FILE *write_file)
    an_obj.basevalue = 0;
    an_obj.size = 0;
    an_obj.weight = 0;
-   an_obj.desc0 = "No Desc";
-   an_obj.desc1 = "No Desc";
-   an_obj.desc2 = "No Desc";
+   an_obj.desc0.truncate(0);
+   an_obj.desc1.truncate(0);
+   an_obj.desc2.truncate(0);
    an_obj.examine = "No Examine";
    an_obj.poss_type.truncate(0);
 
@@ -1241,7 +1251,7 @@ int ap_read_object(FILE *read_file, FILE *write_file)
 
    if (the_token->token_type != T_IDENTIFIER)
    {
-      printf("Error reading name.\n");
+      printf("Error reading name.  Got '%s'\n", the_token->the_string);
       return -1;
    }
    an_obj.name = the_token->the_string;
@@ -1383,6 +1393,7 @@ int ap_read_location(FILE *read_file, FILE *write_file)
    a_loc.title = "No Title";
    a_loc.lflags = new Flags(2);
    a_loc.desc = "No Desc";
+   a_loc.is_dark = 0;
 
    /* get the location name */
    the_token = get_token(read_file, '\0');
@@ -1431,6 +1442,8 @@ int ap_read_location(FILE *read_file, FILE *write_file)
    fprintf(write_file, "LocFlag1 %ld\n", tmp_flags->flags);
    tmp_flags = tmp_flags->next_flag;
    fprintf(write_file, "LocFlag2 %ld\n", tmp_flags->flags);
+   if (a_loc.is_dark)
+     fprintf(write_file, "Lighting 1\n");
    fprintf(write_file, "EndLocation\n\n");
 
    return 1;
@@ -1509,6 +1522,10 @@ int ap_write_obj(FILE *write_file)
    {
 		convert_type = OBJ_TYPE_MONEY;
    }
+   else if (!STRCASECMP(LPCTSTR(dlg.m_selecttype), "Rope"))
+   {
+		convert_type = OBJ_TYPE_ROPE;
+   }
    else
    {
 		convert_type = 9999;
@@ -1528,55 +1545,52 @@ int ap_write_obj(FILE *write_file)
       }
       else if (!STRNCASECMP(user_input, "book", 4))
       {
-		 convert_type = OBJ_TYPE_BOOK;
+	 convert_type = OBJ_TYPE_BOOK;
          got_answer = 1;
       }
       else if (!STRNCASECMP(user_input, "weapon", 4))
       {
-		 convert_type = OBJ_TYPE_WEAPON;
-         ap_write_as_weapon(write_file);
+	 convert_type = OBJ_TYPE_WEAPON;
          got_answer = 1;
       }
       else if (!STRNCASECMP(user_input, "wearable", 4))
       {
-		 convert_type = OBJ_TYPE_WEARABLE;
-         ap_write_as_wearable(write_file);
+	 convert_type = OBJ_TYPE_WEARABLE;
          got_answer = 1;
       }
       else if (!STRNCASECMP(user_input, "key", 3))
       {
-		 convert_type = OBJ_TYPE_KEY;
-         ap_write_as_key(write_file);
+	 convert_type = OBJ_TYPE_KEY;
          got_answer = 1;
       }
       else if (!STRNCASECMP(user_input, "moveable", 4))
       {
-		 convert_type = OBJ_TYPE_MOVEABLE;
-         ap_write_as_moveable(write_file);
+	 convert_type = OBJ_TYPE_MOVEABLE;
          got_answer = 1;
       }
       else if (!STRNCASECMP(user_input, "marker", 4))
       {
-		 convert_type = OBJ_TYPE_MARKER;
-         ap_write_as_marker(write_file);
+	 convert_type = OBJ_TYPE_MARKER;
          got_answer = 1;
       }
       else if (!STRNCASECMP(user_input, "door", 4))
       {
-		 convert_type = OBJ_TYPE_DOOR;
-         ap_write_as_door(write_file);
+	 convert_type = OBJ_TYPE_DOOR;
          got_answer = 1;
       }
       else if (!STRNCASECMP(user_input, "food", 4))
       {
-		 convert_type = OBJ_TYPE_FOOD;
-         ap_write_as_food(write_file);
+	 convert_type = OBJ_TYPE_FOOD;
          got_answer = 1;
       }
       else if (!STRNCASECMP(user_input, "money", 4))
       {
-		 convert_type = OBJ_TYPE_MONEY;
-         ap_write_as_money(write_file);
+	 convert_type = OBJ_TYPE_MONEY;
+         got_answer = 1;
+      }
+      else if (!STRNCASECMP(user_input, "rope", 4))
+      {
+	 convert_type = OBJ_TYPE_ROPE;
          got_answer = 1;
       }
       else if (!STRNCASECMP(user_input, "none", 4))
@@ -1630,6 +1644,10 @@ int ap_write_obj(FILE *write_file)
          ap_write_as_money(write_file);
 		 break;
 
+   case OBJ_TYPE_ROPE:
+         ap_write_as_rope(write_file);
+		 break;
+
    default:
 	   break;
    }
@@ -1653,7 +1671,7 @@ void ap_display_options()
    printf(
       "\nValid options are:\n"
       "   Book, Door, Key, Marker, Mobile, Moveable, Weapon,\n"
-      "   Merger, Money, Wearable, Food, None (does not convert it)\n\n");
+      "   Merger, Money, Wearable, Food, Rope, None (does not convert it)\n\n");
 }
 
 
@@ -1765,6 +1783,16 @@ void ap_write_item_attrib(FILE *write_file)
 
 void ap_write_moveable_attrib(FILE *write_file)
 {
+  printf("desc0: %s\n", an_obj.desc0.str_show());
+  printf("desc1: %s\n", an_obj.desc1.str_show());
+
+  if ((an_obj.desc1.str_show() == NULL) || 
+      (!STRCASECMP(an_obj.desc1.str_show(), "No Desc")))
+    an_obj.desc1 = an_obj.desc0.str_show();
+  if ((an_obj.desc0.str_show() == NULL) || 
+      (!STRCASECMP(an_obj.desc0.str_show(), "No Desc")))
+    an_obj.desc0 = an_obj.desc1.str_show();
+
    fprintf(write_file, "Brief1 ^%s^\n", (an_obj.desc1.str_show() == NULL) ? 
                    (an_obj.desc0.str_show()) : (an_obj.desc1.str_show()));
    fprintf(write_file, "Brief2 ^%s^\n", (an_obj.desc0.str_show() == NULL) ? 
@@ -1855,7 +1883,7 @@ void ap_write_as_wearable(FILE *write_file)
 
    fprintf(write_file, "Armor %d\n", an_obj.armor);
 
-   tmp_flags = (an_obj.itemflags->get_flagstruct());
+   tmp_flags = (an_obj.wearflags->get_flagstruct());
    fprintf(write_file, "WearFlag1 %ld\n", tmp_flags->flags);
 
    fprintf(write_file, "EndWearable\n\n");
@@ -1919,10 +1947,12 @@ void ap_write_as_door(FILE *write_file)
    ap_write_mudobj_attrib(write_file);
    ap_write_item_attrib(write_file);
 
+   fprintf(write_file, "Brief0 ^%s^\n", (an_obj.desc0.str_show() == NULL) ? "" : 
+												an_obj.desc0.str_show());
    fprintf(write_file, "Brief1 ^%s^\n", (an_obj.desc1.str_show() == NULL) ? "" : 
 												an_obj.desc1.str_show());
-   fprintf(write_file, "Brief2 ^%s^\n", (an_obj.desc0.str_show() == NULL) ? "" : 
-												an_obj.desc0.str_show());
+   fprintf(write_file, "Brief2 ^%s^\n", (an_obj.desc2.str_show() == NULL) ? "" : 
+												an_obj.desc2.str_show());
    fprintf(write_file, "EndDoor\n\n");
 }
 
@@ -1992,6 +2022,28 @@ void ap_write_as_money(FILE *write_file)
    fprintf(write_file, "EndMoney\n\n");
 }
 
+/***********************************************************************
+ ** ap_write_as_rope - writes this object to file as a rope obj
+ **
+ ** Parameters: write_file - the AIME file we write to
+ **
+ ** Returns: Nothing
+ **
+ ***********************************************************************/
+
+void ap_write_as_rope(FILE *write_file)
+{
+   fprintf(write_file, "StartRope\n");
+   fprintf(write_file, "Name ^%s^\n", an_obj.name.str_show());
+
+   ap_write_mudobj_attrib(write_file);
+   ap_write_item_attrib(write_file);
+   ap_write_moveable_attrib(write_file);
+
+   fprintf(write_file, "RopeLength 1\n");
+   fprintf(write_file, "EndRope\n\n");
+}
+
 #endif
 
 
