@@ -65,12 +65,12 @@ Flags::Flags()
    {
       if (flag_list == NULL)
       {
-         flag_list = new_flag_long_int();
+         flag_list = new flag_long_int();
          tmp_flags = flag_list;
       }
       else
       {
-         tmp_flags->next_flag = new_flag_long_int();
+         tmp_flags->next_flag = new flag_long_int();
          tmp_flags = tmp_flags->next_flag;
       }
       tmp_flags->next_flag = NULL;
@@ -100,12 +100,12 @@ Flags::Flags(int num_long_int)
    {
       if (flag_list == NULL)
       {
-         flag_list = new_flag_long_int();
+         flag_list = new flag_long_int();
          tmp_flags = flag_list;
       }
       else
       {
-         tmp_flags->next_flag = new_flag_long_int();
+         tmp_flags->next_flag = new flag_long_int();
          tmp_flags = tmp_flags->next_flag;
       }
       tmp_flags->next_flag = NULL;
@@ -131,7 +131,7 @@ Flags::~Flags()
    while (tmp_flags != NULL)
    {
       flag_list = tmp_flags->next_flag;
-      delete_flag_long_int(tmp_flags);
+      delete tmp_flags;
       tmp_flags = flag_list;
    }
 
@@ -684,7 +684,8 @@ int Flags::read_flags(FILE *the_file, ErrLog *error_log)
 #ifndef CONVERTER
       if (the_token->token_type != T_NUMERICAL)
       {
-         error_log->log_err("Error in flags format", "read_flags");
+          if (error_log != NULL)
+            error_log->log_err("Error in flags format", "read_flags");
          return -1;
       }
 #endif
