@@ -119,7 +119,7 @@ char *xlowercase (char *str, int thesize)
   char *newstring;
   char *returnstr;
 
-  newstring = new_char(thesize);
+  newstring = new char[thesize];
 
   returnstr = newstring;
   for (oldstring = str; ((*oldstring != '\0') && (*oldstring)); oldstring++)
@@ -372,12 +372,12 @@ int get_ttype(char *tokenstr)
 
    if ((results = find_token_data(token_tree, tempstr)) != -1)
    {
-      delete_char(tempstr);
+      delete tempstr;
       return results;
    }
 
    /* free the lowercase string */
-   delete_char(tempstr);
+   delete tempstr;
 
    /* if it wasnt in the table, and it isnt an alphanumeric, then mark it
       as OTHER */
@@ -394,29 +394,6 @@ int get_ttype(char *tokenstr)
 }
 
 
-/*****************************************************************************
- **
- ** xfopen - opens a read file, as well as resets globals for reading. This 
- **          should be used to open a file that is intended for the lexer to 
- **          parse through. You should only have one file open at a time 
- **          for use by the function get_token or else stacks could get
- **          corrupted and cause faulty results. You could theoretically
- **          do two files at once (never tried it) but I wouldnt recommend
- **          it
- **
- ** Parameters: filename - the string filename to open
- **
- ** ret - the pointer to the file
- **
- **
- ****************************************************************************/
-
-FILE *xfopen(char *filename)
-{
-   num_in_stack = 0;
-   return fopen(filename, "r");
-}
-
 /****************************************************************************
  **
  ** goto_next_char - positions the file pointer right at the next character
@@ -539,7 +516,7 @@ string_record *get_str_until(FILE *thefile, char until1, char until2)
 
    /* creates a new string record */
    temp_str = new_string_record();
-   temp_str->the_string = new_char(TOKENSTRLEN);
+   temp_str->the_string = new char[TOKENSTRLEN];
    temp_str->the_string[0] = '\0';
    str_ptr = temp_str;
 
@@ -566,7 +543,7 @@ string_record *get_str_until(FILE *thefile, char until1, char until2)
           (char *)realloc(str_ptr->the_string,strlen(str_ptr->the_string) + 1);
          str_ptr->nextstr = new_string_record();
          str_ptr = str_ptr->nextstr;
-         str_ptr->the_string = new_char(TOKENSTRLEN);
+         str_ptr->the_string = new char[TOKENSTRLEN];
          str_ptr->the_string[0] = '\0';
          count = -1;
          nextchar = (char) fgetc(thefile);
