@@ -24,6 +24,10 @@ mod_function mod_list[] = {
   {"AIME_v0.56", aime_to_pseudo, (float) 0.56},
   {"AIME_v0.57", aime_to_pseudo, (float) 0.57},
   {"AIME_v0.58", aime_to_pseudo, (float) 0.58},
+  {"AIME_v0.59", aime_to_pseudo, (float) 0.59},
+  {"AIME_V0.59.1", aime_to_pseudo, (float) 0.591},
+  {"AIME_v0.59.2", aime_to_pseudo, (float) 0.592},
+  {"AIME_v0.60.1", aime_to_pseudo, (float) 0.601},
   {NULL, NULL, 0.0}
 };
 
