@@ -30,6 +30,7 @@
 #define UTILS_C
 
 #ifndef CONVERTER
+#include <signal.h>
 #include "config.h"
 #include "sysdep.h"
 #include "global.h"
@@ -52,6 +53,8 @@
 #include "md5.h"
 #include "race.h"
 #include "verb_list.h"
+#include "memchk.h"
+
 #else
 #include "../../include/strings.h"
 #include "../../include/sysdep.h"
@@ -290,8 +293,8 @@ int test_malloc()
 
    for (i=0; i<1000; i++)
    {
-      teststr = new_char(100);
-      delete_char(teststr);
+      teststr = new char[100];
+      delete teststr;
    }
    return 1;
 
@@ -362,10 +365,10 @@ int data_log_on_pop(Inp_Handler *the_handler, char *player_name,
 
 int check_specials(char *trig_name, MudObject *the_obj,
                          MudObject *the_primary, MudObject *the_secondary,
-                         MudObject *this_obj, Player *the_player)
+                         MudObject *this_obj, Individual *the_user)
 {
    return check_specials(trig_name, the_obj, the_primary, the_secondary,
-                                               this_obj, the_player, NULL);
+                                               this_obj, the_user, NULL);
 }
 
 
@@ -395,7 +398,7 @@ int check_specials(char *trig_name, MudObject *the_obj,
 
 int check_specials(char *trig_name, MudObject *the_obj,
                          MudObject *the_primary, MudObject *the_secondary,
-                         MudObject *this_obj, Player *the_player,
+                         MudObject *this_obj, Individual *the_user,
                                                     char *target_text)
 {
    special_holder *the_special;
@@ -415,7 +418,7 @@ int check_specials(char *trig_name, MudObject *the_obj,
       the_special->environment.trig_used = trig_name;
       the_special->environment.target_str = target_text;
       if ((results = (the_special->the_special)->
-        run_special(the_player, &fill_param, &the_special->environment)) == 2)
+        run_special(the_user, &fill_param, &the_special->environment)) == 2)
       {
          MudObject *container;
 
@@ -490,11 +493,14 @@ int enter_new_player(Inp_Handler *the_handler, char *player_name,
    // Make sure the new character isn't deleted
    tmp_gameflags->clr_flag( GAMEFLAG_DELETED );
 
-   if ((the_config.conf_flags->get_flag(CF_AUTOWIZ)) ||
+   // We no longer use master user, just autowiz
+   /*   if ((the_config.conf_flags->get_flag(CF_AUTOWIZ)) ||
        ((!STRCASECMP(the_player->get_title(), the_config.masteruser.str_show())) &&
        (!strcmp(the_player->get_passwd(), the_config.masterpasswd.str_show()))))
-   {
+       {*/
 
+   if (the_config.conf_flags->get_flag(CF_AUTOWIZ))
+   {
       tmp_comflags->set_all(comflagnames);
       tmp_admflags->set_all(admflagnames);
    }
@@ -554,10 +560,10 @@ int enter_new_player(Inp_Handler *the_handler, char *player_name,
 
    if (plr_race == NULL)
    {
-      the_player->set_location(mainstruct->get_def_start_loc());   
+      the_player->set_loc_str(mainstruct->get_def_start_loc());   
    }
    else
-      the_player->set_location(plr_race->get_init_location());
+      the_player->set_loc_str(plr_race->get_init_location());
 
    if (the_player->reset_curr_loc() == -1)
    {
@@ -567,7 +573,7 @@ int enter_new_player(Inp_Handler *the_handler, char *player_name,
                                     the_config.hardcoded_areaname.str_show());
       mainstruct->set_def_start_loc(holder.str_show());
 
-      the_player->set_location(mainstruct->get_def_start_loc());
+      the_player->set_loc_str(mainstruct->get_def_start_loc());
       if (the_player->reset_curr_loc() == -1)
       {
          printf("Fatal Error!!! "
@@ -610,9 +616,9 @@ int enter_new_player(Inp_Handler *the_handler, char *player_name,
 
    loc_holder->show_location(the_player, 0);
 
-   the_player->send_plr(
+   /* the_player->send_plr(
             "You have been given tutorial scrolls to help you.\n"
-            "Type '&+cread intro&*' to start the tutorial\n\n");
+            "Type '&+cread intro&*' to start the tutorial\n\n"); */
 
    mainstruct->sort_playerlist("exp");
 
@@ -640,7 +646,7 @@ int enter_new_player(Inp_Handler *the_handler, char *player_name,
  ***********************************************************************/
 
 MudObject *get_indicated_param(char *param_name, Specials *the_special,
-                               char *function_name, Player *the_player,
+                               char *function_name, Individual *the_user,
                                in_params *player_params)
 {
    MudObject *tmp_obj;
@@ -652,7 +658,7 @@ MudObject *get_indicated_param(char *param_name, Specials *the_special,
    }
    else if (!STRCASECMP(param_name, "actor"))
    {
-      tmp_obj = the_player;
+      tmp_obj = the_user;
    }
    else if (!STRCASECMP(param_name, "primary"))
    {
@@ -670,7 +676,7 @@ MudObject *get_indicated_param(char *param_name, Specials *the_special,
    {
       holder.sprintf(
        "%s is not a valid second parameter for function %s in special %s.  "
-       "Must be either 'primary', 'secondary', 'this' or 'actor'\n",
+       "Must be either 'primary', 'secondary', 'this' or 'actor'",
         param_name, function_name, the_special->get_name());
       mainstruct->log_error(holder.str_show(), "get_indicated_param");
       return NULL;
@@ -815,11 +821,11 @@ int delete_var_list(special_env *environment)
          case VAR_TYPE_STRING:
          case VAR_TYPE_OBJNAME:
          case VAR_TYPE_VAR:
-            delete_Strings(environment->exec_vars->the_ptr.a_string);
+            delete environment->exec_vars->the_ptr.a_string;
             break;
 
          case VAR_TYPE_INT:
-            delete_long(environment->exec_vars->the_ptr.an_int);
+            delete environment->exec_vars->the_ptr.an_int;
             break;
 
          default:
@@ -1027,7 +1033,7 @@ int sysmessage(char *new_str, ...)
    /* now we reset the varg list and create the array, so we can load them
       all into the string */
    va_start( args, new_str );
-   tmp_str = new_char(count);
+   tmp_str = new char[count];
    BZERO(tmp_str, count);
    xlen = VSNPRINTF( tmp_str, count-1, new_str, args );
 
@@ -1041,7 +1047,7 @@ int sysmessage(char *new_str, ...)
    /* now clean up after ourselves */
    va_end( args );
 
-   delete_char(tmp_str);
+   delete tmp_str;
 
    return 1;
 }
@@ -1089,8 +1095,24 @@ int prompt_user_convert(char *filename, char *directory)
 }
 
 
-#endif // Functions for converter should go after this endif
+/***********************************************************************
+ ** fault - an unexpected error has been found
+ **
+ ** Parameters: the_str - a string description of the problem
+ **
+ ***********************************************************************/
 
+void fault(char *the_str)
+{
+#ifdef CRASH_ON_FAULT
+	raise(11);
+#else
+	sysmessage(the_str);
+#endif
+}
+
+
+#endif // Functions for converter should go after this endif
 
 /***********************************************************************
  ** read_desc_type - reads in a description type from a file
@@ -1147,7 +1169,7 @@ char *read_desc_type(FILE *read_file, ErrLog *error_log,
       instead of the method provided by strings since this is more efficient
       to do one malloc instead of a malloc and destroy for each additional
       line in the desc. */
-   temp_desc = new_char(size + 2);
+   temp_desc = new char[size + 2];
    BZERO(temp_desc, size + 2);
 
    /* load the desc strings into the array */
@@ -1182,7 +1204,95 @@ char *read_desc_type(FILE *read_file, ErrLog *error_log,
    return temp_desc;
 }
 
+#ifndef CONVERTER
+int test_mem_worker()
+{
+   Code *tmp_code;
 
+   tmp_code = new Code("test_funct");
+   delete tmp_code;
+	return 1;
+}
+
+int test_funct_worker()
+{
+  token_record *the_token;
+
+  FILE *test_file = xfopen("/home/slate/dist/aime/test.txt", "r", "test");
+
+  if (test_file == NULL)
+    fault("test file did not open properly!\n");
+  the_token = get_token(test_file, '\0');
+  the_token = get_token(test_file, '\0');
+  the_token = get_token(test_file, '\0');
+  the_token = get_token(test_file, '\0');
+  xfclose(test_file, "test");
+
+  return 1;
+}
+
+
+/***********************************************************************
+ ** file_exists - if a file exists or not
+ **
+ ** Parameters: the_file - the full file path
+ **
+ ** Returns: 1 for exists, 0 for not
+ **
+ ***********************************************************************/
+
+int file_exists(char *the_file)
+{
+#ifdef WIN32
+   long lAttr;
+
+   lAttr = GetFileAttributes(the_file);
+   if(lAttr == 0xFFFFFFFF)
+      return 0;
+   return 1;
+#else
+   struct stat check_file;
+
+   if (stat(the_file, &check_file) == -1)
+      return 0;
+   return 1;
+
+#endif
+}
+
+
+int test_funct()
+{
+  printf("testing\n");
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_mem_worker();
+  test_mem_worker();
+  test_mem_worker();
+  test_mem_worker();
+  test_mem_worker();
+  test_mem_worker();
+  test_mem_worker();
+  test_mem_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  test_funct_worker();
+  printf("tested\n");
+
+  return 1;
+}
+#endif
 
 #endif // UTILS_C
 
