@@ -10,6 +10,7 @@
 #include <afxsock.h>
 #include "strings.h"
 #include "..\INCLUDE\strings.h"	// Added by ClassView
+#include "..\INCLUDE\linkedlist.h"
 
 /////////////////////////////////////////////////////////////////////////////
 // CClientSocket command target
@@ -43,9 +44,11 @@ protected:
 public:
 	void unlock();
 	BOOL set_locked();
+	int fill_read_buffer(char *input_buf);
+
 	BOOL valid_input;
 	Strings write_buffer;
-	Strings read_buffer;
+	LinkedList<Strings> read_buffer;
     Strings partial_line;
 
 private:
