@@ -207,7 +207,7 @@ int Connection::check_socket()
  **
  ***********************************************************************/
 
-Strings *Connection::get_input(int lines)
+Strings *Connection::get_input()
 {  Strings *the_input = NULL;
 
 	if (!valid_socket)
@@ -215,19 +215,17 @@ Strings *Connection::get_input(int lines)
 
    if (!lost_link())
    {
+#ifdef DEBUG_INPUT
+       printf("Reading input.\n");
+#endif
 
-       if (list_sock.read_buffer.str_len() != 0)
-       {
-          the_input = new_Strings();
-          the_input->copy_lines(list_sock.read_buffer.str_show(), lines);
-          list_sock.read_buffer.del_lines(lines);
-          the_input->handle_backspaces();
-       }
-       if ((list_sock.read_buffer.str_show() == NULL) ||
-            (list_sock.read_buffer.str_len() == 0))
-       {
-          list_sock.read_buffer.truncate(0);
-       }
+       if ((the_input = list_sock.read_buffer.get_first()) == NULL)
+	      return NULL;
+
+       list_sock.read_buffer.reset_current();
+       list_sock.read_buffer.del_cur_entry();
+
+       the_input->handle_backspaces();
 
        /* now reset the idle time */
        last_input = time(0);
@@ -684,10 +682,11 @@ int Connection::echo_off()
       (char) IAC,
       (char) WILL,
       (char) TELOPT_ECHO,
-      (char)  0,
    };
    flush();
    list_sock.Send(the_string, sizeof(the_string));
+
+   flush();
    return 1;
 }
 
@@ -711,12 +710,14 @@ int Connection::echo_on()
       (char) TELOPT_ECHO,
       (char) TELOPT_NAOFFD,
       (char) TELOPT_NAOCRD,
-      (char)  0,
    };
    flush();
 
    list_sock.Send(the_string, sizeof(the_string)); 
 
+   flush();
+   Sleep(100);
+
    return 1;
 }
 
@@ -762,13 +763,9 @@ void Connection::set_color(int the_num)
 
 bool    Connection::has_input()
 {
-   if ((list_sock.read_buffer.str_show() != NULL) && (list_sock.read_buffer.str_len() == 0))
-      list_sock.read_buffer.truncate(0);
-
-   if (list_sock.read_buffer.str_show() == NULL)
-      return false;
-   else
-      return true;
+   if (list_sock.read_buffer.get_first() == NULL)
+	  return false;
+   return true;
 }
 
 
